@@ -20,29 +20,31 @@
 #define EXCELFILTER_H
 
 #include <filterbase.h>
-#include <qarray.h>
 
 class QDataStream;
-class XMLTree;
+class Handler;
 
 class ExcelFilter : public FilterBase
 {
-	Q_OBJECT
 public:
-	ExcelFilter(const QByteArray &mainStream);
-	~ExcelFilter();
+    ExcelFilter(const QByteArray &mainStream);
+    ~ExcelFilter();
 
-	virtual bool filter();
-	virtual const QDomDocument *const part();
+    virtual bool filter();
+    virtual const QDomDocument *const part();
 
-private slots:
-	void slotGotAuthor(const QString &author);
+//private slots:
+//    void slotGotAuthor(const QString &author);
 
 private:
-	QDataStream *s;
-	XMLTree *tree;
-	double length;
-	static const int MAX_RECORD_SIZE = 0x2024;
+    ExcelFilter(const ExcelFilter &);
+    const ExcelFilter &operator=(const ExcelFilter &);
+
+    QDataStream *m_stream;
+	Handler *m_handler;
+
+    const unsigned m_length;
+    static const int MAX_RECORD_SIZE;
 };
 
 #endif
