@@ -35,6 +35,7 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <klineeditdlg.h>
+#include <kinputdialog.h>
 
 #include "karbon_part.h"
 #include "karbon_view.h"
@@ -46,6 +47,8 @@
 #include "vlayercmd.h"
 #include "vdeletecmd.h"
 #include "vzordercmd.h"
+#include "vgroupcmd.h"
+#include "vungroupcmd.h"
 #include "vselection.h"
 #include "vstroke.h"
 #include "vcanvas.h"
@@ -264,8 +267,8 @@ VDocumentTab::~VDocumentTab()
 void
 VDocumentTab::updateDocumentInfo()
 {
-	m_width->setText( KoUnit::userValue( m_view->part()->document().width(), m_view->part()->unit() ) + m_view->part()->unitName() );
-	m_height->setText( KoUnit::userValue( m_view->part()->document().height(), m_view->part()->unit() ) + m_view->part()->unitName() );
+	m_width->setText( KoUnit::toUserStringValue( m_view->part()->document().width(), m_view->part()->unit() ) + m_view->part()->unitName() );
+	m_height->setText( KoUnit::toUserStringValue( m_view->part()->document().height(), m_view->part()->unit() ) + m_view->part()->unitName() );
 	m_layers->setText( QString::number( m_view->part()->document().layers().count() ) );
 } // VDocumentTab::updateDocumentInfo
 
@@ -300,10 +303,18 @@ VDocumentTab::slotCommandExecuted()
  *  Layers tab                                                           *
  *************************************************************************/
 
-VObjectListViewItem::VObjectListViewItem( QListViewItem* parent, VObject* object, VDocument *doc, uint key )
-	: QListViewItem( parent, 0L ), m_object( object ), m_document( doc ), m_key( key )
+VObjectListViewItem::VObjectListViewItem( QListViewItem* parent, VObject* object, VDocument *doc, uint key, QPtrDict<VObjectListViewItem> *map )
+	: QListViewItem( parent, 0L ), m_object( object ), m_document( doc ), m_key( key ), m_map( map )
 {
 	update();
+	// add itself to object list item map
+	m_map->insert( object, this );
+}
+
+VObjectListViewItem::~VObjectListViewItem() 
+{
+	// remove itself from object list item map
+	m_map->take( m_object );
 }
 
 QString
@@ -345,19 +356,27 @@ VObjectListViewItem::update()
 
 	// set thumb preview, lock and visible pixmaps
 	setPixmap( 0, preview );
-	QString s = ( m_object->state() == VObject::normal_locked || m_object->state() == VObject::hidden_locked ) ? "locked.png" : "unlocked.png";
+	QString s = ( m_object->state() == VObject::normal_locked || m_object->state() == VObject::hidden_locked ) ? "locked" : "unlocked";
 	setPixmap( 1, *KarbonFactory::rServer()->cachePixmap( s, KIcon::Small ) );
-	s = ( m_object->state() == VObject::hidden || m_object->state() == VObject::hidden_locked ) ? "14_layer_novisible.png" : "14_layer_visible.png";
+	s = ( m_object->state() == VObject::hidden || m_object->state() == VObject::hidden_locked ) ? "14_layer_novisible" : "14_layer_visible";
 	setPixmap( 2, *KarbonFactory::rServer()->cachePixmap( s, KIcon::Small ) );
 }
 
 
-VLayerListViewItem::VLayerListViewItem( QListView* parent, VLayer* layer, VDocument *doc )
-	: QCheckListItem( parent, 0L, CheckBox ), m_layer( layer ), m_document( doc)
+VLayerListViewItem::VLayerListViewItem( QListView* parent, VLayer* layer, VDocument *doc, QPtrDict<VLayerListViewItem> *map )
+	: QCheckListItem( parent, 0L, CheckBox ), m_layer( layer ), m_document( doc), m_map( map )
 {
 	update();
+	// add itself to layer list item map
+	m_map->insert( layer, this );
 } // VLayerListViewItem::VLayerListViewItem
 
+VLayerListViewItem::~VLayerListViewItem()
+{
+	// remove itself from layer list item map
+	m_map->take( m_layer );
+}
+
 void
 VLayerListViewItem::update()
 {
@@ -387,9 +406,9 @@ VLayerListViewItem::update()
 
 	// set thumb preview, lock and visible pixmaps
 	setPixmap( 0, preview );
-	QString s = ( m_layer->state() == VObject::normal_locked || m_layer->state() == VObject::hidden_locked ) ? "locked.png" : "unlocked.png";
+	QString s = ( m_layer->state() == VObject::normal_locked || m_layer->state() == VObject::hidden_locked ) ? "locked" : "unlocked";
 	setPixmap( 1, *KarbonFactory::rServer()->cachePixmap( s, KIcon::Small ) );
-	s = ( m_layer->state() == VObject::normal || m_layer->state() == VObject::normal_locked ) ? "14_layer_visible.png" : "14_layer_novisible.png";
+	s = ( m_layer->state() == VObject::normal || m_layer->state() == VObject::normal_locked ) ? "14_layer_visible" : "14_layer_novisible";
 	setPixmap( 2, *KarbonFactory::rServer()->cachePixmap( s, KIcon::Small ) );
 } // VLayerListViewItem::update
 
@@ -409,6 +428,12 @@ VLayerListViewItem::pos()
 		return 1 + item->pos();
 } // VLayerListViewItem::pos
 
+QString
+VLayerListViewItem::key( int, bool ) const
+{
+	return QString( "%1" ).arg( m_key );
+}
+
 VLayersTab::VLayersTab( KarbonView* view, QWidget* parent )
 		: QWidget( parent, "LayersTab" ), m_view( view ), m_document( &view->part()->document() )
 {
@@ -419,19 +444,19 @@ VLayersTab::VLayersTab( KarbonView* view, QWidget* parent )
 	m_buttonGroup = new QHButtonGroup( this );
 	m_buttonGroup->setInsideMargin( 3 );
 	button = new QToolButton( m_buttonGroup );
-	button->setIconSet( SmallIcon( "14_layer_newlayer.png" ) );
+	button->setIconSet( SmallIcon( "14_layer_newlayer" ) );
 	button->setTextLabel( i18n( "New" ) );
 	m_buttonGroup->insert( button );
 	button = new QToolButton( m_buttonGroup );
-	button->setIconSet( SmallIcon( "14_layer_raiselayer.png" ) );
+	button->setIconSet( SmallIcon( "14_layer_raiselayer" ) );
 	button->setTextLabel( i18n( "Raise" ) );
 	m_buttonGroup->insert( button );
 	button = new QToolButton( m_buttonGroup );
-	button->setIconSet( SmallIcon( "14_layer_lowerlayer.png" ) );
+	button->setIconSet( SmallIcon( "14_layer_lowerlayer" ) );
 	button->setTextLabel( i18n( "Lower" ) );
 	m_buttonGroup->insert( button );
 	button = new QToolButton( m_buttonGroup );
-	button->setIconSet( SmallIcon( "14_layer_deletelayer.png" ) );
+	button->setIconSet( SmallIcon( "14_layer_deletelayer" ) );
 	button->setTextLabel( i18n( "Delete" ) );
 	m_buttonGroup->insert( button );
 	layout->addWidget( m_buttonGroup, 1);
@@ -446,13 +471,16 @@ VLayersTab::VLayersTab( KarbonView* view, QWidget* parent )
 	m_layersListView->setColumnAlignment( 1, Qt::AlignCenter );
 	m_layersListView->setColumnAlignment( 2, Qt::AlignCenter );
 	m_layersListView->setResizeMode( QListView::NoColumn );
-	//m_layersListView->setSorting( 0, false );
+	m_layersListView->setSorting( 0, false );
 	m_layersListView->setRootIsDecorated( true );
+	m_layersListView->setSelectionMode( QListView::Extended );
 
-	connect( m_layersListView, SIGNAL( clicked( QListViewItem*, const QPoint&, int ) ), this, SLOT( selectionChanged( QListViewItem*, const QPoint&, int ) ) );
+	connect( m_layersListView, SIGNAL( clicked( QListViewItem*, const QPoint&, int ) ), this, SLOT( itemClicked( QListViewItem*, const QPoint&, int ) ) );
 	connect( m_layersListView, SIGNAL( rightButtonClicked( QListViewItem*, const QPoint&, int ) ), this, SLOT( renameItem( QListViewItem*, const QPoint&, int ) ) );
-	connect( m_view, SIGNAL( selectionChange() ), this, SLOT( slotSelectionChanged() ) );
+	connect( m_layersListView, SIGNAL( selectionChanged() ), this, SLOT( selectionChangedFromList() ) );
+	connect( m_view, SIGNAL( selectionChange() ), this, SLOT( selectionChangedFromTool() ) );
 	connect( m_buttonGroup, SIGNAL( clicked( int ) ), this, SLOT( slotButtonClicked( int ) ) );
+	connect( view->part()->commandHistory(), SIGNAL( commandExecuted( VCommand*) ), this, SLOT( slotCommandExecuted( VCommand* ) ) );
 
 	layout->activate();
 	updateLayers();
@@ -478,99 +506,232 @@ VLayersTab::slotButtonClicked( int ID )
 	}
 } // VLayersTab::slotButtonClicked
 
-void
-VLayersTab::slotSelectionChanged()
+void 
+VLayersTab::resetSelection()
 {
-	// TODO : use some kind of mapping...
-	m_layersListView->clearSelection();
-	VObjectListIterator itr = m_document->selection()->objects();
-	for( ; itr.current();++itr )
-		if( itr.current()->state() != VObject::deleted )
-		{
-			QListViewItemIterator it( m_layersListView );
-			bool found = false;
-			while( !found && dynamic_cast<VObjectListViewItem *>( it.current() ) )
-			{
-				if( dynamic_cast<VObjectListViewItem *>( it.current() ) &&
-					dynamic_cast<VObjectListViewItem *>( it.current() )->object() == itr.current() )
-				{
-					m_layersListView->setSelected( it.current(), true );
-					found = true;
-				}
-				++it;
-			}
-			// not found, insert
-			if( !found )
-			{
-				VLayerListViewItem *layerItem = dynamic_cast<VLayerListViewItem *>( m_layers[ m_document->activeLayer() ] );
-				if( layerItem && !m_objects[ itr.current() ] )
-					m_objects.insert( itr.current(), new VObjectListViewItem( layerItem, itr.current(), m_document, layerItem->childCount() ) );
-			}
+	QListViewItemIterator it( m_layersListView );
 
-		}
+	// iterates over all list items and deselects them manually
+	// to avoid the list views selectionChanged signal
+	for(; it.current(); ++it )
+	{
+		it.current()->setSelected( false );
+		it.current()->repaint();
+	}
+}
+
+void 
+VLayersTab::selectActiveLayer()
+{
+	if( ! m_layers[ m_document->activeLayer() ] )
+	{
+		QPtrVector<VLayer> vector;
+		m_document->layers().toVector( &vector );
+		// find another layer to set active
+		for( int i = vector.count() - 1; i >= 0; i-- )
+			if ( vector[i]->state() != VObject::deleted )
+			{
+				m_document->setActiveLayer( vector[i] );
+				break;
+			}
+	}
+
+	// deselect all other layers
+	QPtrDictIterator<VLayerListViewItem> it( m_layers );
+	for(; it.current(); ++it )
+	{
+		it.current()->setSelected( false );
+		it.current()->repaint();
+	}
+
+	VLayerListViewItem *layerItem = m_layers[ m_document->activeLayer() ];
+	if( layerItem )
+	{
+		layerItem->setSelected( true );
+		layerItem->repaint();
+		kdDebug(38000) << "selecting active layer: " << layerItem->text() << endl;
+	}
 }
 
 void
-VLayersTab::selectionChanged( QListViewItem* item, const QPoint &, int col )
+VLayersTab::selectionChangedFromTool()
+{
+	resetSelection();
+	removeDeletedObjectsFromList();
+
+	// TODO : use some kind of mapping...
+	VObjectListIterator itr = m_document->selection()->objects();
+	for( ; itr.current(); ++itr )
+		if( itr.current()->state() != VObject::deleted )
+		{
+			VObject *obj = itr.current();
+
+			VObjectListViewItem *item = m_objects[ obj ];
+			if( ! item ) 
+			{
+				VLayerListViewItem *layerItem = m_layers[ obj->parent() ];
+				if( layerItem )
+					updateObjects( layerItem->layer(), layerItem );
+				else
+				{
+					VObjectListViewItem *objectItem = m_objects[ obj->parent() ];
+					if( objectItem )
+						updateObjects( objectItem->object(), objectItem );
+					else
+						continue;
+				}
+				item = m_objects[ obj ];
+			}
+			if( ! item ) continue;
+
+			item->setSelected( true );
+			item->update();
+		}
+	selectActiveLayer();	
+}
+
+void 
+VLayersTab::updateChildItems( QListViewItem *item )
+{
+	QListViewItemIterator it( item );
+
+	// iterator points to item, so make the next item current first
+	for( ++it; it.current(); ++it )
+	{
+		VObjectListViewItem *objectItem = dynamic_cast<VObjectListViewItem *>( it.current() );
+		if( ! objectItem ) continue;
+		
+		if( dynamic_cast<VGroup*>( objectItem->object() ) )
+			updateChildItems( objectItem );
+
+		objectItem->update();
+		objectItem->repaint();
+	}
+}
+
+void 
+VLayersTab::toggleState( VObject *obj, int col )
+{
+	switch( col )
+	{
+		case 1: // toggle visibility
+			if( obj->state() == VObject::hidden_locked )
+				obj->setState( VObject::hidden );
+			else if( obj->state() == VObject::normal_locked )
+				obj->setState( VObject::selected );
+			else if( obj->state() == VObject::normal || obj->state() >= VObject::selected )
+				obj->setState( VObject::normal_locked );
+			else if( obj->state() == VObject::hidden )
+				obj->setState( VObject::hidden_locked );
+		break;
+		case 2: // toggle locking
+			if( obj->state() == VObject::hidden_locked )
+				obj->setState( VObject::normal_locked );
+			else if( obj->state() == VObject::normal_locked )
+				obj->setState( VObject::hidden_locked );
+			else if( obj->state() == VObject::normal || obj->state() >= VObject::selected )
+				obj->setState( VObject::hidden );
+			else if( obj->state() == VObject::hidden )
+				obj->setState( VObject::selected );
+		break;
+		default: return;
+	}
+
+	if( obj->state() < VObject::selected )
+		m_document->selection()->take( *obj );
+	else
+		m_document->selection()->append( obj );
+}
+
+void
+VLayersTab::itemClicked( QListViewItem* item, const QPoint &, int col )
 {
 	if( item )
 	{
 		VLayerListViewItem *layerItem = dynamic_cast<VLayerListViewItem *>( item );
 		if( layerItem )
 		{
-			VLayer *obj = layerItem->layer();
-			m_document->setActiveLayer( layerItem->layer() );
-			m_document->selection()->clear();
-
+			if( col == 0 )
+			{
+				m_document->setActiveLayer( layerItem->layer() );
+				selectActiveLayer();
+			}
 			if( col > 0 )
 			{
-				if( col == 2 )
-					obj->setState( obj->state() == VObject::normal || obj->state() == VObject::normal_locked ? VObject::hidden : VObject::normal );
-				else
-					if( obj->state() == VObject::hidden_locked )
-						obj->setState( VObject::hidden );
-					else if( obj->state() == VObject::normal_locked )
-						obj->setState( VObject::normal );
-					else if( obj->state() == VObject::normal )
-						obj->setState( VObject::normal_locked );
-					else if( obj->state() == VObject::hidden )
-						obj->setState( VObject::hidden_locked );
+				toggleState( layerItem->layer(), col );
+
 				layerItem->update();
+				layerItem->repaint();
+
+				updateChildItems( layerItem );
+
 				m_view->part()->repaintAllViews();
 			}
 		}
 		else
 		{
-			VObjectListViewItem *objectItem = dynamic_cast< VObjectListViewItem *>( m_layersListView->selectedItem() );
-			VObject *obj = objectItem->object();
+			VObjectListViewItem *objectItem = dynamic_cast< VObjectListViewItem *>( item );
 
-			if( col > 0 ) // set visibility
+			if( col == 0 )
 			{
-				if( col == 2 )
-					obj->setState( obj->state() == VObject::hidden ? VObject::normal : VObject::hidden );
-				else
-					if( obj->state() == VObject::hidden_locked )
-						obj->setState( VObject::hidden );
-					else if( obj->state() == VObject::normal_locked )
-						obj->setState( VObject::normal );
-					else if( obj->state() == VObject::normal || obj->state() >= VObject::selected )
-						obj->setState( VObject::normal_locked );
-					else if( obj->state() == VObject::hidden )
-						obj->setState( VObject::hidden_locked );
-				objectItem->update();
-				m_document->selection()->take( *obj );
-				m_view->part()->repaintAllViews();
+				VObject *obj = objectItem->object();
+				if( obj->state() == VObject::normal )
+					obj->setState( VObject::selected );
 			}
-			else if( obj->state() == VObject::normal ||
-					 obj->state() >= VObject::selected ) // select only visible and unlocked objects
+			if( col > 0 ) 
 			{
-				m_document->selection()->clear();
-				m_document->selection()->append( obj );
+				toggleState( objectItem->object(), col );
+				
+				if( objectItem->object()->state() == VObject::selected )
+					objectItem->setSelected( true );
+				else
+					objectItem->setSelected( false );
+
+				objectItem->update();
+				objectItem->repaint();
+
+				if( dynamic_cast<VGroup*>( objectItem->object() ) )
+					updateChildItems( objectItem );
+
 				m_view->part()->repaintAllViews();
 			}
 		}
 	}
-} // VLayersTab::selectionChanged
+} // VLayersTab::itemClicked
+
+void
+VLayersTab::selectionChangedFromList()
+{
+	m_document->selection()->clear();
+
+	QListViewItemIterator it( m_layersListView );
+
+	// iterate over all list items and add their corresponding object 
+	// to the documents selection if the list item is selected and not hidden or locked or both
+	for(; it.current(); ++it )
+	{
+		VObjectListViewItem *objectItem = dynamic_cast<VObjectListViewItem *>( it.current() );
+		if( ! objectItem ) continue;
+
+		VObject::VState state = objectItem->object()->state();
+		
+		if( state == VObject::deleted ) 
+		{
+			delete objectItem;
+			continue;
+		}
+
+		if( objectItem->isSelected() && (state != VObject::hidden) && (state != VObject::normal_locked ) 
+		&& (state != VObject::hidden_locked) )
+		{
+			m_document->selection()->append( objectItem->object() );
+			objectItem->repaint();
+		}
+	}
+	
+	m_view->selectionChanged();
+	m_view->part()->repaintAllViews();
+}
 
 void
 VLayersTab::renameItem( QListViewItem* item, const QPoint&, int col )
@@ -578,13 +739,13 @@ VLayersTab::renameItem( QListViewItem* item, const QPoint&, int col )
 	if ( ( item ) && col == 0 )
 	{
 		bool ok = true;
-		VLayerListViewItem* layerItem = dynamic_cast<VLayerListViewItem *>( m_layersListView->selectedItem() );
+		VLayerListViewItem* layerItem = dynamic_cast<VLayerListViewItem *>( item );
 		if( !layerItem )
 		{
-			VObjectListViewItem *objectItem = dynamic_cast< VObjectListViewItem *>( m_layersListView->selectedItem() );
+			VObjectListViewItem *objectItem = dynamic_cast< VObjectListViewItem *>( item );
 			VObject *obj = objectItem->object();
-			QString name = KLineEditDlg::getText( i18n( "Current Object" ), i18n( "Change the name of the object:" ),
-																	obj->name(), &ok, this );
+			QString name = KInputDialog::getText( i18n( "Current Object" ), i18n( "Change the name of the object:" ),
+												  obj->name(), &ok, this );
 			if( ok )
 			{
 				m_document->setObjectName( obj, name );
@@ -593,8 +754,8 @@ VLayersTab::renameItem( QListViewItem* item, const QPoint&, int col )
 		}
 		else
 		{
-			QString name = KLineEditDlg::getText( i18n( "Rename Layer" ), i18n( "Change the name of the current layer:" ),
-																	layerItem->layer()->name(), &ok, this );
+			QString name = KInputDialog::getText( i18n( "Rename Layer" ), i18n( "Change the name of the current layer:" ),
+												  layerItem->layer()->name(), &ok, this );
 			if( ok )
 			{
 				layerItem->layer()->setName( name );
@@ -608,8 +769,8 @@ void
 VLayersTab::addLayer()
 {
 	bool ok = true;
-	QString name = KLineEditDlg::getText( i18n( "New Layer" ), i18n( "Enter the name of the new layer:" ),
-	                             i18n( "New layer" ), &ok, this );
+	QString name = KInputDialog::getText( i18n( "New Layer" ), i18n( "Enter the name of the new layer:" ),
+										  i18n( "New layer" ), &ok, this );
 	if( ok )
 	{
 		VLayer* layer = new VLayer( m_document );
@@ -626,83 +787,135 @@ VLayersTab::raiseItem()
 {
 	VCommand *cmd = 0L;
 	//QListViewItem *newselection = 0L;
-	VLayerListViewItem* layerItem = dynamic_cast<VLayerListViewItem *>( m_layersListView->selectedItem() );
-	if( layerItem )
+	QListViewItemIterator it( m_layersListView );
+ 
+	for(; it.current(); ++it )
 	{
-		VLayer *layer = layerItem->layer();
-		if( layer && m_document->canRaiseLayer( layer ) )
+		if( ! it.current()->isSelected() ) continue;
+ 
+		VLayerListViewItem* layerItem = dynamic_cast<VLayerListViewItem *>( it.current() );
+		if( layerItem )
 		{
-			cmd = new VLayerCmd( m_document, i18n( "Raise Layer" ),
-			                                layerItem->layer(), VLayerCmd::raiseLayer );
-			//newselection = layerItem;
+			VLayer *layer = layerItem->layer();
+			if( layer && m_document->canRaiseLayer( layer ) )
+			{
+				cmd = new VLayerCmd( m_document, i18n( "Raise Layer" ),
+								layerItem->layer(), VLayerCmd::raiseLayer );
+				//newselection = layerItem;
+			}
+		}
+		else
+		{
+			VObjectListViewItem* item = dynamic_cast< VObjectListViewItem *>( it.current() );
+			if( item )
+			{
+				cmd = new VZOrderCmd( m_document, item->object(), VZOrderCmd::up );
+				//newselection = item;
+			}
+		}
+		if( cmd )
+		{	
+			m_view->part()->addCommand( cmd, true );
+			//if( newselection )
+			//	m_layersListView->setSelected( newselection, true );
 		}
 	}
-	else
-	{
-		VObjectListViewItem* item = dynamic_cast< VObjectListViewItem *>( m_layersListView->selectedItem() );
-		if( item )
-		{
-			cmd = new VZOrderCmd( m_document, item->object(), VZOrderCmd::up );
-			//newselection = item;
-		}
-	}
-	if( cmd )
-	{
-		m_view->part()->addCommand( cmd, true );
-		updatePreviews();
-		//if( newselection )
-		//	m_layersListView->setSelected( newselection, true );
-	}
+	if( cmd ) updatePreviews();
 } // VLayersTab::raiseItem
 
 void
 VLayersTab::lowerItem()
 {
 	VCommand *cmd = 0L;
-	VLayerListViewItem* layerItem = dynamic_cast<VLayerListViewItem *>( m_layersListView->selectedItem() );
-	if( layerItem )
+	QListViewItemIterator it( m_layersListView );
+
+	for(; it.current(); ++it )
 	{
-		VLayer *layer = layerItem->layer();
-		if( layer && m_document->canLowerLayer( layer ) )
-			cmd = new VLayerCmd( m_document, i18n( "Lower Layer" ), layer, VLayerCmd::lowerLayer );
-	}
-	else
-	{
-		VObjectListViewItem* item = dynamic_cast< VObjectListViewItem *>( m_layersListView->selectedItem() );
-		if( item )
-			cmd = new VZOrderCmd( m_document, item->object(), VZOrderCmd::down );
-	}
-	if( cmd )
-	{
-		m_view->part()->addCommand( cmd, true );
-		updatePreviews();
+		if( ! it.current()->isSelected() ) continue;
+		
+		VLayerListViewItem* layerItem = dynamic_cast<VLayerListViewItem *>( it.current() );
+		if( layerItem )
+		{
+			VLayer *layer = layerItem->layer();
+			if( layer && m_document->canLowerLayer( layer ) )
+				cmd = new VLayerCmd( m_document, i18n( "Lower Layer" ), layer, VLayerCmd::lowerLayer );
+		}
+		else
+		{
+			VObjectListViewItem* item = dynamic_cast< VObjectListViewItem *>( it.current() );
+			if( item )
+				cmd = new VZOrderCmd( m_document, item->object(), VZOrderCmd::down );
+		}
+		if( cmd )
+		{
+			m_view->part()->addCommand( cmd, true );
+		}
 	}
+	if( cmd ) updatePreviews();
 } // VLayersTab::lowerItem
 
 void
 VLayersTab::deleteItem()
 {
 	VCommand *cmd = 0L;
-	VLayerListViewItem* layerItem = dynamic_cast< VLayerListViewItem *>( m_layersListView->selectedItem() );
-	if( layerItem )
+	QListViewItemIterator it( m_layersListView );
+
+	QPtrList<QListViewItem> deleteItems;
+	deleteItems.setAutoDelete( false );
+
+	// collect all selected items because they get deselected
+	// when the first item is removed
+	for(; it.current(); ++it )
 	{
-		VLayer *layer = layerItem->layer();
-		if( layer )
-		{
-			cmd = new VLayerCmd( m_document, i18n( "Delete Layer" ), layer, VLayerCmd::deleteLayer );
-			m_view->part()->addCommand( cmd, true );
-			delete layerItem;
-		}
+		if( ! it.current()->isSelected() ) continue;
+			deleteItems.append( it.current() );
 	}
-	else
+	
+	for( ;deleteItems.first(); )
 	{
-		VObjectListViewItem* item = dynamic_cast< VObjectListViewItem *>( m_layersListView->selectedItem() );
-		if( item )
+		VLayerListViewItem* layerItem = dynamic_cast< VLayerListViewItem *>( deleteItems.current() );
+		if( layerItem )
 		{
-			cmd = new VDeleteCmd( m_document, item->object() );
-			m_view->part()->addCommand( cmd, true );
-			delete item;
+			VLayer *layer = layerItem->layer();
+			if( layer && m_layers.count() > 1 )
+			{
+				cmd = new VLayerCmd( m_document, i18n( "Delete Layer" ), layer, VLayerCmd::deleteLayer );
+
+				VObjectListIterator itr = layer->objects();
+				// iterate over this layers child objects and remove them from the internal 
+				// object list and the list of the to be deleted items
+				for( ; itr.current(); ++itr )
+				{
+					VObjectListViewItem *objectItem = m_objects.take( itr.current() );
+					deleteItems.remove( objectItem );
+				}
+				
+				delete layerItem;
+
+				m_view->part()->addCommand( cmd );
+				
+				selectActiveLayer();
+			}
 		}
+		else
+		{
+			VObjectListViewItem* item = dynamic_cast< VObjectListViewItem *>( deleteItems.current() );
+			if( item )
+			{
+				cmd = new VDeleteCmd( m_document, item->object() );
+				
+				delete item;
+
+				m_view->part()->addCommand( cmd );
+			}
+		}
+		// remove first item, next item becomes current
+		deleteItems.removeFirst();
+	}
+	if( cmd ) 
+	{
+		updatePreviews();
+		m_view->part()->repaintAllViews();
 	}
 } // VLayersTab::deleteItem
 
@@ -716,62 +929,142 @@ VLayersTab::updatePreviews()
 void
 VLayersTab::updateLayers()
 {
+	removeDeletedObjectsFromList();	
+
 	QPtrVector<VLayer> vector;
 	m_document->layers().toVector( &vector );
-	VLayerListViewItem* item;
+	VLayerListViewItem* item = 0L;
 	for( int i = vector.count() - 1; i >= 0; i-- )
 	{
 		if ( vector[i]->state() != VObject::deleted )
 		{
 			if( !m_layers[ vector[i] ] )
-				m_layers.insert( vector[i], new VLayerListViewItem( m_layersListView, vector[i], m_document ) );
-			item = m_layers[ vector[i] ];
+			{
+				item = new VLayerListViewItem( m_layersListView, vector[i], m_document, &m_layers );
+				item->setOpen( true );
+			}
+			else 
+				item = m_layers[ vector[i] ];
 
-			item->setOpen( true );
-			VObjectListIterator itr = vector[i]->objects();
-			uint objcount = 1;
-			for( ; itr.current();++itr, objcount++ )
-				if( itr.current()->state() != VObject::deleted )
-				{
-					if( !m_objects[ itr.current() ] )
-						m_objects.insert( itr.current(), new VObjectListViewItem( item, itr.current(), m_document, objcount ) );
-					else
-						m_objects[ itr.current() ]->setKey( objcount );
+			item->setKey(i);
 
-					//kdDebug(38000) << "obj : " << itr.current() << ", key : " << m_objects[ itr.current() ]->key( 0, true ).latin1() << endl;
-
-					if( dynamic_cast<VGroup *>( itr.current() ) )
-						updateObjects( itr.current(),  m_objects[ itr.current() ] );
-				}
-
-			item->sort();
+			updateObjects( vector[i], item );
 		}
 	}
+
+	selectActiveLayer();
 	m_layersListView->sort();
 } // VLayersTab::updateLayers
 
 void
 VLayersTab::updateObjects( VObject *object, QListViewItem *item )
 {
-	uint objcount = 1;
 	VObjectListIterator itr = dynamic_cast<VGroup *>( object )->objects();
-	for( ; itr.current();++itr, objcount++ )
+
+	for( uint objcount = 1; itr.current(); ++itr, objcount++ )
 		if( itr.current()->state() != VObject::deleted )
 		{
-			if( !m_objects[ itr.current() ] )
-				m_objects.insert( itr.current(), new VObjectListViewItem( item, itr.current(), m_document, objcount ) );
-			else
+			VObjectListViewItem *objectItem = m_objects[ itr.current() ];
+			if( ! objectItem )
 			{
-				delete m_objects[ itr.current() ];
-				m_objects.insert( itr.current(), new VObjectListViewItem( item, itr.current(), m_document, objcount ) );
-				m_objects[ itr.current() ]->setKey( objcount );
+				// object not found -> insert
+				objectItem = new VObjectListViewItem( item, itr.current(), m_document, objcount, &m_objects );
+				objectItem->update();
+			}
+			else if( objectItem->parent() != item )
+			{
+				// object found, but has false parent -> reparent
+				objectItem->parent()->takeItem( objectItem );
+				item->insertItem( objectItem );
 			}
 
+			objectItem->setKey( objcount );
+
 			if( dynamic_cast<VGroup *>( itr.current() ) )
-				updateObjects( itr.current(), m_objects[ itr.current() ] );
+				updateObjects( itr.current(), objectItem );
+		}
+}
+
+void
+VLayersTab::removeDeletedObjectsFromList()
+{
+	QPtrDictIterator<VObjectListViewItem> it( m_objects );
+
+	// iterate over all object items and delete the following items:
+	// - items representing deleted objects
+	// - items with objects objects that changed parents
+	// BEWARE: when deleting an item, the iterator is automatically incremented
+	for(; it.current(); )
+	{
+		VLayerListViewItem *layerItem = dynamic_cast<VLayerListViewItem*>( it.current()->parent() );
+		if( layerItem )
+		{
+			VGroup *group = dynamic_cast<VGroup*>( layerItem->layer() );
+			// check if object of item is still child of object of parent item
+			if( group && ! group->objects().contains( it.current()->object() ) )
+			{
+				layerItem->takeItem( it.current() );
+				delete it.current();
+				continue;
+			}
+		}
+		else
+		{
+			VObjectListViewItem *objectItem = dynamic_cast<VObjectListViewItem*>( it.current()->parent() );
+			if( objectItem ) 
+			{
+				VGroup *group = dynamic_cast<VGroup*>( objectItem->object() );
+				// check if object of item is still child of object of parent item
+				if( group && ! group->objects().contains( it.current()->object() ) )
+				{
+					objectItem->takeItem( it.current() );
+					delete it.current();
+					continue;
+				}
+			}
+			else
+			{
+				delete it.current();
+				continue;
+			}
 		}
 
-	item->sort();
+		if( it.current()->object()->state() == VObject::deleted )
+		{
+			delete it.current();
+			continue;
+		}
+
+		++it;
+	}
+
+	QPtrDictIterator<VLayerListViewItem> itr( m_layers );
+
+	// iterate over all layer items and delete the following items:
+	// - items representing deleted layers
+	// BEWARE: when deleting an item, the iterator is automatically incremented
+	for(; itr.current(); )
+	{
+		if( itr.current()->layer()->state() == VObject::deleted )
+		{
+			m_layersListView->takeItem( itr.current() );
+			delete itr.current();
+			continue;
+		}
+		++itr;
+	}
+}
+
+
+void 
+VLayersTab::slotCommandExecuted( VCommand* command )
+{
+	// sync listview on changing layers or deleting/undeleting or grouping/ungrouping objects
+	if( dynamic_cast<VLayerCmd*>( command ) 
+	|| dynamic_cast<VDeleteCmd*>( command ) 
+	|| dynamic_cast<VGroupCmd*>( command ) 
+	|| dynamic_cast<VUnGroupCmd*>( command ) )
+		updateLayers();
 }
 
 /*************************************************************************
@@ -830,6 +1123,14 @@ VHistoryGroupItem::paintCell( QPainter* p, const QColorGroup& cg, int column, in
 	p->drawText( xstart, 0, width - xstart, height(), align | Qt::AlignVCenter, text( column ) );
 } // VHistoryGroupItem::paintCell
 
+void
+VHistoryGroupItem::paintFocus( QPainter*, const QColorGroup&, const QRect& )
+{
+	// Do not paint any focus rectangle
+	// It makes the list and the selected item look messy
+
+} // VHistoryGroupItem::paintFocus
+
 VHistoryItem::VHistoryItem( VCommand* command, QListView* parent, QListViewItem* after )
 		: QListViewItem( parent, after ), m_command( command )
 {
@@ -860,7 +1161,7 @@ VHistoryItem::~VHistoryItem()
 void
 VHistoryItem::paintCell( QPainter* p, const QColorGroup& cg, int column, int width, int align )
 {
-	p->fillRect( 0, 0, width - 1, height() - 1, ( m_command->success() ? cg.base() : cg.base().dark( 140 ) ) );
+	p->fillRect( 0, 0, width, height(), ( m_command->success() ? cg.base() : cg.base().dark( 140 ) ) );
 
 	const QPixmap* pixmap = this->pixmap( column );
 	int xstart;
@@ -877,6 +1178,14 @@ VHistoryItem::paintCell( QPainter* p, const QColorGroup& cg, int column, int wid
 	p->drawText( xstart, 0, width - xstart, height(), align | Qt::AlignVCenter, text( column ) );
 } // VHistoryItem::paintCell
 
+void
+VHistoryItem::paintFocus( QPainter*, const QColorGroup&, const QRect& )
+{
+	// Do not paint any focus rectangle
+	// It makes the list and the selected item look messy
+
+} // VHistoryItem::paintFocus
+
 VHistoryTab::VHistoryTab( KarbonPart* part, QWidget* parent )
 		: QWidget( parent ), m_part( part )
 {
