@@ -21,7 +21,7 @@
 #ifndef __VTRANSFORMDOCKER_H__
 #define __VTRANSFORMDOCKER_H__
 
-#include <vdocker.h>
+#include "vdocker.h"
 
 class KarbonPart;
 class KarbonView;
@@ -38,7 +38,8 @@ public slots:
 	void update();
 
 private slots:
-	void transform();
+	void translate();
+	void scale();
 
 private:
 	KarbonPart *m_part;
