@@ -12,7 +12,7 @@ KAboutData * newKarbonAboutData()
 	KAboutData * aboutData = new KAboutData(
 		"karbon",
 		I18N_NOOP( "Karbon14" ),
-		"0.1",
+		"0.2",
 		I18N_NOOP( "Yet another vector graphics application." ),
 		KAboutData::License_GPL,
 		I18N_NOOP( "(c) 2001-2005, The Karbon Developers" ),
@@ -33,6 +33,11 @@ KAboutData * newKarbonAboutData()
 		0,
 		"benoit.vautrin@free.fr",
 		0 );
+	aboutData->addCredit(
+		"Inge Wallin",
+		I18N_NOOP( "Bug fixes" ),
+		"inge@lysator.liu.se",
+		0 );
 	// TODO: add the names of some helpful souls
         return aboutData;
 }
