@@ -24,9 +24,13 @@
 #include <qwidget.h>
 #include <knuminput.h>
 
-class KChartParams;
 class QCheckBox;
 
+namespace KChart
+{
+
+class KChartParams;
+
 class KChartParameter3dConfigPage : public QWidget
 {
     Q_OBJECT
@@ -36,13 +40,20 @@ public:
                                  QWidget* parent );
     void init();
     void apply();
+
 protected slots:
     void slotChange3DParameter(bool);
+
 private:
-    KChartParams* _params;
-    KIntNumInput* angle3d;
-    KDoubleNumInput* depth;
-    QCheckBox* bar3d, *drawShadowColor;
+    KChartParams     *m_params;
+
+    // Widgets
+    KIntNumInput     *angle3d;
+    KDoubleNumInput  *depth;
+    QCheckBox        *bar3d;
+    QCheckBox        *drawShadowColor;
 };
 
+}  //KChart namespace
+
 #endif
