@@ -22,13 +22,21 @@
 #include <klocale.h>
 #include "kchart_aboutdata.h"
 
+using namespace KChart;
+
+namespace KChart
+{
+
 static const KCmdLineOptions options[]=
 {
 	{"+[file]", I18N_NOOP("File to open"),0},
 	KCmdLineLastOption
 };
 
-int main( int argc, char **argv )
+}  //namespace KChart
+
+
+extern "C" KCHART_EXPORT int kdemain( int argc, char **argv )
 {
     KCmdLineArgs::init( argc, argv, newKChartAboutData());
     KCmdLineArgs::addCmdLineOptions( options );
