@@ -22,7 +22,6 @@
 #include "kivio_map.h"
 #include "kivio_view.h"
 #include "kivio_doc.h"
-#include "kivio_tabbar.h"
 
 #include "kivio_icon_view.h"
 #include "kivio_stencil.h"
@@ -32,8 +31,7 @@
 #include "kivio_screen_painter.h"
 #include "kivio_grid_data.h"
 
-#include "tool_controller.h"
-#include "tool.h"
+#include "kivio_pluginmanager.h"
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -43,6 +41,9 @@
 #include <kozoomhandler.h>
 #include <koSize.h>
 #include <koRuler.h>
+#include <koPoint.h>
+#include <kotabbar.h>
+#include <kapplication.h>
 
 #include <assert.h>
 #include <stdio.h>
@@ -54,11 +55,10 @@
 
 using namespace Kivio;
 
-KivioCanvas::KivioCanvas( QWidget *par, KivioView* view, KivioDoc* doc, ToolController* tc, QScrollBar* vs, QScrollBar* hs)
+KivioCanvas::KivioCanvas( QWidget *par, KivioView* view, KivioDoc* doc, QScrollBar* vs, QScrollBar* hs)
 : QWidget(par, "KivioCanvas", WResizeNoErase | WRepaintNoErase),
   m_pView(view),
   m_pDoc(doc),
-  m_pToolsController(tc),
   m_pVertScrollBar(vs),
   m_pHorzScrollBar(hs)
 {
@@ -187,22 +187,26 @@ void KivioCanvas::resizeEvent( QResizeEvent* )
 void KivioCanvas::wheelEvent( QWheelEvent* ev )
 {
   ev->accept();
-/*
-  QPoint p = ev->pos();
-  if ((ev->delta()<0)) {
-    zoomIn(p);
-  } else {
-    zoomOut(p);
-  }
-*/
-  //QPoint p = ev->pos();
+  
   if( (ev->delta()>0))
   {
-     m_pVertScrollBar->setValue(m_pVertScrollBar->value() - 30);
+     if(ev->state() == ControlButton) {
+       zoomIn(ev->pos());
+     } else if(ev->state() == ShiftButton) {
+       m_pVertScrollBar->setValue(m_pVertScrollBar->value() - height());
+     } else {
+       m_pVertScrollBar->setValue(m_pVertScrollBar->value() - 30);
+     }
   }
   else
   {
-     m_pVertScrollBar->setValue(m_pVertScrollBar->value() + 30);
+     if(ev->state() == ControlButton) {
+       zoomOut(ev->pos());
+     } else if(ev->state() == ShiftButton) {
+       m_pVertScrollBar->setValue(m_pVertScrollBar->value() + height());
+     } else {
+       m_pVertScrollBar->setValue(m_pVertScrollBar->value() + 30);
+     }
   }
 }
 
@@ -219,7 +223,6 @@ void KivioCanvas::setUpdatesEnabled( bool isUpdate )
 
       blockSignals(false);
 
-      emit zoomChanges();
       emit visibleAreaChanged();
     }
   } else {
@@ -232,7 +235,7 @@ void KivioCanvas::zoomIn(const QPoint &p)
 {
   setUpdatesEnabled(false);
   KoPoint p0 = mapFromScreen(p);
-  setZoom(m_pView->zoomHandler()->zoom() + 25);
+  m_pView->viewZoom(m_pView->zoomHandler()->zoom() + 25);
   QPoint p1 = mapToScreen(p0);
   scrollDx(-p1.x()+p.x());
   scrollDy(-p1.y()+p.y());
@@ -246,7 +249,7 @@ void KivioCanvas::zoomOut(const QPoint &p)
   int newZoom = m_pView->zoomHandler()->zoom() - 25;
 
   if(newZoom > 0) {
-    setZoom(newZoom);
+    m_pView->viewZoom(newZoom);
     QPoint p1 = mapToScreen(p0);
     scrollDx(-p1.x()+p.x());
     scrollDy(-p1.y()+p.y());
@@ -265,87 +268,60 @@ void KivioCanvas::paintEvent( QPaintEvent* ev )
   QPainter painter;
   painter.begin(m_buffer);
 
-  QRect rect( ev->rect() );
-  painter.fillRect(rect,white);
-
-  // Draw Grid
-  if (m_pDoc->grid().isShow) {
-    int x = rect.x();
-    int y = rect.y();
-    int w = x + rect.width();
-    int h = y + rect.height();
-
-    KoSize dxy = m_pDoc->grid().freq;
-
-    KoPoint p(0, 0);
-
-    painter.setPen(m_pDoc->grid().color);
-
-    QPoint p0 = mapToScreen(p);
-
-    while (p0.x() < x) {
-      p.rx() += dxy.width();
-      p0 = mapToScreen(p);
-    }
-
-    while (p0.x() <= w) {
-      painter.drawLine(p0.x(),y,p0.x(),h);
-
-      p.rx() += dxy.width();
-      p0 = mapToScreen(p);
-    }
-
-    p.setCoords(0, 0);
-    p0 = mapToScreen(p);
-
-    while (p0.x() > w) {
-      p.rx() -= dxy.width();
-      p0 = mapToScreen(p);
-    }
-
-    while (p0.x() >= x) {
-      painter.drawLine(p0.x(),y,p0.x(),h);
-
-      p.rx() -= dxy.width();
-      p0 = mapToScreen(p);
-    }
-
-    p.setCoords(0, 0);
-    p0 = mapToScreen(p);
-
-    while (p0.y() < y) {
-      p.ry() += dxy.height();
-      p0 = mapToScreen(p);
-    }
-
-    while (p0.y() <= h) {
-      painter.drawLine(x,p0.y(),w,p0.y());
-
-      p.ry() += dxy.height();
-      p0 = mapToScreen(p);
-    }
-
-    p.setCoords(0, 0);
-    p0 = mapToScreen(p);
-
-    while (p0.y() > h) {
-      p.ry() -= dxy.height();
-      p0 = mapToScreen(p);
-    }
-
-    while (p0.y() >= y) {
-      painter.drawLine(x,p0.y(),w,p0.y());
-
-      p.ry() -= dxy.height();
-      p0 = mapToScreen(p);
-    }
-  }
-
-  painter.translate(-m_iXOffset,-m_iYOffset);
-
   KoPageLayout pl = page->paperLayout();
   int pw = m_pView->zoomHandler()->zoomItX(pl.ptWidth);
   int ph = m_pView->zoomHandler()->zoomItY(pl.ptHeight);
+  QRect fillRect(0, 0, pw, ph);
+  QRect paintRect = ev->rect();
+  QRegion grayRegion(paintRect);
+  grayRegion.translate(m_iXOffset, m_iYOffset);
+  grayRegion -= fillRect;
+  grayRegion.translate(-m_iXOffset, -m_iYOffset);
+
+  // This code comes from KPresenter's kprcanvas.cpp
+  // Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
+  painter.save();
+  painter.setClipRegion(grayRegion, QPainter::CoordPainter);
+  painter.setPen(Qt::NoPen);
+  painter.fillRect(grayRegion.boundingRect(), KApplication::palette().active().brush(QColorGroup::Mid));
+  painter.restore();
+  // end of copy...
+
+  painter.translate(-m_iXOffset, -m_iYOffset);
+  painter.fillRect(fillRect, white);
+
+  // Draw Grid
+  if (m_pDoc->grid().isShow) {
+    int x = paintRect.x();
+    int y = paintRect.y();
+    int w = QMIN(x + paintRect.width() + m_iXOffset, pw);
+    int h = QMIN(y + paintRect.height() + m_iYOffset, ph);
+
+    QSize dxy = m_pView->zoomHandler()->zoomSize(m_pDoc->grid().freq);
+    
+    if(m_pView->zoomHandler()->zoom() >= 150) {
+      dxy = dxy / 2;
+    } else if(m_pView->zoomHandler()->zoom() <= 50) {
+      dxy = dxy * 2;
+    }
+    
+    painter.setPen(m_pDoc->grid().color);
+    
+    x = qRound(x / dxy.width()) * dxy.width();
+
+    while (x <= w) {
+      painter.drawLine(x, y, x, h);
+      x += dxy.width();
+    }
+
+    x = paintRect.x();
+    y = qRound(y / dxy.height()) * dxy.height();
+
+    while (y <= h) {
+      painter.drawLine(x, y, w, y);
+      y += dxy.height();
+    }
+  }
 
   if (m_pView->isShowPageMargins()) {
     int ml = m_pView->zoomHandler()->zoomItX(pl.ptLeft);
@@ -359,32 +335,31 @@ void KivioCanvas::paintEvent( QPaintEvent* ev )
     painter.restore();
   }
 
-  if (m_pView->isShowPageBorders()) {
-    painter.setPen(black);
-    painter.fillRect(pw, 3, 5, ph, gray);
-    painter.fillRect(3, ph, pw, 3, gray);
-    painter.drawRect(0, 0, pw, ph);
-  }
+  // Draw page borders
+  painter.setPen(black);
+  painter.fillRect(pw, 3, 5, ph, gray);
+  painter.fillRect(3, ph, pw, 3, gray);
+  painter.drawRect(0, 0, pw, ph);
 
   // Draw content
   KivioScreenPainter kpainter;
   kpainter.start( m_buffer );
-  kpainter.painter()->translate( -m_iXOffset, -m_iYOffset );
-  kpainter.painter()->translate( 0, 0 );
-  m_pDoc->paintContent(kpainter, rect, false, page, QPoint(0, 0), m_pView->zoomHandler(), true);
+  kpainter.translateBy( -m_iXOffset, -m_iYOffset );
+  m_pDoc->paintContent(kpainter, paintRect, false, page, QPoint(0, 0), m_pView->zoomHandler(), true);
   kpainter.stop();
 
   paintGuides(false);
   painter.end();
 
-  bitBlt(this,rect.left(),rect.top(),m_buffer,rect.left(),rect.top(),rect.width(),rect.height());
+  bitBlt(this, paintRect.left(), paintRect.top(), m_buffer,
+         paintRect.left(), paintRect.top(), paintRect.width(), paintRect.height());
 }
 
 void KivioCanvas::updateScrollBars()
 {
   KoPageLayout pl = activePage()->paperLayout();
-  m_pScrollX = m_pView->zoomHandler()->zoomItX(pl.ptWidth) - width();
-  m_pScrollY = m_pView->zoomHandler()->zoomItY(pl.ptHeight) - height();
+  m_pScrollX = QMAX(m_pView->zoomHandler()->zoomItX(pl.ptWidth) - width(), 0);
+  m_pScrollY = QMAX(m_pView->zoomHandler()->zoomItY(pl.ptHeight) - height(), 0);
 
   m_pHorzScrollBar->setRange(0, m_pScrollX);
   if ( m_pHorzScrollBar->value() > m_pHorzScrollBar->maxValue() ||
@@ -409,37 +384,13 @@ QSize KivioCanvas::actualSize()
   return QSize(m_pScrollX, m_pScrollY);
 }
 
-void KivioCanvas::setZoom(int zoom)
-{
-  if(zoom < 10 || zoom > 2000) {
-    return;
-  }
-  
-  m_pView->zoomHandler()->setZoomAndResolution(zoom, QPaintDevice::x11AppDpiX(),
-    QPaintDevice::x11AppDpiY());
-
-  updateScrollBars();
-  erase();
-  repaint();
-
-  emit zoomChanges();
-  emit visibleAreaChanged();
-}
-
-KoSize KivioCanvas::actualGridFrequency()
-{
-  KoSize actual;
-  actual.setWidth(m_pView->zoomHandler()->zoomItX(m_pDoc->grid().freq.width()));
-  actual.setHeight(m_pView->zoomHandler()->zoomItY(m_pDoc->grid().freq.height()));
-
-  return actual;
-}
-
 bool KivioCanvas::event( QEvent* e )
 {
   bool f = QWidget::event(e);
-  if (m_pToolsController && delegateThisEvent)
-    m_pToolsController->delegateEvent(e,this);
+
+  if (m_pView->pluginManager() && delegateThisEvent) {
+    f = m_pView->pluginManager()->delegateEvent(e);
+  }
 
   delegateThisEvent = true;
   return f;
@@ -966,57 +917,17 @@ void KivioCanvas::dropEvent( QDropEvent *e )
     // Terminate the drawing object
     endSpawnerDragDraw();
 
-//    // Get as handle on the icon view
-//    KivioIconView *pIconView = (KivioIconView *)m_pView->stackBar()->visiblePage();
-
-//    // Get a pointer to the currently dragged KivioStencilSpawner object
-//    KivioStencilSpawner *pSpawner = pIconView->curDragSpawner();
+    // Get a pointer to the currently dragged KivioStencilSpawner object
     KivioStencilSpawner *pSpawner = KivioIconView::curDragSpawner();
+    
     if( !pSpawner )
         return;
-
-
-    // Get a pointer to the current KivioPage
-    KivioPage *pPage = activePage();
-    if( !pPage )
-    {
-       kdDebug(43000) << "KivioCanvas::dropEvent() - No active page for stencil to drop on" << endl;
-        return;
-    }
-
-    // Allocate a new stencil
-    KivioStencil *pNewStencil = pSpawner->newStencil();
-
-    // Set the current stencil settings
+        
     QPoint pos = e->pos();
     KoPoint pagePoint = snapToGrid(mapFromScreen( pos ));
-    pNewStencil->setX( pagePoint.x() );
-    pNewStencil->setY( pagePoint.y() );
-    pNewStencil->setW( pSpawner->defWidth() );
-    pNewStencil->setH( pSpawner->defHeight() );
-    pNewStencil->setTextFont(doc()->defaultFont());
+    view()->addStencilFromSpawner(pSpawner, pagePoint.x(), pagePoint.y());
 
-    // Only set these properties if we held ctrl down
-    // FIXME: Make this happen!
-//    pNewStencil->setFGColor( m_pView->fgColor() );
-//    pNewStencil->setBGColor( m_pView->bgColor() );
-//    pNewStencil->setLineWidth( (float)m_pView->lineWidth() );
-
-
-    // Add the new stencil to the page
-    pPage->addStencil( pNewStencil );
-
-    pPage->unselectAllStencils();
-    pPage->selectStencil( pNewStencil );
-
-    // Select the "selection tool" in case it's not done
-    Tool *t = m_pToolsController->findTool("Select");
-    if( t )
-    {
-        m_pToolsController->selectTool(t);
-    }
-
-    m_pDoc->updateView(activePage());
+    // FIXME Select the "selection tool" in case it's not done
 }
 
 
@@ -1054,6 +965,7 @@ void KivioCanvas::drawSelectedStencilsXOR()
     while( pStencil )
     {
         pStencil->paintOutline( &m_dragStencilData );
+        pStencil->paintSelectionHandles( &m_dragStencilData );
 
         pStencil = activePage()->selectedStencils()->next();
     }
@@ -1077,6 +989,7 @@ void KivioCanvas::drawStencilXOR( KivioStencil *pStencil )
     m_dragStencilData.zoomHandler = m_pView->zoomHandler();
 
     pStencil->paintOutline( &m_dragStencilData );
+    pStencil->paintSelectionHandles( &m_dragStencilData );
 
     unclippedSpawnerPainter->painter()->restore();
 }
@@ -1100,7 +1013,7 @@ void KivioCanvas::keyReleaseEvent( QKeyEvent *e )
             break;
         }
         case Key_Escape: {
-            m_pToolsController->activateDefault();
+            m_pView->pluginManager()->activateDefaultTool();
         }break;
     }
 }
@@ -1109,56 +1022,10 @@ KoPoint KivioCanvas::snapToGridAndGuides(KoPoint point)
 {
   KoPoint p = point;
 
-  KoSize dist = m_pDoc->grid().snap;
-  KoSize dxy = m_pDoc->grid().freq;
+  p = snapToGrid(p);
 
-  int dx = qRound(p.x()/dxy.width());
-  int dy = qRound(p.y()/dxy.height());
-
-  float distx = QMIN(QABS(p.x() - dxy.width() * dx), QABS(p.x() - dxy.width() * (dx + 1)));
-  float disty = QMIN(QABS(p.y() - dxy.height() * dy), QABS(p.y() - dxy.height()* (dy + 1)));
-
-  if( m_pDoc->grid().isSnap)
-  {
-    if ( distx < dist.width()) {
-      if (QABS(p.x() - dxy.width() * dx) < QABS(p.x() - dxy.width() * (dx + 1))) {
-        p.rx() = dxy.width() * dx;
-      } else {
-        p.rx() = dxy.width() * (dx + 1);
-      }
-    }
-
-    if ( disty < dist.height()) {
-      if (QABS(p.y() - dxy.height() * dy) < QABS(p.y() - dxy.height() * (dy + 1))) {
-        p.ry() = dxy.height() * dy;
-      } else {
-        p.ry() = dxy.height() * (dy + 1);
-      }
-    }
-  }
-
-  /*
-  * Now if the point is within 4 pixels of a gridline, snap
-  * to the grid line.
-  */
-  if (m_pView->isSnapGuides())
-  {
-    float four = m_pView->zoomHandler()->unzoomItY(4);
-    KivioGuideLines *pGuides = activePage()->guideLines();
-    KivioGuideLineData *pData = pGuides->findHorizontal( point.y(), four );
-
-    if( pData )
-    {
-      p.ry() = (float)pData->position();
-    }
-
-    pData = pGuides->findVertical( point.x(), four );
-
-    if( pData )
-    {
-      p.rx() = (float)pData->position();
-    }
-  }
+  bool snappedX, snappedY;
+  p = snapToGuides(p, snappedX, snappedY);
 
   return p;
 }
@@ -1171,28 +1038,26 @@ KoPoint KivioCanvas::snapToGrid(KoPoint point)
   KoPoint p = point;
 
   KoSize dist = m_pDoc->grid().snap;
-  KoSize dxy = m_pDoc->grid().freq;
+  KoSize freq = m_pDoc->grid().freq;
 
-  int dx = qRound(p.x() / dxy.width());
-  int dy = qRound(p.y() / dxy.height());
+  if(m_pView->zoomHandler()->zoom() >= 150) {
+    freq = freq / 2;
+  } else if(m_pView->zoomHandler()->zoom() <= 50) {
+    freq = freq * 2;
+  }
 
-  float distx = QMIN(QABS(p.x() - dxy.width() * dx), QABS(p.x() - dxy.width() * (dx + 1)));
-  float disty = QMIN(QABS(p.y() - dxy.height() * dy), QABS(p.y() - dxy.height() * (dy + 1)));
+  int dx = qRound(p.x() / freq.width());
+  int dy = qRound(p.y() / freq.height());
+
+  double distx = QABS(p.x() - freq.width() * dx);
+  double disty = QABS(p.y() - freq.height() * dy);
 
   if(distx < dist.width()) {
-    if(QABS(p.x() - dxy.width() * dx) < QABS(p.x() - dxy.width() * (dx + 1))) {
-      p.rx() = dxy.width() * dx;
-    } else {
-      p.rx() = dxy.width() * (dx + 1);
-    }
+    p.setX(m_pView->zoomHandler()->unzoomItX(m_pView->zoomHandler()->zoomItX(freq.width()) * dx));
   }
 
   if(disty < dist.height()) {
-    if(QABS(p.y() - dxy.height() * dy) < QABS(p.y() - dxy.height() * (dy + 1))) {
-      p.ry() = dxy.height() * dy;
-    } else {
-      p.ry() = dxy.height() * (dy + 1);
-    }
+    p.setY(m_pView->zoomHandler()->unzoomItY(m_pView->zoomHandler()->zoomItY(freq.height()) * dy));
   }
 
   return p;
@@ -1206,7 +1071,7 @@ KoPoint KivioCanvas::snapToGuides(KoPoint point, bool &snappedX, bool &snappedY)
 
   if (m_pView->isSnapGuides())
   {
-    float four = m_pView->zoomHandler()->unzoomItY(4);
+    double four = m_pView->zoomHandler()->unzoomItY(4);
     KivioGuideLines *pGuides = activePage()->guideLines();
     KivioGuideLineData *pData = pGuides->findHorizontal( point.y(), four );
 
@@ -1368,14 +1233,14 @@ void KivioCanvas::paintGuides(bool show)
     bitBlt(this,0,0,m_buffer);
 }
 
-void KivioCanvas::setViewCenterPoint(KivioPoint p)
+void KivioCanvas::setViewCenterPoint(const KoPoint &p)
 {
   setUpdatesEnabled(false);
 
-  KivioRect va = visibleArea();
+  KoRect va = visibleArea();
 
-  float x = QMAX(0, p.x() - (va.w() / 2));
-  float y = QMAX(0, p.y() - (va.h() / 2));
+  float x = QMAX(0, p.x() - (va.width() / 2));
+  float y = QMAX(0, p.y() - (va.height() / 2));
 
   m_pVertScrollBar->setValue(m_pView->zoomHandler()->zoomItY(y));
   m_pHorzScrollBar->setValue(m_pView->zoomHandler()->zoomItX(x));
@@ -1383,76 +1248,76 @@ void KivioCanvas::setViewCenterPoint(KivioPoint p)
   setUpdatesEnabled(true);
 }
 
-KivioRect KivioCanvas::visibleArea()
+KoRect KivioCanvas::visibleArea()
 {
   KoPoint p0 = mapFromScreen(QPoint(0,0));
   KoPoint p1 = mapFromScreen(QPoint(width()-1,height()-1));
 
-  return KivioRect(p0.x(), p0.y(), p1.x() - p0.x(), p1.y() - p0.y());
+  return KoRect(p0.x(), p0.y(), p1.x() - p0.x(), p1.y() - p0.y());
 }
 
-void KivioCanvas::setVisibleArea(KivioRect r, int margin)
+void KivioCanvas::setVisibleArea(KoRect r, int margin)
 {
   setUpdatesEnabled(false);
   KoZoomHandler zoom;
-  zoom.setZoomAndResolution(100, QPaintDevice::x11AppDpiX(),
-    QPaintDevice::x11AppDpiY());
+  zoom.setZoomAndResolution(100, KoGlobal::dpiX(),
+    KoGlobal::dpiY());
 
   float cw = width() - 2 * margin;
   float ch = height() - 2 * margin;
 
-  float zw = cw / (float)zoom.zoomItX(r.w());
-  float zh = ch / (float)zoom.zoomItY(r.h());
+  float zw = cw / (float)zoom.zoomItX(r.width());
+  float zh = ch / (float)zoom.zoomItY(r.height());
   float z = QMIN(zw, zh);
 
-  setZoom(qRound(z * 100));
+  m_pView->viewZoom(qRound(z * 100));
 
-  KivioPoint c = r.center();
+  KoPoint c = r.center();
 
-  setViewCenterPoint(c);
+  setViewCenterPoint(KoPoint(c.x(), c.y()));
   setUpdatesEnabled(true);
 }
 
-void KivioCanvas::setVisibleAreaByWidth(KivioRect r, int margin)
+void KivioCanvas::setVisibleAreaByWidth(KoRect r, int margin)
 {
   setUpdatesEnabled(false);
   KoZoomHandler zoom;
-  zoom.setZoomAndResolution(100, QPaintDevice::x11AppDpiX(),
-    QPaintDevice::x11AppDpiY());
+  zoom.setZoomAndResolution(100, KoGlobal::dpiX(),
+    KoGlobal::dpiY());
 
   float cw = width() - 2*margin;
-  float z = cw / (float)zoom.zoomItX(r.w());
+  float z = cw / (float)zoom.zoomItX(r.width());
 
-  setZoom(qRound(z * 100));
+  m_pView->viewZoom(qRound(z * 100));
 
-  KivioPoint c = r.center();
+  KoPoint c = r.center();
 
-  setViewCenterPoint(c);
+  setViewCenterPoint(KoPoint(c.x(), c.y()));
   setUpdatesEnabled(true);
 }
 
-void KivioCanvas::setVisibleAreaByHeight(KivioRect r, int margin)
+void KivioCanvas::setVisibleAreaByHeight(KoRect r, int margin)
 {
   setUpdatesEnabled(false);
   KoZoomHandler zoom;
-  zoom.setZoomAndResolution(100, QPaintDevice::x11AppDpiX(),
-    QPaintDevice::x11AppDpiY());
+  zoom.setZoomAndResolution(100, KoGlobal::dpiX(),
+    KoGlobal::dpiY());
 
   float ch = height() - 2*margin;
-  float z = ch / (float)zoom.zoomItY(r.h());
+  float z = ch / (float)zoom.zoomItY(r.height());
 
-  setZoom(qRound(z * 100));
+  m_pView->viewZoom(qRound(z * 100));
 
-  KivioPoint c = r.center();
+  KoPoint c = r.center();
 
-  setViewCenterPoint(c);
+  setViewCenterPoint(KoPoint(c.x(), c.y()));
   setUpdatesEnabled(true);
 }
 
 void KivioCanvas::startPasteMoving()
 {
   setEnabled(false);
-  KivioPoint p = activePage()->getRectForAllSelectedStencils().center();
+  KoPoint p = activePage()->getRectForAllSelectedStencils().center();
   m_origPoint.setCoords(p.x(), p.y());
 
   // Create a new painter object
@@ -1460,13 +1325,13 @@ void KivioCanvas::startPasteMoving()
   drawSelectedStencilsXOR();
 
   // Build the list of old geometry
-  KivioRect *pData;
+  KoRect *pData;
   m_lstOldGeometry.clear();
   KivioStencil* pStencil = activePage()->selectedStencils()->first();
 
   while( pStencil )
   {
-    pData = new KivioRect;
+    pData = new KoRect;
     *pData = pStencil->rect();
     m_lstOldGeometry.append(pData);
 
@@ -1495,7 +1360,7 @@ void KivioCanvas::continuePasteMoving(const QPoint &pos)
 
   // Translate to the new position
   KoPoint p;
-  KivioRect selectedRect = activePage()->getRectForAllSelectedStencils();
+  KoRect selectedRect = activePage()->getRectForAllSelectedStencils();
 
   newX = selectedRect.x() + dx;
   newY = selectedRect.y() + dy;
@@ -1508,15 +1373,15 @@ void KivioCanvas::continuePasteMoving(const QPoint &pos)
   newY = p.y();
 
   // Now the guides override the grid so we attempt to snap to them
-  p.setCoords(selectedRect.x() + dx + selectedRect.w(), selectedRect.y() + dy + selectedRect.h());
+  p.setCoords(selectedRect.x() + dx + selectedRect.width(), selectedRect.y() + dy + selectedRect.height());
   p = snapToGuides(p, snappedX, snappedY);
 
   if(snappedX) {
-    newX = p.x() - selectedRect.w();
+    newX = p.x() - selectedRect.width();
   }
 
   if(snappedY) {
-    newY = p.y() - selectedRect.h();
+    newY = p.y() - selectedRect.height();
   }
 
   p.setCoords(selectedRect.x() + dx, selectedRect.y() + dy);
@@ -1535,7 +1400,7 @@ void KivioCanvas::continuePasteMoving(const QPoint &pos)
 
   // Translate to the new position
   KivioStencil *pStencil = activePage()->selectedStencils()->first();
-  KivioRect* pData = m_lstOldGeometry.first();
+  KoRect* pData = m_lstOldGeometry.first();
   // bool move = true;
 
   while( pStencil && pData )
@@ -1562,7 +1427,7 @@ void KivioCanvas::continuePasteMoving(const QPoint &pos)
 void KivioCanvas::endPasteMoving()
 {
   KivioStencil *pStencil = activePage()->selectedStencils()->first();
-  KivioRect *pData = m_lstOldGeometry.first();
+  KoRect *pData = m_lstOldGeometry.first();
 
   while( pStencil && pData )
   {
