@@ -33,7 +33,7 @@ class KivioScreenPainter : public KivioPainter
 protected:
     QPainter *m_pPainter;
     float m_transX, m_transY;
-    float m_rotation;
+    int m_rotation;
 
 public:
     KivioScreenPainter();
@@ -93,13 +93,17 @@ public:
     void drawPixmap( float, float, const QPixmap & );
 
     void drawHandle( float, float, int );
+    virtual void drawSelectionBox( const QRect& );
 
     virtual void saveState();
     virtual void restoreState();
     virtual void setTranslation(float, float);
     virtual void translateBy(float, float);
-    virtual void setRotation(float);
-    virtual void rotateBy(float);
+    virtual void setRotation(int);
+    virtual void rotateBy(int);
+    virtual int rotation();
+
+    virtual void setWorldMatrix(QWMatrix, bool);
 };
 
 #endif
