@@ -1,6 +1,7 @@
 // -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
+   Copyright (C) 2005 Thorsten Zachmann <zachmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,6 +36,7 @@
 #include "kppolygonobject.h"
 #include "kpclosedlineobject.h"
 #include <kdebug.h>
+#include <kooasiscontext.h>
 
 #include <qpainter.h>
 using namespace std;
@@ -130,7 +132,62 @@ QDomDocumentFragment KPGroupObject::save( QDomDocument& doc, double offset )
     return fragment;
 }
 
-double KPGroupObject::load(const QDomElement &element, KPresenterDoc *doc)
+
+bool KPGroupObject::saveOasisObjectAttributes( KPOasisSaveContext &sc ) const
+{
+    QPtrListIterator<KPObject> it( objects );
+    for ( ; it.current() ; ++it )
+    {
+        //TODO what to do with parts?
+        it.current()->saveOasisObject( sc );
+    }
+    return true;
+}
+
+void KPGroupObject::saveOasisPosObject( KoXmlWriter &xmlWriter, int indexObj ) const
+{
+    xmlWriter.addAttribute( "draw:id", "object" + QString::number( indexObj ) );
+
+#if 0
+    if ( kAbs( angle ) > 1E-6 )
+    {
+        double value = -1 * ( ( double )angle* M_PI )/180.0;
+        QString str = QString( "rotate (%1)" ).arg( value );
+        xmlWriter.addAttribute( "draw:transform", str );
+    }
+#endif
+}
+
+
+const char * KPGroupObject::getOasisElementName() const
+{
+    return "draw:g";
+}
+
+
+void KPGroupObject::loadOasisGroupObject( KPresenterDoc *_doc, KPrPage * newpage, QDomNode &element, KoOasisContext & context, KPRLoadingInfo *info)
+{
+    //KPObject::loadOasis( element, context, info );
+    updateObjs = false;
+    _doc->loadOasisObject( newpage,element, context, this);
+    QPtrListIterator<KPObject> it( objects );
+    KoRect r=KoRect();
+    for ( ; it.current() ; ++it )
+    {
+        r |= it.current()->getBoundingRect();
+    }
+    setOrig( r.x(), r.y() );
+    setSize( r.width(), r.height() );
+    updateObjs = true;
+}
+
+void KPGroupObject::addObjects( KPObject * obj )
+{
+    kdDebug()<<"add object to group object:"<<obj<<endl;
+    objects.append( obj );
+}
+
+double KPGroupObject::load( const QDomElement &element, KPresenterDoc *doc)
 {
     //FIXME
     double offset=KPObject::load(element);
@@ -242,13 +299,13 @@ double KPGroupObject::load(const QDomElement &element, KPresenterDoc *doc)
 }
 
 void KPGroupObject::draw( QPainter *_painter,KoZoomHandler *_zoomhandler,
-                          SelectionMode selectionMode, bool drawContour )
+                          int pageNum, SelectionMode selectionMode, bool drawContour )
 {
     QPtrListIterator<KPObject> it( objects );
     for ( ; it.current() ; ++it )
-        it.current()->draw( _painter, _zoomhandler, selectionMode, drawContour );
+        it.current()->draw( _painter, _zoomhandler, pageNum, selectionMode, drawContour );
 
-    KPObject::draw( _painter, _zoomhandler, selectionMode, drawContour );
+    KPObject::draw( _painter, _zoomhandler, pageNum, selectionMode, drawContour );
 }
 
 void KPGroupObject::updateSizes( double fx, double fy )
@@ -262,7 +319,7 @@ void KPGroupObject::updateSizes( double fx, double fy )
         double _x = ( it.current()->getOrig().x() - orig.x() ) * fx + orig.x();
         double _y = ( it.current()->getOrig().y() - orig.y() ) * fy + orig.y();
         it.current()->setOrig( _x, _y );
-        
+
         double _w = it.current()->getSize().width() * fx;
         double _h = it.current()->getSize().height() * fy;
         it.current()->setSize( _w, _h );
@@ -377,15 +434,15 @@ void KPGroupObject::setEffect2( Effect2 _effect2 )
         it.current()->setEffect2( _effect2 );
 }
 
-void KPGroupObject::setPresNum( int _presNum )
+void KPGroupObject::setAppearStep( int _appearStep )
 {
-    KPObject::setPresNum( _presNum );
+    KPObject::setAppearStep( _appearStep );
 
     if ( !updateObjs )
         return;
     QPtrListIterator<KPObject> it( objects );
     for ( ; it.current() ; ++it )
-        it.current()->setPresNum( _presNum );
+        it.current()->setAppearStep( _appearStep );
 }
 
 void KPGroupObject::setDisappear( bool b )
@@ -399,15 +456,15 @@ void KPGroupObject::setDisappear( bool b )
         it.current()->setDisappear( b );
 }
 
-void KPGroupObject::setDisappearNum( int num )
+void KPGroupObject::setDisappearStep( int _disappearStep )
 {
-    KPObject::setDisappearNum( num );
+    KPObject::setDisappearStep( _disappearStep );
 
     if ( !updateObjs )
         return;
     QPtrListIterator<KPObject> it( objects );
     for ( ; it.current() ; ++it )
-        it.current()->setDisappearNum( num );
+        it.current()->setDisappearStep( _disappearStep );
 }
 
 void KPGroupObject::setEffect3( Effect3 _effect3)
@@ -543,18 +600,53 @@ void KPGroupObject::flip( bool horizontal ) {
         it.current()->flip( horizontal );
         double mx = 0;
         double my = 0;
-        if ( horizontal ) 
+        if ( ! horizontal )
         {
             double disttop = it.current()->getOrig().y() - orig.y();
             double distbottom = ext.height() - disttop - it.current()->getSize().height();
-            my = distbottom - disttop; 
+            my = distbottom - disttop;
         }
-        else 
+        else
         {
             double distleft = it.current()->getOrig().x() - orig.x();
             double distright = ext.width() - distleft - it.current()->getSize().width();
-            mx = distright - distleft; 
+            mx = distright - distleft;
         }
         it.current()->moveBy( mx, my );
     }
 }
+
+void KPGroupObject::removeFromObjList()
+{
+    inObjList = false; 
+    QPtrListIterator<KPObject> it( objects );
+    for ( ; it.current() ; ++it ) 
+        it.current()->removeFromObjList();
+}
+
+void KPGroupObject::addToObjList()
+{ 
+    inObjList = true; 
+    QPtrListIterator<KPObject> it( objects );
+    for ( ; it.current() ; ++it ) 
+        it.current()->addToObjList();
+}
+
+void KPGroupObject::incCmdRef()
+{ 
+    QPtrListIterator<KPObject> it( objects );
+    for ( ; it.current() ; ++it ) 
+        it.current()->incCmdRef();
+
+    cmds++; 
+}
+
+void KPGroupObject::decCmdRef()
+{ 
+    QPtrListIterator<KPObject> it( objects );
+    for ( ; it.current() ; ++it ) 
+        it.current()->decCmdRef();
+
+    cmds--; 
+    doDelete(); 
+}
