@@ -1,6 +1,7 @@
 // -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
+   Copyright (C) 2005 Thorsten Zachmann <zachmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,7 +34,14 @@
 #include <koPoint.h>
 #include <koSize.h>
 #include <koRect.h>
-#include "kpobject.h"
+#include <koStyleStack.h>
+#include <koOasisStyles.h>
+#include <koxmlwriter.h>
+#include <koGenStyles.h>
+#include "kprloadinginfo.h"
+#include "kprbrush.h"
+
+class KoSavingContext;
 class QPainter;
 class DCOPObject;
 class QDomDocumentFragment;
@@ -43,6 +51,7 @@ class KoZoomHandler;
 class KPresenterDoc;
 class KPTextObject;
 class KoTextObject;
+class KoOasisContext;
 
 #define RAD_FACTOR 180.0 / M_PI
 
@@ -93,14 +102,18 @@ public:
         { effect = _effect; }
     virtual void setEffect2( Effect2 _effect2 )
         { effect2 = _effect2; }
-    virtual void setPresNum( int _presNum )
-        { presNum = _presNum; }
+    virtual void setAppearStep( int _appearStep )
+        { appearStep = _appearStep; }
     virtual void setDisappear( bool b )
         { disappear = b; }
-    virtual void setDisappearNum( int num )
-        { disappearNum = num; }
+    virtual void setDisappearStep( int num )
+        { disappearStep = num; }
     virtual void setEffect3( Effect3 _effect3)
         { effect3 = _effect3; }
+    virtual void setAppearSpeed( EffectSpeed _speed )
+        { m_appearSpeed = _speed; }
+    virtual void setDisappearSpeed( EffectSpeed _speed )
+        { m_disappearSpeed = _speed; }
     virtual void setAppearTimer( int _appearTimer )
         { appearTimer = _appearTimer; }
     virtual void setDisappearTimer( int _disappearTimer )
@@ -121,6 +134,30 @@ public:
 
     virtual QDomDocumentFragment save( QDomDocument& doc, double offset );
     virtual double load(const QDomElement &element);
+    virtual void loadOasis(const QDomElement &element, KoOasisContext & context,  KPRLoadingInfo *info);
+
+    struct KPOasisSaveContext
+    {
+        KPOasisSaveContext( KoXmlWriter &_xmlWriter, KoSavingContext &_context,
+                            int &_indexObj, int &_partIndexObj, bool _onMaster )
+            : xmlWriter( _xmlWriter )
+            , context( _context ) 
+            , indexObj( _indexObj )
+            , partIndexObj( _partIndexObj )
+            , onMaster( _onMaster ) {};
+            
+        KoXmlWriter &xmlWriter;
+        KoSavingContext &context;
+        int &indexObj;
+        int &partIndexObj;
+        bool onMaster;
+    };
+
+    virtual bool saveOasisObject( KPOasisSaveContext &sc ) const;
+
+    //return true if we have a animation into object
+    bool saveOasisObjectStyleShowAnimation( KoXmlWriter &animation, int objectId );
+    bool saveOasisObjectStyleHideAnimation( KoXmlWriter &animation, int objectId );
 
     virtual void flip(bool horizontal );
 
@@ -157,6 +194,10 @@ public:
         { return effect2; }
     virtual Effect3 getEffect3() const
         { return effect3; }
+    virtual EffectSpeed getAppearSpeed() const
+        { return m_appearSpeed; }
+    virtual EffectSpeed getDisappearSpeed() const
+        { return m_disappearSpeed; }
     virtual int getAppearTimer() const
         { return appearTimer; }
     virtual int getDisappearTimer() const
@@ -169,14 +210,20 @@ public:
         { return a_fileName; }
     virtual QString getDisappearSoundEffectFileName() const
         { return d_fileName; }
-    virtual int getPresNum() const
-        { return presNum; }
+    /**
+     * get the step when the object appears on the site
+     */
+    virtual int getAppearStep() const
+        { return appearStep; }
     virtual int getSubPresSteps() const
         { return 0; }
     virtual bool getDisappear() const
         { return disappear; }
-    virtual int getDisappearNum() const
-        { return disappearNum; }
+    /**
+     * get the step when the object disappears from the site
+     */
+    virtual int getDisappearStep() const
+        { return disappearStep; }
 
     virtual void setOwnClipping( bool _ownClipping )
         { ownClipping = _ownClipping; }
@@ -187,7 +234,7 @@ public:
 
     // the main drawing method.
     virtual void draw( QPainter *_painter, KoZoomHandler*_zoomHandler,
-                       SelectionMode selectionMode, bool drawContour = FALSE );
+                       int /*pageNum*/, SelectionMode selectionMode, bool drawContour = FALSE );
 
     virtual bool contains( const KoPoint &_point ) const;
     virtual bool intersects( const KoRect & _rect ) const;
@@ -232,6 +279,8 @@ public:
         { if (selected || force ) lst.append( this );}
     virtual QPen getPen() const;
 
+    bool haveAnimation() const;
+
 protected:
     /**
      * Helper function to caluclate the size and the orig of a point object
@@ -252,9 +301,6 @@ protected:
     QDomElement createValueElement(const QString &tag, int value, QDomDocument &doc);
     QDomElement createGradientElement(const QString &tag, const QColor &c1, const QColor &c2,
                                       int type, bool unbalanced, int xfactor, int yfactor, QDomDocument &doc);
-    void toGradient(const QDomElement &element, QColor &c1, QColor &c2, BCType &type,
-                    bool &unbalanced, int &xfactor, int &yfactor) const;
-
     QDomElement createPenElement(const QString &tag, const QPen &pen, QDomDocument &doc);
     QPen toPen(const QDomElement &element) const;
 
@@ -265,6 +311,19 @@ protected:
                          const QString &rattr="red", const QString &gattr="green",
                          const QString &battr="blue") const;
 
+    void saveOasisObjectProtectStyle( KoGenStyle &styleobjectauto ) const;
+    void saveOasisShadowElement( KoGenStyle &styleobjectauto ) const;
+
+    QString getStyle( KPOasisSaveContext &sc ) const;
+    virtual void fillStyle( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const;
+    /**
+     * Get the element name for saving the object
+     */
+    virtual const char * getOasisElementName() const = 0;
+    //virtual bool saveOasisObjectAttributes( KPOasisSaveContext &sc ) const = 0;
+    virtual bool saveOasisObjectAttributes( KPOasisSaveContext &sc ) const;
+    virtual void saveOasisPosObject( KoXmlWriter &xmlWriter, int indexObj ) const;
+
     float angle;
     KoPoint orig;
     KoSize ext;
@@ -274,10 +333,13 @@ protected:
     Effect effect;
     Effect2 effect2;
     Effect3 effect3;
+    EffectSpeed m_appearSpeed;
+    EffectSpeed m_disappearSpeed;
     int appearTimer, disappearTimer;
     QString a_fileName, d_fileName;
     QString objectName;
-    int presNum, disappearNum;
+    // step when objects appears/disappears
+    int appearStep, disappearStep;
 
     bool disappear:1;
     bool appearSoundEffect:1;
@@ -292,7 +354,6 @@ protected:
     bool protect:1;
     bool keepRatio:1;
 
-    float presFakt;
     int subPresStep;
     int cmds;
 
@@ -323,26 +384,37 @@ class KPShadowObject : public KPObject
 public:
     KPShadowObject();
     KPShadowObject( const QPen &_pen );
-    KPShadowObject( const QPen &_pen, const QBrush &_brush );
 
     KPShadowObject &operator=( const KPShadowObject & );
 
     virtual void setPen( const QPen &_pen )
         { pen = _pen; }
-    virtual void setBrush( const QBrush &_brush )
-        { brush = _brush; }
 
     virtual QPen getPen() const
         { return pen; }
-    virtual QBrush getBrush() const
-        { return brush; }
 
     virtual QDomDocumentFragment save( QDomDocument& doc, double offset );
     virtual double load(const QDomElement &element);
-
+    virtual void loadOasis(const QDomElement &element, KoOasisContext & context, KPRLoadingInfo *info);
     virtual void draw( QPainter *_painter, KoZoomHandler*_zoomHandler,
-                       SelectionMode selectionMode, bool drawContour = FALSE );
+                       int pageNum, SelectionMode selectionMode, bool drawContour = FALSE );
+    virtual void saveOasisStrokeElement( KoGenStyles& mainStyles, KoGenStyle &styleobjectauto ) const;
+    QString saveOasisStrokeStyle( KoGenStyles& mainStyles ) const;
+
 protected:
+    /**
+     * Helper method for saving draw:points. The svg:viewBox is also saved.
+     */
+    static bool saveOasisDrawPoints( const KoPointArray &points, KPOasisSaveContext &sc );
+
+    /**
+     * Helper method for loading draw:points. The svg:viewBox is taken into account.
+     */
+    bool loadOasisDrawPoints( KoPointArray &points, const QDomElement &element,
+                              KoOasisContext & context, KPRLoadingInfo *info );
+
+    virtual void fillStyle( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const;
+
     /**
      * @ref save() only saves if the pen is different from the default pen.
      * The default pen can vary depending on the subclass of KPShadowObject
@@ -361,24 +433,9 @@ protected:
      *
      * This method isn't pure virtual because some objects implement draw() directly.
      */
-    virtual void paint( QPainter* /*painter*/, KoZoomHandler* /*zoomHandler*/,
-                        bool /*drawingShadow*/, bool /*drawContour*/ =  FALSE ) {}
+    virtual void paint( QPainter* /* painter */, KoZoomHandler* /* zoomHandler */,
+                        int /* pageNum */, bool /* drawingShadow */, bool /* drawContour */ =  FALSE ) {}
     QPen pen;
-    QBrush brush;
-};
-
-class KPPointObject : public KPShadowObject
-{
-public:
-    KPPointObject();
-    KPPointObject( const QPen &_pen );
-    KPPointObject( const QPen &_pen, const QBrush &_brush );
-
-    virtual KoSize getRealSize() const;
-    virtual KoPoint getRealOrig() const;
-
-protected:
-    KoPointArray points;
 };
 
 class KP2DObject : public KPShadowObject
@@ -390,48 +447,76 @@ public:
                 bool _unbalanced, int _xfactor, int _yfactor );
     virtual ~KP2DObject() { delete gradient; }
 
-    virtual void setFillType( FillType _fillType );
-    virtual void setGColor1( const QColor &_gColor1 )
-        { if ( gradient ) gradient->setColor1( _gColor1 ); gColor1 = _gColor1; }
-    virtual void setGColor2( const QColor &_gColor2 )
-        { if ( gradient ) gradient->setColor2( _gColor2 ); gColor2 = _gColor2; }
-    virtual void setGType( BCType _gType )
-        { if ( gradient ) gradient->setBackColorType( _gType ); gType = _gType; }
+    virtual void setFillType( FillType fillType );
+    virtual void setBrush( const QBrush &brush )
+        { m_brush.setBrush( brush ); }
+    virtual void setGColor1( const QColor &gColor1 )
+        { if ( gradient ) gradient->setColor1( gColor1 ); m_brush.setGColor1( gColor1 ); m_redrawGradientPix = true; }
+    virtual void setGColor2( const QColor &gColor2 )
+        { if ( gradient ) gradient->setColor2( gColor2 ); m_brush.setGColor2( gColor2 ); m_redrawGradientPix = true; }
+    virtual void setGType( BCType gType )
+        { if ( gradient ) gradient->setBackColorType( gType ); m_brush.setGType( gType ); m_redrawGradientPix = true; }
     virtual void setGUnbalanced( bool b )
-        { if ( gradient ) gradient->setUnbalanced( b ); unbalanced = b; }
-    virtual void setGXFactor( int f )
-        { if ( gradient ) gradient->setXFactor( f ); xfactor = f; }
-    virtual void setGYFactor( int f )
-        { if ( gradient ) gradient->setYFactor( f ); yfactor = f; }
+        { if ( gradient ) gradient->setUnbalanced( b ); m_brush.setGUnbalanced( b ); m_redrawGradientPix = true; }
+    virtual void setGXFactor( int xfactor )
+        { if ( gradient ) gradient->setXFactor( xfactor ); m_brush.setGXFactor( xfactor ); m_redrawGradientPix = true; }
+    virtual void setGYFactor( int yfactor )
+        { if ( gradient ) gradient->setYFactor( yfactor ); m_brush.setGYFactor( yfactor ); m_redrawGradientPix = true; }
 
     virtual FillType getFillType() const
-        { return fillType; }
+        { return m_brush.getFillType(); }
+    virtual QBrush getBrush() const
+        { return m_brush.getBrush(); }
     virtual QColor getGColor1() const
-        { return gColor1; }
+        { return m_brush.getGColor1(); }
     virtual QColor getGColor2() const
-        { return gColor2; }
+        { return m_brush.getGColor2(); }
     virtual BCType getGType() const
-        { return gType; }
+        { return m_brush.getGType(); }
     virtual bool getGUnbalanced() const
-        { return unbalanced; }
+        { return m_brush.getGUnbalanced(); }
     virtual int getGXFactor() const
-        { return xfactor; }
+        { return m_brush.getGXFactor(); }
     virtual int getGYFactor() const
-        { return yfactor; }
+        { return m_brush.getGYFactor(); }
 
     virtual QDomDocumentFragment save( QDomDocument& doc, double offset );
     virtual double load(const QDomElement &element);
+    virtual void loadOasis(const QDomElement &element, KoOasisContext & context, KPRLoadingInfo *info);
+    virtual void draw( QPainter *_painter, KoZoomHandler*_zoomHandler,
+                       int pageNum, SelectionMode selectionMode, bool drawContour = FALSE );
 
     virtual void flip(bool horizontal );
 
 protected:
-    QColor gColor1, gColor2;
-    BCType gType;
-    FillType fillType;
-    bool unbalanced;
-    int xfactor, yfactor;
+    QString saveOasisGradientStyle( KoGenStyles& mainStyles ) const;
 
+    virtual void fillStyle( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const;
+    void saveOasisBackgroundElement( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const;
+
+    KPrBrush m_brush;
     KPGradient *gradient;
+    /// holds the painted gradient
+    QPixmap m_gradientPix;
+    bool m_redrawGradientPix;
+};
+
+class KPStartEndLine
+{
+public:
+    KPStartEndLine( LineEnd _start, LineEnd _end );
+    void save( QDomDocumentFragment &fragment, QDomDocument& doc );
+    void load( const QDomElement &element );
+
+    void saveOasisMarkerElement( KoGenStyles& mainStyles,  KoGenStyle &styleobjectauto ) const;
+    QString saveOasisMarkerStyle( KoGenStyles &mainStyles, const LineEnd &_element ) const;
+    void loadOasisMarkerElement( KoOasisContext & context, const QString & attr, LineEnd &_element );
+
+protected:
+    //duplicate from kpobject
+    QDomElement createValueElement(const QString &tag, int value, QDomDocument &doc);
+
+    LineEnd lineBegin, lineEnd;
 };
 
 #endif
