@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
+   Copyright (C) 2005 Thorsten Zachmann <zachmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,6 +18,11 @@
    Boston, MA 02111-1307, USA.
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+
 #include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
@@ -33,21 +39,22 @@
 #include <qlayout.h>
 #include <qvbox.h>
 #include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qtabwidget.h>
 
-#include "styledia.h"
-#include "confpiedia.h"
-#include "confrectdia.h"
-#include "confpolygondia.h"
-#include "confpicturedia.h"
+#include "penstylewidget.h"
+#include "brushproperty.h"
+#include "pieproperty.h"
+#include "rectproperty.h"
+#include "polygonproperty.h"
 
 #include "kpresenter_dlg_config.h"
 #include "kpresenter_view.h"
 #include "kpresenter_doc.h"
+#include "kprpage.h"
 #include <koUnit.h>
 
 #include <float.h>
-#include <kspell.h>
 #include <knumvalidator.h>
 #include <qlineedit.h>
 #include "kprcommand.h"
@@ -60,14 +67,19 @@
 #include <kurlrequesterdlg.h>
 #include <klistview.h>
 #include <kfiledialog.h>
-#include <koSpellConfig.h>
 #include <koeditpath.h>
-#include <koSconfig.h>
+
+#ifdef HAVE_LIBKSPELL2
+#include <kspell2/configwidget.h>
+#include <kspell2/settings.h>
+#include <kspell2/broker.h>
+using namespace KSpell2;
+#endif
 
 KPConfig::KPConfig( KPresenterView* parent )
     : KDialogBase(KDialogBase::IconList,i18n("Configure KPresenter") ,
                   KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel| KDialogBase::Default,
-                  KDialogBase::Ok)
+                  KDialogBase::Ok, parent)
 
 {
     m_doc = parent->kPresenterDoc();
@@ -78,16 +90,20 @@ KPConfig::KPConfig( KPresenterView* parent )
                         BarIcon("colorize", KIcon::SizeMedium) );
     _colorBackground = new configureColorBackground( parent, page );
 
+#ifdef HAVE_LIBKSPELL2
     page = addVBoxPage( i18n("Spelling"), i18n("Spell Checker Behavior"),
                         BarIcon("spellcheck", KIcon::SizeMedium) );
     _spellPage=new configureSpellPage(parent, page);
+#else
+    _spellPage=0;
+#endif
 
     page = addVBoxPage( i18n("Misc"), i18n("Misc"),
                         BarIcon("misc", KIcon::SizeMedium) );
     _miscPage=new configureMiscPage(parent, page);
 
     page = addVBoxPage( i18n("Document"), i18n("Document Settings"),
-                        BarIcon("document", KIcon::SizeMedium) );
+                        BarIcon("kpresenter_kpr", KIcon::SizeMedium) );
 
     _defaultDocPage=new configureDefaultDocPage(parent, page);
 
@@ -127,7 +143,7 @@ void KPConfig::slotApply()
     KMacroCommand *macro = 0L;
     _interfacePage->apply();
     _colorBackground->apply();
-    _spellPage->apply();
+    if (_spellPage) _spellPage->apply();
     m_pathPage->apply();
     KCommand *cmd = _miscPage->apply();
     if ( cmd )
@@ -160,7 +176,7 @@ void KPConfig::slotDefault()
         _colorBackground->slotDefault();
         break;
     case 2:
-        _spellPage->slotDefault();
+        if (_spellPage) _spellPage->slotDefault();
         break;
     case 3:
         _miscPage->slotDefault();
@@ -219,9 +235,9 @@ configureInterfacePage::configureInterfacePage( KPresenterView *_view, QWidget *
     box->addWidget(recentFiles);
 
     QString suffix = KoUnit::unitName( unit ).prepend(' ');
-    double val = KoUnit::ptToUnit( ptIndent, unit );
-    indent = new KDoubleNumInput( val, this);
-    indent->setRange(KoUnit::ptToUnit( 0.1, unit ), KoUnit::ptToUnit( 50, unit ), KoUnit::ptToUnit( 0.1, unit ));
+    indent = new KDoubleNumInput( this );
+    indent->setValue( KoUnit::toUserValue( ptIndent, unit ) );
+    indent->setRange(KoUnit::toUserValue( 0.1, unit ), KoUnit::toUserValue( 50, unit ), KoUnit::toUserValue( 0.1, unit ));
 
 
     indent->setSuffix( suffix );
@@ -242,7 +258,7 @@ void configureInterfacePage::apply()
 
     config->setGroup( "Interface" );
 
-    double newIndent = KoUnit::ptFromUnit( indent->value(), doc->getUnit() );
+    double newIndent = KoUnit::fromUserValue( indent->value(), doc->getUnit() );
     if( newIndent != doc->getIndentValue() )
     {
         config->writeEntry( "Indent", newIndent, true, false, 'g', DBL_DIG /* 6 is not enough */ );
@@ -277,7 +293,7 @@ void configureInterfacePage::apply()
 
 void configureInterfacePage::slotDefault()
 {
-    double newIndent = KoUnit::ptToUnit( MM_TO_POINT( 10 ), m_pView->kPresenterDoc()->getUnit() );
+    double newIndent = KoUnit::toUserValue( MM_TO_POINT( 10 ), m_pView->kPresenterDoc()->getUnit() );
     indent->setValue( newIndent );
     recentFiles->setValue(10);
     showRuler->setChecked(true);
@@ -357,52 +373,33 @@ configureSpellPage::configureSpellPage( KPresenterView *_view, QWidget *parent,
 {
     m_pView=_view;
     config = KPresenterFactory::global()->config();
-    m_spellConfigWidget = new KoSpellConfigWidget( parent, m_pView->kPresenterDoc()->getKOSpellConfig(), true);
-#if 0
-    if( config->hasGroup("KSpell kpresenter") )
-    {
-        config->setGroup( "KSpell kpresenter" );
-        m_spellConfigWidget->setDontCheckUpperWord(config->readBoolEntry("KSpell_dont_check_upper_word",false));
-        m_spellConfigWidget->setDontCheckTitleCase(config->readBoolEntry("KSpell_dont_check_title_case",false));
-    }
+#ifdef HAVE_LIBKSPELL2
+    m_spellConfigWidget = new ConfigWidget( _view->broker(), parent );
+    m_spellConfigWidget->setBackgroundCheckingButtonShown( true );
 #endif
-    m_spellConfigWidget->setBackgroundSpellCheck( m_pView->kPresenterDoc()->backgroundSpellCheckEnabled() );
-    m_spellConfigWidget->addIgnoreList( m_pView->kPresenterDoc()->spellListIgnoreAll() );
 }
 
 void configureSpellPage::apply()
 {
 
-    KOSpellConfig *_spellConfig = m_spellConfigWidget->spellConfig();
-    config->setGroup( "KSpell kpresenter" );
-    config->writeEntry ("KSpell_NoRootAffix",(int) _spellConfig->noRootAffix ());
-    config->writeEntry ("KSpell_RunTogether", (int) _spellConfig->runTogether ());
-    config->writeEntry ("KSpell_Dictionary", _spellConfig->dictionary ());
-    config->writeEntry ("KSpell_DictFromList",(int)  _spellConfig->dictFromList());
-    config->writeEntry ("KSpell_Encoding", (int)  _spellConfig->encoding());
-    config->writeEntry ("KSpell_Client",  _spellConfig->client());
-    config->writeEntry( "KSpell_dont_check_title_case", (int)_spellConfig->dontCheckTitleCase());
-    config->writeEntry( "KSpell_dont_check_upper_word", (int)_spellConfig->dontCheckUpperWord());
-    config->writeEntry ("KSpell_IgnoreCase",(int) _spellConfig->ignoreCase());
-    config->writeEntry( "KSpell_IgnoreAccent", (int) _spellConfig->ignoreAccent());
-    config->writeEntry( "KSpell_SpellWordWithNumber", (int)_spellConfig->spellWordWithNumber());
-    m_spellConfigWidget->saveDictionary();
+#ifdef HAVE_LIBKSPELL2
     KPresenterDoc* doc = m_pView->kPresenterDoc();
-    doc->setKOSpellConfig(*_spellConfig);
+    m_spellConfigWidget->save();
 
-    bool state = m_spellConfigWidget->backgroundSpellCheck();
-    config->writeEntry( "SpellCheck", (int)state );
 
-    doc->addIgnoreWordAllList( m_spellConfigWidget->ignoreList() );
-
-    doc->reactivateBgSpellChecking(state);
-    //FIXME reactivate just if there is a changes.
-    doc->enableBackgroundSpellCheck( state );
+    m_pView->kPresenterDoc()->setSpellCheckIgnoreList(
+        m_pView->broker()->settings()->currentIgnoreList() );
+    //FIXME reactivate just if there are changes.
+    doc->enableBackgroundSpellCheck( m_pView->broker()->settings()->backgroundCheckerEnabled() );
+    doc->reactivateBgSpellChecking();
+#endif
 }
 
 void configureSpellPage::slotDefault()
 {
-    m_spellConfigWidget->setDefault();
+#ifdef HAVE_LIBKSPELL2
+    m_spellConfigWidget->slotDefault();
+#endif
 }
 
 configureMiscPage::configureMiscPage( KPresenterView *_view, QWidget *parent, char *name )
@@ -462,13 +459,13 @@ configureMiscPage::configureMiscPage( KPresenterView *_view, QWidget *parent, ch
     tmpQGroupBox->layout()->setMargin(KDialog::marginHint());
     grid = new QGridLayout( tmpQGroupBox->layout(), 8, 1 );
 
-    KoRect rect = doc->stickyPage()->getPageRect();
+    KoRect rect = doc->masterPage()->getPageRect();
     QLabel *lab=new QLabel(i18n("Resolution X (%1):").arg(doc->getUnitName()), tmpQGroupBox);
     grid->addWidget(lab,0,0);
     KoUnit::Unit unit = doc->getUnit();
     resolutionX = new KDoubleNumInput(tmpQGroupBox);
-    resolutionX->setValue( KoUnit::ptToUnit( doc->getGridX(), unit ) );
-    resolutionX->setRange( KoUnit::ptToUnit(10.0 , unit), KoUnit::ptToUnit(rect.width(), unit), KoUnit::ptToUnit(1, unit ), false);
+    resolutionX->setValue( KoUnit::toUserValue( doc->getGridX(), unit ) );
+    resolutionX->setRange( KoUnit::toUserValue(10.0 , unit), KoUnit::toUserValue(rect.width(), unit), KoUnit::toUserValue(1, unit ), false);
 
     grid->addWidget(resolutionX,1,0);
 
@@ -476,8 +473,8 @@ configureMiscPage::configureMiscPage( KPresenterView *_view, QWidget *parent, ch
     grid->addWidget(lab,2,0);
 
     resolutionY = new KDoubleNumInput(tmpQGroupBox);
-    resolutionY->setValue( KoUnit::ptToUnit( doc->getGridY(), unit ) );
-    resolutionY->setRange( KoUnit::ptToUnit(10.0,unit), KoUnit::ptToUnit(rect.width(), unit), KoUnit::ptToUnit( 1,unit ), false);
+    resolutionY->setValue( KoUnit::toUserValue( doc->getGridY(), unit ) );
+    resolutionY->setRange( KoUnit::toUserValue(10.0,unit), KoUnit::toUserValue(rect.width(), unit), KoUnit::toUserValue( 1,unit ), false);
 
     grid->addWidget(resolutionY, 3, 0);
     box->addWidget(tmpQGroupBox);
@@ -554,8 +551,8 @@ KCommand * configureMiscPage::apply()
         macroCmd->addCommand(cmd);
     }
 
-    doc->setGridValue( KoUnit::ptFromUnit( resolutionX->value(), doc->getUnit() ),
-                       KoUnit::ptFromUnit( resolutionY->value(), doc->getUnit() ), true);
+    doc->setGridValue( KoUnit::fromUserValue( resolutionX->value(), doc->getUnit() ),
+                       KoUnit::fromUserValue( resolutionY->value(), doc->getUnit() ), true);
     doc->repaint( false );
 
     config->sync();
@@ -573,8 +570,8 @@ void configureMiscPage::slotDefault()
     m_cbPrintNotes->setChecked(true);
     KPresenterDoc* doc = m_pView->kPresenterDoc();
 
-    resolutionY->setValue( KoUnit::ptToUnit( MM_TO_POINT( 10.0 ), doc->getUnit() ) );
-    resolutionX->setValue( KoUnit::ptToUnit( MM_TO_POINT( 10.0 ), doc->getUnit() ) );
+    resolutionY->setValue( KoUnit::toUserValue( MM_TO_POINT( 10.0 ), doc->getUnit() ) );
+    resolutionX->setValue( KoUnit::toUserValue( MM_TO_POINT( 10.0 ), doc->getUnit() ) );
 }
 
 configureDefaultDocPage::configureDefaultDocPage(KPresenterView *_view, QWidget *parent, char *name )
@@ -633,10 +630,8 @@ configureDefaultDocPage::configureDefaultDocPage(KPresenterView *_view, QWidget
     QLabel *languageTitle = new QLabel(i18n("Global language:"), languageContainer);
 
     m_globalLanguage = new QComboBox( languageContainer );
-    m_globalLanguage->insertStringList( KoGlobal::listOfLanguages());
-
-
-    m_globalLanguage->setCurrentItem(KoGlobal::languageIndexFromTag(doc->globalLanguage()));
+    m_globalLanguage->insertStringList( KoGlobal::listOfLanguages() );
+    m_globalLanguage->setCurrentText( KoGlobal::languageFromTag( doc->globalLanguage() ) );
 
     languageLayout->addWidget(languageTitle, 0, 0);
     languageLayout->addWidget(m_globalLanguage, 0, 1);
@@ -669,10 +664,10 @@ configureDefaultDocPage::configureDefaultDocPage(KPresenterView *_view, QWidget
     new QLabel(i18n("Tab stop (%1):").arg(doc->getUnitName()), gbDocumentSettings);
     m_tabStopWidth = new KDoubleNumInput( gbDocumentSettings );
     m_oldTabStopWidth = doc->tabStopValue();
-    KoRect rect = doc->stickyPage()->getPageRect();
+    KoRect rect = doc->masterPage()->getPageRect();
 
-    m_tabStopWidth->setRange( KoUnit::ptToUnit( MM_TO_POINT(2),doc->getUnit() ) , KoUnit::ptToUnit( rect.width(), doc->getUnit() ) , 0.1, false);
-    m_tabStopWidth->setValue( KoUnit::ptToUnit( m_oldTabStopWidth, doc->getUnit() ));
+    m_tabStopWidth->setRange( KoUnit::toUserValue( MM_TO_POINT(2),doc->getUnit() ) , KoUnit::toUserValue( rect.width(), doc->getUnit() ) , 0.1, false);
+    m_tabStopWidth->setValue( KoUnit::toUserValue( m_oldTabStopWidth, doc->getUnit() ));
     box->addWidget(gbDocumentSettings);
     QVGroupBox* gbDocumentCursor = new QVGroupBox( i18n("Cursor"), this );
     gbDocumentCursor->setMargin( KDialog::marginHint() );
@@ -730,10 +725,10 @@ KCommand *configureDefaultDocPage::apply()
 
     //Laurent Todo add a message box to inform user that
     //global language will change after re-launch kword
-    QString lang = KoGlobal::tagOfLanguage( m_globalLanguage->currentText() );
+    const QString lang = KoGlobal::tagOfLanguage( m_globalLanguage->currentText() );
     config->writeEntry( "language" , lang);
     m_oldLanguage = lang;
-    //don't call this fiunction otherwise we can have a textobject with
+    //don't call this function otherwise we can have a textobject with
     // a default language and other textobject with other default language.
     //doc->setGlobalLanguage( lang );
 
@@ -752,7 +747,7 @@ KCommand *configureDefaultDocPage::apply()
         macro->addCommand( cmd);
         m_oldStartingPage=newStartingPage;
     }
-    double newTabStop = KoUnit::ptFromUnit( m_tabStopWidth->value(), doc->getUnit() );
+    double newTabStop = KoUnit::fromUserValue( m_tabStopWidth->value(), doc->getUnit() );
     if ( newTabStop != m_oldTabStopWidth)
     {
         if ( !macro )
@@ -770,10 +765,10 @@ void configureDefaultDocPage::slotDefault()
     autoSave->setValue( m_pView->kPresenterDoc()->defaultAutoSave()/60 );
     m_variableNumberOffset->setValue(1);
     m_cursorInProtectedArea->setChecked(true);
-    m_tabStopWidth->setValue(KoUnit::ptToUnit( MM_TO_POINT(15), m_pView->kPresenterDoc()->getUnit()));
+    m_tabStopWidth->setValue(KoUnit::toUserValue( MM_TO_POINT(15), m_pView->kPresenterDoc()->getUnit()));
     m_createBackupFile->setChecked( true );
     m_directInsertCursor->setChecked( false );
-    m_globalLanguage->setCurrentItem(KoGlobal::languageIndexFromTag(KGlobal::locale()->language()));
+    m_globalLanguage->setCurrentText( KoGlobal::languageFromTag( KGlobal::locale()->language() ) );
     m_autoHyphenation->setChecked( false );
 }
 
@@ -803,37 +798,41 @@ configureToolsPage::configureToolsPage( KPresenterView *_view, QWidget *parent,
 
     QTabWidget *tab = new QTabWidget(this);
 
-    m_confPenDia = new ConfPenDia(tab, 0, StyleDia::SdAll);
-    m_confPenDia->setPen(m_pView->getPen());
-    m_confPenDia->setLineBegin(m_pView->getLineBegin());
-    m_confPenDia->setLineEnd(m_pView->getLineEnd());
-    tab->addTab(m_confPenDia, i18n("&Pen"));
+    PenCmd::Pen pen( m_pView->getPen(), m_pView->getLineBegin(), m_pView->getLineEnd() );
+    m_confPenDia = new PenStyleWidget(tab, 0, pen, true );
+    tab->addTab( m_confPenDia, i18n( "Outl&ine" ) );
 
-    m_confBrushDia = new ConfBrushDia(tab, 0, StyleDia::SdAll);
-    m_confBrushDia->setBrush(m_pView->getBrush());
-    m_confBrushDia->setFillType(m_pView->getFillType());
-    m_confBrushDia->setGradient(m_pView->getGColor1(), m_pView->getGColor2(), m_pView->getGType(),
-                                m_pView->getGUnbalanced(), m_pView->getGXFactor(), m_pView->getGYFactor());
-    tab->addTab(m_confBrushDia, i18n("&Brush"));
+    BrushCmd::Brush brush( m_pView->getBrush(),
+                           m_pView->getGColor1(),
+                           m_pView->getGColor2(),
+                           m_pView->getGType(),
+                           m_pView->getFillType(),
+                           m_pView->getGUnbalanced(),
+                           m_pView->getGXFactor(),
+                           m_pView->getGYFactor() );
+    m_brushProperty = new BrushProperty( this, 0, brush );
+    tab->addTab( m_brushProperty, i18n( "&Fill" ) );
 
-    m_confPieDia = new ConfPieDia(tab, "ConfPieDia");
-    m_confPieDia->setType(m_pView->getPieType());
-    m_confPieDia->setAngle(m_pView->getPieAngle());
-    m_confPieDia->setLength(m_pView->getPieLength());
-    m_confPieDia->setPenBrush(m_pView->getPen(), m_pView->getBrush());
-    tab->addTab(m_confPieDia, i18n("P&ie"));
+    RectValueCmd::RectValues rectValues;
+    rectValues.xRnd = m_pView->getRndX();
+    rectValues.yRnd = m_pView->getRndY();
+    m_rectProperty = new RectProperty( this, 0, rectValues );
+    tab->addTab( m_rectProperty, i18n( "&Rectangle" ) );
 
-    m_confPolygonDia = new ConfPolygonDia(tab, "ConfPolygonDia");
-    m_confPolygonDia->setCheckConcavePolygon(m_pView->getCheckConcavePolygon());
-    m_confPolygonDia->setCornersValue(m_pView->getCornersValue());
-    m_confPolygonDia->setSharpnessValue(m_pView->getSharpnessValue());
-    m_confPolygonDia->setPenBrush(m_pView->getPen(), m_pView->getBrush());
-    tab->addTab(m_confPolygonDia, i18n("P&olygon"));
+    PolygonSettingCmd::PolygonSettings polygonSettings;
+    polygonSettings.checkConcavePolygon = m_pView->getCheckConcavePolygon();
+    polygonSettings.cornersValue = m_pView->getCornersValue();
+    polygonSettings.sharpnessValue = m_pView->getSharpnessValue();
+    m_polygonProperty = new PolygonProperty( this, 0, polygonSettings );
+    tab->addTab( m_polygonProperty, i18n( "Polygo&n" ) );
+
+    PieValueCmd::PieValues pieValues;
+    pieValues.pieType = m_pView->getPieType();
+    pieValues.pieAngle = m_pView->getPieAngle();
+    pieValues.pieLength = m_pView->getPieLength();
+    m_pieProperty = new PieProperty( this, 0, pieValues );
+    tab->addTab( m_pieProperty, i18n( "&Pie" ) );
 
-    m_confRectDia = new ConfRectDia(tab, "ConfRectDia" );
-    m_confRectDia->setRnds(m_pView->getRndX(), m_pView->getRndY());
-    m_confRectDia->setPenBrush(m_pView->getPen(), m_pView->getBrush());
-    tab->addTab(m_confRectDia, i18n("&Rectangle"));
     box->addWidget(tab);
 }
 
@@ -843,52 +842,68 @@ configureToolsPage::~configureToolsPage()
 
 void configureToolsPage::apply()
 {
-    m_pView->setPieType(m_confPieDia->getType());
-    m_pView->setPieAngle(m_confPieDia->getAngle());
-    m_pView->setPieLength(m_confPieDia->getLength());
-    m_pView->setCheckConcavePolygon(m_confPolygonDia->getCheckConcavePolygon());
-    m_pView->setCornersValue(m_confPolygonDia->getCornersValue());
-    m_pView->setSharpnessValue(m_confPolygonDia->getSharpnessValue());
-    m_pView->setRndX(m_confRectDia->getRndX());
-    m_pView->setRndY(m_confRectDia->getRndY());
-    m_pView->setPen(m_confPenDia->getPen());
-    m_pView->setBrush(m_confBrushDia->getBrush());
-    m_pView->setLineBegin(m_confPenDia->getLineBegin());
-    m_pView->setLineEnd(m_confPenDia->getLineEnd());
-    m_pView->setFillType(m_confBrushDia->getFillType());
-    m_pView->setGColor1(m_confBrushDia->getGColor1());
-    m_pView->setGColor2(m_confBrushDia->getGColor2());
-    m_pView->setGType(m_confBrushDia->getGType());
-    m_pView->setGUnbalanced(m_confBrushDia->getGUnbalanced());
-    m_pView->setGXFactor(m_confBrushDia->getGXFactor());
-    m_pView->setGYFactor(m_confBrushDia->getGYFactor());
-    m_pView->getActionBrushColor()->setCurrentColor((m_confBrushDia->getBrush()).color());
-    m_pView->getActionPenColor()->setCurrentColor((m_confPenDia->getPen()).color());
-    m_confRectDia->setPenBrush(m_confPenDia->getPen(),
-                               m_confBrushDia->getBrush());
-    m_confPolygonDia->setPenBrush(m_confPenDia->getPen(),
-                                  m_confBrushDia->getBrush());
-    m_confPieDia->setPenBrush(m_confPenDia->getPen(),
-                              m_confBrushDia->getBrush());
+    PenCmd::Pen pen = m_confPenDia->getPen();
+    m_pView->setPen( pen.pen );
+    m_pView->setLineBegin( pen.lineBegin );
+    m_pView->setLineEnd( pen.lineEnd );
+    m_pView->getActionPenColor()->setCurrentColor( pen.pen.color() );
+
+    BrushCmd::Brush brush = m_brushProperty->getBrush();
+    m_pView->setBrush( brush.brush );
+    m_pView->setFillType( brush.fillType );
+    m_pView->setGColor1( brush.gColor1 );
+    m_pView->setGColor2( brush.gColor2 );
+    m_pView->setGType( brush.gType );
+    m_pView->setGUnbalanced( brush.unbalanced );
+    m_pView->setGXFactor( brush.xfactor );
+    m_pView->setGYFactor( brush.yfactor );
+    m_pView->getActionBrushColor()->setCurrentColor( brush.brush.color() );
+
+    RectValueCmd::RectValues rectValues = m_rectProperty->getRectValues();
+    m_pView->setRndX( rectValues.xRnd );
+    m_pView->setRndY( rectValues.yRnd );
+
+    PolygonSettingCmd::PolygonSettings polygonSettings = m_polygonProperty->getPolygonSettings();
+    m_pView->setCheckConcavePolygon( polygonSettings.checkConcavePolygon );
+    m_pView->setCornersValue( polygonSettings.cornersValue );
+    m_pView->setSharpnessValue( polygonSettings.sharpnessValue );
+
+    PieValueCmd::PieValues pieValues = m_pieProperty->getPieValues();
+    m_pView->setPieType( pieValues.pieType );
+    m_pView->setPieAngle( pieValues.pieAngle );
+    m_pView->setPieLength( pieValues.pieLength );
+
+    //TODO set pen brush in m_rectProperty
+    //TODO set pen brush in m_polygonProperty
+    //TODO set pen brush in m_pieProperty
 }
 
 void configureToolsPage::slotDefault()
 {
-    m_confPieDia->setType(PT_PIE);
-    m_confPieDia->setLength(90 * 16);
-    m_confPieDia->setAngle(45 * 16);
-    m_confPolygonDia->setCheckConcavePolygon(false);
-    m_confPolygonDia->setCornersValue(3);
-    m_confPolygonDia->setSharpnessValue(0);
-    m_confRectDia->setRnds(0, 0);
-    m_confPenDia->setPen(QPen(black, 1, SolidLine));
-    m_confBrushDia->setBrush(QBrush(white, SolidPattern));
-    m_confPenDia->setLineBegin(L_NORMAL);
-    m_confPenDia->setLineEnd(L_NORMAL);
-    m_confBrushDia->setGradient(red, green, BCT_GHORZ, false, 100, 100);
-    m_confBrushDia->setFillType(FT_BRUSH);
-    m_pView->getActionBrushColor()->setCurrentColor((m_confBrushDia->getBrush()).color());
-    m_pView->getActionPenColor()->setCurrentColor((m_confPenDia->getPen()).color());
+    PenCmd::Pen pen( QPen(black, 1, SolidLine), L_NORMAL, L_NORMAL );
+    m_confPenDia->setPen( pen );
+    m_pView->getActionPenColor()->setCurrentColor( pen.pen.color() );
+
+    BrushCmd::Brush brush( QBrush( white, SolidPattern ), red, green,
+                           BCT_GHORZ, FT_BRUSH, false, 100, 100 );
+    m_brushProperty->setBrush( brush );
+    m_pView->getActionBrushColor()->setCurrentColor( brush.brush.color() );
+
+    RectValueCmd::RectValues rectValues;
+    rectValues.xRnd = 0;
+    rectValues.yRnd = 0;
+    m_rectProperty->setRectValues( rectValues );
+
+    PolygonSettingCmd::PolygonSettings polygonSettings;
+    polygonSettings.checkConcavePolygon = false;
+    polygonSettings.cornersValue = 3;
+    polygonSettings.sharpnessValue = 0;
+    m_polygonProperty->setPolygonSettings( polygonSettings );
+
+    PieValueCmd::PieValues pieValues;
+    pieValues.pieType = PT_PIE;
+    pieValues.pieAngle = 45 * 16;
+    pieValues.pieLength = 90 * 16;
 }
 
 configurePathPage::configurePathPage( KPresenterView *_view, QWidget *parent, char *name )
