@@ -20,6 +20,18 @@
 
 #include "kpresenter_utils.h"
 
+#include "kpobject.h"
+#include "kpgroupobject.h"
+#include "kpfreehandobject.h"
+#include "kppolylineobject.h"
+#include "kpquadricbeziercurveobject.h"
+#include "kpcubicbeziercurveobject.h"
+#include "kppieobject.h"
+
+#include <koxmlns.h>
+#include <kozoomhandler.h>
+#include <koPoint.h>
+
 #include <qpainter.h>
 #include <qpointarray.h>
 #include <qpoint.h>
@@ -27,8 +39,8 @@
 #include <qsize.h>
 #include <qbitmap.h>
 #include <qcursor.h>
-#include <kozoomhandler.h>
-#include <koPoint.h>
+#include <qdatetime.h>
+#include <qdom.h>
 
 void drawFigure( LineEnd figure, QPainter* painter, const KoPoint &coord, const QColor &color,
                  int _w, float angle, KoZoomHandler* _zoomHandler)
@@ -157,6 +169,18 @@ void drawFigureWithOffset( LineEnd figure, QPainter* painter, const QPoint &coor
     drawFigure( figure, painter, offsetPoint, color, _w, angle,_zoomHandler );
 }
 
+void drawFigureWithOffset( LineEnd figure, QPainter* painter, const KoPoint &coord, const QColor &color,
+                           int w, float angle, KoZoomHandler*_zoomHandler, bool begin )
+{
+    KoSize diff = getOffset( figure, w, angle );
+    KoPoint offsetPoint(diff.width(), diff.height());
+    double offsetAngle = angle + ( begin ? 90.0 : -90.0 );
+    KoPoint lineOffset( w * cos( offsetAngle * M_PI / 180.0 ) / 2,
+                        w * sin( offsetAngle * M_PI / 180.0 ) / 2 );
+    offsetPoint += coord + lineOffset;
+    drawFigure( figure, painter, offsetPoint, color, w, angle,_zoomHandler );
+}
+
 KoSize getBoundingSize( LineEnd figure, int _w, const KoZoomHandler*_zoomHandler )
 {
     switch ( figure )
@@ -277,6 +301,40 @@ LineEnd lineEndBeginFromString( const QString & type )
     return L_NORMAL;
 }
 
+QString lineEndBeginSvg( LineEnd element )
+{
+    QString str;
+    switch( element )
+    {
+    case L_NORMAL:
+        //nothing
+        break;
+    case L_ARROW:
+        str = "m10 0-10 30h20z";
+        break;
+    case L_SQUARE:
+        str =  "m0 0h10v10h-10z";
+        break;
+    case L_CIRCLE:
+        str = "m462 1118-102-29-102-51-93-72-72-93-51-102-29-102-13-105 13-102 29-106 51-102 72-89 93-72 102-50 102-34 106-9 101 9 106 34 98 50 93 72 72 89 51 102 29 106 13 102-13 105-29 102-51 102-72 93-93 72-98 51-106 29-101 13z";
+        break;
+    case L_LINE_ARROW:
+        str = "m0 2108v17 17l12 42 30 34 38 21 43 4 29-8 30-21 25-26 13-34 343-1532 339 1520 13 42 29 34 39 21 42 4 42-12 34-30 21-42v-39-12l-4 4-440-1998-9-42-25-39-38-25-43-8-42 8-38 25-26 39-8 42z";
+        break;
+    case L_DIMENSION_LINE:
+        str = "m0 0h278 278 280v36 36 38h-278-278-280v-36-36z";
+        break;
+    case L_DOUBLE_ARROW:
+        str = "m737 1131h394l-564-1131-567 1131h398l-398 787h1131z";
+        break;
+    case L_DOUBLE_LINE_ARROW:
+        //this define is not good I don't know how to define it.
+        str = "m0 11h312 312h122z";
+        break;
+    }
+    return str;
+}
+
 KoPointArray getCloseObject( KoPointArray points, bool close, bool objClosed )
 {
     KoPointArray tmpPoints=points;
@@ -328,3 +386,78 @@ QCursor KPresenterUtils::rotateCursor()
 
     return QCursor( pix, 11, 13 );
 }
+
+QString saveOasisTimer( int second )
+{
+    QTime time;
+    time = time.addSecs( second );
+    QString hours( QString::number( time.hour() ).rightJustify( 2, '0' ) );
+    QString ms( QString::number( time.minute() ).rightJustify( 2, '0' ) );
+    QString sec( QString::number( time.second() ).rightJustify( 2, '0' ) );
+
+
+    //ISO8601 chapter 5.5.3.2
+    //QDate doesn't encode it as this format.
+    QString timeIso = QString( "PT%1H%2M%3S" ).arg( hours ).arg( ms ).arg( sec );
+    return timeIso;
+}
+
+int loadOasisTimer( const QString & timer )
+{
+    QString str( timer );
+    //convert date duration
+    int hour( str.mid( 2, 2 ).toInt() );
+    int minute( str.mid( 5, 2 ).toInt() );
+    int second( str.mid( 8, 2 ).toInt() );
+
+    return ( second + minute*60 + hour*60*60 );
+}
+
+
+int readOasisSettingsInt( const QDomElement & element )
+{
+    if ( element.hasAttributeNS( KoXmlNS::config, "type" ) )
+    {
+        QString type = element.attributeNS( KoXmlNS::config, "type", QString::null );
+        QString str = element.text();
+        bool b;
+        int value = str.toInt( &b );
+        return ( b ? value : 0 );
+    }
+    return 0;
+}
+
+double readOasisSettingsDouble( const QDomElement & element )
+{
+    if ( element.hasAttributeNS( KoXmlNS::config, "type" ) )
+    {
+        QString type = element.attributeNS( KoXmlNS::config, "type", QString::null );
+        QString str = element.text();
+        bool b;
+        double value = str.toDouble( &b );
+        return ( b ? value : 0 );
+    }
+    return 0.0;
+}
+
+bool readOasisSettingsBool( const QDomElement & element )
+{
+    if ( element.hasAttributeNS( KoXmlNS::config, "type" ) )
+    {
+        QString type = element.attributeNS( KoXmlNS::config, "type", QString::null );
+        QString str = element.text();
+        return ( str == "true" ? true : false );
+    }
+    return false;
+}
+
+QString readOasisSettingsString( const QDomElement & element )
+{
+    if ( element.hasAttributeNS( KoXmlNS::config, "type" ) )
+    {
+        QString type = element.attributeNS( KoXmlNS::config, "type", QString::null );
+        QString str = element.text();
+        return str;
+    }
+    return QString::null;
+}
