@@ -32,7 +32,7 @@ static const KCmdLineOptions options[]=
 	KCmdLineLastOption
 };
 
-int main( int argc, char **argv )
+extern "C" KPRESENTER_EXPORT int kdemain( int argc, char **argv )
 {
     KCmdLineArgs::init( argc, argv, newKPresenterAboutData() );
     KCmdLineArgs::addCmdLineOptions( options );
