@@ -1,14 +1,47 @@
-#ifndef __kspread_canvas_h__
-#define __kspread_canvas_h__
+/* This file is part of the KDE project
+
+   Copyright 1999-2002,2004 Laurent Montel <montel@kde.org>
+   Copyright 2002-2005 Ariya Hidayat <ariya@kde.org>
+   Copyright 1999-2001,2003 David Faure <faure@kde.org>
+   Copyright 2001-2003 Philipp Mueller <philipp.mueller@gmx.de>
+   Copyright 2002-2003 Norbert Andres <nandres@web.de>
+   Copyright 2000-2001 Werner Trobin <trobin@kde.org>
+   Copyright 2002 Harri Porten <porten@kde.org>
+   Copyright 2002 John Dailey <dailey@vt.edu>
+   Copyright 1999-2000 Torben Weis <weis@kde.org>
+   Copyright 2000 Wilco Greven <greven@kde.org>
+   Copyright 1999 Boris Wedl <boris.wedl@kfunigraz.ac.at>
+   Copyright 1999 Reginald Stadlbauer <reggie@kde.org>
+
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
+
+#ifndef KSPREAD_CANVAS
+#define KSPREAD_CANVAS
 
 #include <qlineedit.h>
 #include <qtooltip.h>
 #include <qpen.h>
 
 #include <koQueryTrader.h>
-#include <kspread_view.h>
-#include <kspread_doc.h>
-#include "kspread_selection.h"
+#include <koRect.h>
+
+#include "kspread_util.h"
+
+#include <koffice_export.h>
 
 class KSpreadEditWidget;
 class KSpreadCanvas;
@@ -18,76 +51,33 @@ class KSpreadSheet;
 class KSpreadDoc;
 class KSpreadPoint;
 class KSpreadRange;
+class KSpreadView;
+class KSpreadSelection;
 class KSpreadCellEditor;
 class KSpreadCell;
 class QWidget;
 class QTimer;
-
+class QButton;
+class KSpreadLocationEditWidget;
+class KSpreadComboboxLocationEditWidget;
 class QPainter;
 class QLabel;
+class QScrollBar;
 
 #define YBORDER_WIDTH 50
 #define XBORDER_HEIGHT 20
 
-
- /**
- * A widget that allows the user to enter an arbitrary
- * cell location to goto or cell selection to highlight
- */
-class KSpreadLocationEditWidget : public QLineEdit
-{
-	Q_OBJECT
-public:
-	KSpreadLocationEditWidget( QWidget *_parent, KSpreadView * _canvas );
-
-protected:
-	virtual void keyPressEvent( QKeyEvent * _ev );
-private:
-	KSpreadView * m_pView;
-signals:
-	void gotoLocation( int, int );
-};
-
-/**
- * The widget that appears above the table and allows to
- * edit the cells content.
- */
-class KSpreadEditWidget : public QLineEdit
-{
-    Q_OBJECT
-public:
-    KSpreadEditWidget( QWidget *parent, KSpreadCanvas *canvas,
-                       QButton *cancelButton, QButton *okButton);
-
-    virtual void setText( const QString& t );
-
-    // Go into edit mode (enable the buttons)
-    void setEditMode( bool mode );
-
-    void showEditWidget(bool _show);
-public slots:
-    void slotAbortEdit();
-    void slotDoneEdit();
-
-protected:
-    virtual void keyPressEvent ( QKeyEvent* _ev );
-    virtual void focusOutEvent( QFocusEvent* ev );
-
-private:
-    QButton* m_pCancelButton;
-    QButton* m_pOkButton;
-    KSpreadCanvas* m_pCanvas;
-};
+class CanvasPrivate;
 
 /**
  * The canvas builds a part of the GUI of KSpread.
  * It contains the borders, scrollbars,
- * editwidget and of course it displays the table.
+ * editwidget and of course it displays the sheet.
  * Especially most of the user interface logic is implemented here.
  * That means that this class knows what to do when a key is pressed
  * or if the mouse button was clicked.
  */
-class KSpreadCanvas : public QWidget
+class KSPREAD_EXPORT KSpreadCanvas : public QWidget
 {
     friend class KSpreadHBorder;
     friend class KSpreadVBorder;
@@ -102,8 +92,11 @@ public:
     enum MouseActions { NoAction = 0, Mark = 1, ResizeCell = 2, AutoFill = 3 };
     enum EditorType { CellEditor, FormulaEditor, EditWidget };
 
-    KSpreadCanvas( QWidget *_parent, KSpreadView *_view, KSpreadDoc* _doc );
+    KSpreadCanvas (KSpreadView *_view);
     ~KSpreadCanvas( );
+    
+    KSpreadView* view();
+    KSpreadDoc* doc();
 
     /**
      * Called from @ref KSpreadView to complete the construction. Has to
@@ -111,7 +104,8 @@ public:
      */
     void init();
 
-    KSpreadCellEditor* editor() const { return m_pEditor ; }
+    KSpreadEditWidget* editWidget() const;
+    KSpreadCellEditor* editor() const;
 
 
   /**
@@ -120,9 +114,9 @@ public:
      * For example the user selects "Sheet1!A1:B2" then this function
      * returns 12.
      */
-    int chooseTextLen() const { return length_namecell; }
+    int chooseTextLen() const;
 
-    KSpreadSelection* selectionInfo() const {return m_pView->selectionInfo();}
+    KSpreadSelection* selectionInfo() const;
     QRect selection() const;
     QPoint marker() const;
     int markerColumn() const;
@@ -131,26 +125,26 @@ public:
     void updateCellRect( const QRect &_rect );
     void updateSelection( const QRect& oldSelection, const QPoint& oldMarker );
 
-    const QPen& defaultGridPen() const { return m_defaultGridPen; }
+    const QPen& defaultGridPen() const;
 
-    double zoom() const { return m_pView->zoom(); }
+    double zoom() const;
 
     /**
      * Returns the width of the columns before the current screen
      */
-    double xOffset() const { return m_dXOffset; }
+    double xOffset() const;
     /**
      * Returns the height of the rows before the current screen
      */
-    double yOffset() const { return m_dYOffset; }
+    double yOffset() const;
 
     /**
      * Return a rect indicating which cell range is currently visible onscreen
      */
     QRect visibleCells();
 
-    KSpreadSheet* activeTable() const;
-    KSpreadSheet* findTable( const QString& _name ) const;
+    KSpreadSheet* activeSheet() const;
+    KSpreadSheet* findSheet( const QString& _name ) const;
 
     /**
      * A convenience function.
@@ -163,11 +157,11 @@ public:
 
     /**
      * Move the cursor to the specified cell. This may include switching
-     * the table. In addition @ref #KSpreadView::updateEditWidget is called.
+     * the sheet. In addition @ref #KSpreadView::updateEditWidget is called.
      *
      * @param location the cell to move to
      *
-     * @param table the table to move to.  If NULL, the active table is used
+     * @param sheet the sheet to move to.  If NULL, the active sheet is used
 
      * @param extendSelection determines wether this move of the marker is part
      *                        of a selection, that means: The user holds the
@@ -177,15 +171,15 @@ public:
      *                        selected, and the selection anchor will be reset
      *                        to this cell.
      */
-    void gotoLocation( QPoint const & location, KSpreadSheet* table = NULL,
+    void gotoLocation( QPoint const & location, KSpreadSheet* sheet = NULL,
                        bool extendSelection = false);
 
     /**
      * convenience function
      */
-    void gotoLocation( int col, int row, KSpreadSheet* table = NULL,
+    void gotoLocation( int col, int row, KSpreadSheet* sheet = NULL,
                        bool extendSelection = false)
-    {gotoLocation(QPoint(col, row), table, extendSelection);}
+    {gotoLocation(QPoint(col, row), sheet, extendSelection);}
 
 
     /**
@@ -223,7 +217,7 @@ public:
      * But somehow KSpreadCanvas must know whether the EditWidget or the CellEditor
      * lost the focus when the user clicked on the canvas.
      */
-    void setLastEditorWithFocus( EditorType type ) { m_focusEditorType = type; }
+    void setLastEditorWithFocus( EditorType type );
 
     /**
      * Switches to choose mode and sets the initial selection to the
@@ -236,7 +230,7 @@ public:
     void startChoose( const QRect& selection );
     void endChoose();
 
-    bool chooseMode(){ return m_bChoose; }
+    bool chooseMode() const;
 
     /**
     * Adjust a area in height and width
@@ -252,14 +246,11 @@ public:
 
     // Created by the view since it's layout is managed there,
     // but is in fact a sibling of the canvas, which needs to know about it.
-    void setEditWidget( KSpreadEditWidget * ew ) { m_pEditWidget = ew; }
-
-    KSpreadView* view()const { return m_pView; }
-    KSpreadDoc* doc()const { return m_pDoc; }
+    void setEditWidget( KSpreadEditWidget * ew );
 
     virtual bool focusNextPrevChild( bool );
 
-    bool chooseFormulaArea() const { return m_bChoose;}
+    bool chooseFormulaArea() const { return chooseMode();}
 
     /**
      * Depending on the offset in "zoomed" screen pixels
@@ -312,7 +303,6 @@ private:
     KSpreadVBorder* vBorderWidget() const;
     QScrollBar* horzScrollBar() const;
     QScrollBar* vertScrollBar() const;
-    KSpreadEditWidget* editWidget() const { return m_pEditWidget; }
 
     void drawChooseMarker( );
     void drawChooseMarker( const QRect& );
@@ -330,7 +320,7 @@ private:
     /**
      * @see #setLastEditorWithFocus
      */
-    EditorType lastEditorWithFocus() const { return m_focusEditorType; }
+    EditorType lastEditorWithFocus() const;
 
     /**
      * Hides the marker. Hiding it multiple times means that it has to be shown ( using @ref #showMarker ) multiple times
@@ -341,85 +331,6 @@ private:
 
     // void drawMarker( QPainter * _painter = 0L );
 
-    bool choose_visible;
-    int  length_namecell;
-    int  length_text;
-
-    KSpreadView *m_pView;
-    KSpreadDoc* m_pDoc;
-    QTimer * m_scrollTimer;
-
-    /**
-     * If the user is dragging around with the mouse then this tells us what he is doing.
-     * The user may want to mark cells or he started in the lower right corner
-     * of the marker which is something special. The values for the 2 above
-     * methods are called 'Mark' and 'ResizeCell' or 'AutoFill' depending
-     * on the mouse button used. By default this variable holds
-     * the value 'NoAction'.
-     */
-    MouseActions m_eMouseAction;
-
-    /**
-     * Used to indicate whether the user started drawing a rubber band rectangle.
-     */
-    bool m_bGeometryStarted;
-    QPoint m_ptGeometryStart;
-    QPoint m_ptGeometryEnd;
-
-
-    /**
-     * True when the mouse button is pressed
-     */
-    bool m_bMousePressed;
-
-    /**
-     * If we use the lower right corner of the marker to start autofilling, then this
-     * rectangle conatins all cells that were already marker when the user started
-     * to mark the rectangle which he wants to become autofilled.
-     *
-     * @see #mousePressEvent
-     * @see #mouseReleeaseEvent
-     */
-    QRect m_rctAutoFillSrc;
-
-    /**
-     * If the mouse is over some anchor ( in the sense of HTML anchors )
-     * then this one is stored here.
-     */
-    QString m_strAnchor;
-
-    /**
-     * Non visible range left from current screen
-     * Example:
-     * If the first visible column is 'E', then m_dXOffset stores
-     * the width of the invisible columns 'A' to 'D'.
-     */
-    double m_dXOffset;
-
-    /**
-     * Non visible range on top of the current screen
-     * Example:
-     * If the first visible row is '5', then m_dYOffset stores
-     * the height of the invisible rows '1' to '4'.
-     */
-    double m_dYOffset;
-
-    /**
-     * Start coordinates for drag and drop
-     */
-    QPoint m_dragStart;
-    bool   m_dragging;
-
-    KSpreadLocationEditWidget *m_pPosWidget;
-    KSpreadEditWidget *m_pEditWidget;
-    KSpreadCellEditor *m_pEditor;
-
-    /**
-     * Used to draw the grey grid that is usually only visible on the
-     * screen, but not by printing on paper.
-     */
-    QPen m_defaultGridPen;
-
     // int m_iMarkerColumn;
     // int m_iMarkerRow;
     /**
@@ -432,26 +343,6 @@ private:
     // int m_iMarkerVisible;
 
 
-    /**
-     * Is true if the user is to choose a cell.
-     *
-     * @see #startChoose
-     * @see #endChoose
-     * @see KSpreadAssistant2
-     */
-    bool m_bChoose;
-    /**
-     * If a choose selection is started (@ref #startChoose) the current
-     * table is saved here.
-     */
-    KSpreadSheet* m_chooseStartTable;
-
-    /**
-     * @see #setLastEditorWithFocus
-     * @see #lastEditorWithFocus
-     */
-    EditorType m_focusEditorType;
-
 private:
 
   void startTheDrag();
@@ -475,13 +366,10 @@ private:
 
 
   bool formatKeyPress( QKeyEvent * _ev );
-  double getDouble( KSpreadCell * cell );
-  void convertToDouble( KSpreadCell * cell );
-  void convertToPercent( KSpreadCell * cell );
-  void convertToMoney( KSpreadCell * cell );
-  void convertToTime( KSpreadCell * cell );
-  void convertToDate( KSpreadCell * cell );
-
+  
+  /** helper method for formatKeyPress */
+  bool formatCellByKey (KSpreadCell *cell, int key, const QRect &rect);
+  
   void processClickSelectionHandle(QMouseEvent *event);
   void processLeftClickAnchor();
 
@@ -494,6 +382,9 @@ private:
    */
   void extendCurrentSelection(QPoint cell);
 
+  /** current cursor position, be it marker of choose marker */
+  QPoint cursorPos ();
+  
   /**
    * returns the rect that needs to be redrawn
    */
@@ -512,6 +403,8 @@ private:
   void processOtherKey(QKeyEvent *event);
   bool processControlArrowKey(QKeyEvent *event);
 
+  void processIMEvent( QIMEvent * event );
+
   void updateChooseRect(const QPoint &newMarker, const QPoint &newAnchor);
 
   /**
@@ -523,6 +416,10 @@ private:
    */
   void setSelectionChangePaintDirty(KSpreadSheet* sheet,
                                     QRect area1, QRect area2);
+
+private:
+  CanvasPrivate* d;
+
 };
 
 /**
@@ -540,6 +437,8 @@ public:
     void equalizeColumn( double resize );
 
     void updateColumns( int from, int to );
+    
+    QSize sizeHint() const;
 
 private slots:
     void doAutoScroll();
@@ -552,6 +451,7 @@ protected:
     virtual void mouseMoveEvent( QMouseEvent* _ev );
     virtual void wheelEvent( QWheelEvent* );
     virtual void focusOutEvent( QFocusEvent* ev );
+    virtual void resizeEvent( QResizeEvent * _ev );
     void paintSizeIndicator( int mouseX, bool firstTime );
 
 private:
@@ -622,6 +522,8 @@ public:
     void equalizeRow( double resize );
     void updateRows( int from, int to );
 
+    QSize sizeHint() const;
+
 private slots:
     void doAutoScroll();
 
@@ -674,4 +576,4 @@ private:
     KSpreadCanvas* m_canvas;
 };
 
-#endif
+#endif // KSPREAD_CANVAS
