@@ -27,8 +27,9 @@ DESCRIPTION
     (one for each cell).
 */
 
-#include <kwframe.h>
-#include <kwtextframeset.h>
+#include "kwframe.h"
+#include "kwtextframeset.h"
+
 #include <qptrlist.h>
 #include <qvaluevector.h>
 #include <qobject.h>
@@ -43,10 +44,9 @@ class KWordFrameSetIface;
 
 class RemovedRow;
 class RemovedColumn;
+
 /**
- * Class: KWTableFrameSet
- *
- * This class implements tables by acting as the manager for
+ * @brief This class implements tables by acting as the manager for
  * the frame(set)s which make up the table cells.
  *
  * We have a cell structure which contains one frameset, because
@@ -54,14 +54,15 @@ class RemovedColumn;
  * exactly one frame. Therefore the terms cell, frameSet and frame
  * can be used to describe the same thing: one table-cell
  */
-
-
 class KWTableFrameSet : public KWFrameSet
 {
     Q_OBJECT
 public:
 
-    // A cell can be any type of FrameSet, but for now, we only support text!
+    /**
+     * Table cell
+     * @note A cell can be any type of FrameSet, but for now, we only support text!
+     */
     class Cell : public KWTextFrameSet
     {
         unsigned int m_row, m_col;
@@ -133,7 +134,7 @@ public:
         bool isJoinedCell() const { return m_isJoinedCell; }
         void clearMark() { m_marker = false; }
         void setMark() { m_marker = true; }
-        bool marked() { return m_marker; }
+        bool marked() const { return m_marker; }
 
         /** Overloaded to not clear any preview borders. */
         void drawContents( QPainter *painter, const QRect & crect,
@@ -143,7 +144,7 @@ public:
     };
     friend class Cell;
 
-    // Represents a row, for direct access to cells with m_rowArray[row][column]
+    /// Represents a row, for direct access to cells with m_rowArray[row][column]
     class Row {
     public:
         Cell* operator[] ( uint i ) const { return i < size() ? m_cellArray[i] : 0; }
@@ -153,14 +154,36 @@ public:
         void addCell( Cell *cell );
         void removeCell( Cell* cell );
 
-        // Array of cells in the row. If a cell has m_cols = N, the N-1 following entries are 0.
-        // (Same thing is a cell from a row above has m_rows > 1)
+        /**
+         * @brief Array of cells in the row.
+         *
+         * If a cell has m_cols = N, N values in this array point to the same cell.
+         * (Same thing is a cell from a row above has m_rows > 1)
+         */
         QPtrVector< Cell > m_cellArray;
 
     };
 
     /** The three different types of TableIterators */
-    enum {VISIT_GRID = 1, VISIT_CELL = 2, CHECKED = 3};
+    enum VisitType {
+        /**
+         * This iterator visits each grid position once, ie every
+         * location in the m_rowArray rows. When some cells are joined, this
+         * iterator will visit those cells more than once.
+         */
+        VISIT_GRID = 1,
+
+        /**
+         * This iterator visits each cell in the table once, whether
+         * or not some of the cells are joined. If you want to visit all the cells
+         * fast and perform some read-only operation, this is the one to use.
+         */
+        VISIT_CELL = 2,
+        /**
+         * Like VISIT_CELL it also visits each cell once, but has some other benefits. Slower.
+         */
+        CHECKED = 3
+    };
 
     /**
       All the TableIterator templates are the same, except for the pre-increment
@@ -182,22 +205,26 @@ public:
       This includes m_rowArray, the Rows and Cells but not m_colPositions and
       m_rowPositions, as they are not used during the traversal.
       The conditions include:
-      ( A ) All positions in m_rowArray must be occupied by a valid cell, ie must
-      not be null.
-      ( B ) The Cell instance variables (m_row, m_rows, etc) must correctly
-      correspond to where the cells are in m_rowArray.
-      ( C ) The m_rows and m_cols instance variables of the table are also correct.
+      <UL>
+      <LI>( A ) All positions in m_rowArray must be occupied by a valid cell, ie must
+      not be null.</LI>
+      <LI>( B ) The Cell instance variables (m_row, m_rows, etc) must correctly
+      correspond to where the cells are in m_rowArray.</LI>
+      <LI>( C ) The m_rows and m_cols instance variables of the table are also correct.</LI>
+      </UL>
       Taken together, these conditions are pretty much equivalent to the
       validate() function passing. These conditions may not hold in the middle
       of a method when table data structures are being manipulated.
 
       This table shows what conditions are necessary for each type of iterator:
 
-                                      A      B      C
-      TableIterator<VISIT_GRID>    |  x   |      |  x   |
-      TableIterator<VISIT_CELL>    |  x   |  x   |  x   |
-      TableIterator<CHECKED>       |      |      |  x   |
-      MarkedIterator               |  x   |      |  x   |
+      <TABLE>
+      <TR><TD>                           </TD><TD>A</TD><TD>B</TD><TD>C</TD></TR>
+      <TR><TD>TableIterator\<VISIT_GRID\></TD><TD>x</TD><TD> </TD><TD>x</TD></TR>
+      <TR><TD>TableIterator\<VISIT_CELL\></TD><TD>x</TD><TD>x</TD><TD>x</TD></TR>
+      <TR><TD>TableIterator\<CHECKED\>   </TD><TD> </TD><TD> </TD><TD>x</TD></TR>
+      <TR><TD>MarkedIterator             </TD><TD>x</TD><TD> </TD><TD>x</TD></TR>
+      </TABLE>
 
       The only iterator that can be used when their are null positions in the
       table is the checked iterator.
@@ -271,15 +298,15 @@ public:
     /** The type of frameset. Use this to differentiate between different instantiations of
      *  the framesets. Each implementation will return a different frameType.
      */
-    virtual FrameSetType type() { return FT_TABLE; }
+    virtual FrameSetType type() const { return FT_TABLE; }
 
     virtual KWordFrameSetIface* dcopObject();
 
     virtual void addTextFrameSets( QPtrList<KWTextFrameSet> & lst, bool onlyReadWrite =false  );
 
-    // constructor
+    /// constructor
     KWTableFrameSet( KWDocument *_doc, const QString & name );
-    // destructor
+    /// destructor
     virtual ~KWTableFrameSet();
 
     virtual KWFrameSetEdit * createFrameSetEdit( KWCanvas * canvas );
@@ -293,15 +320,15 @@ public:
     virtual void drawContents( QPainter * painter, const QRect & crect,
                                const QColorGroup & cg, bool onlyChanged, bool resetChanged,
                                KWFrameSetEdit *edit, KWViewMode *viewMode );
-    // Dummy since we reimplement drawContents
+    /// Dummy since we reimplement drawContents
     virtual void drawFrame(KWFrame *, QPainter *, const QRect &, const QRect&,
                            const QPoint&,
                            KWFrame *, const QColorGroup &, bool, bool,
                            KWFrameSetEdit *, KWViewMode *, bool ) {}
 
     // Frameset management
-    Cell *getCell( unsigned int row, unsigned int col );
-    Cell *getCellByPos( double x, double y );
+    Cell *getCell( unsigned int row, unsigned int col ) const;
+    Cell *getCellByPos( double x, double y ) const;
 
     enum CellSize {
         TblAuto = 0,
@@ -379,12 +406,19 @@ public:
 
     /** move the whole of the table, this is mainly for anchored frames. */
     void moveBy( double dx, double dy );
-    /** point the outlines of all the cells */
+
+    // /** point the outlines of all the cells */
     //void drawAllRects( QPainter &p, int xOffset, int yOffset );
 
-    /** select all frames from the first selected to the argument frameset. */
+    /**
+     * @brief select all frames from the first selected to the argument frameset.
+     *
+     * the selectUntil method will select all frames from the first
+     * selected to the frame of the argument frameset.
+     */
     void selectUntil( Cell *cell );
-    /** convenience method */
+
+    /** @overload KWTableFrameSet::selectUntil */
     void selectUntil( double x, double y);
 
     bool getFirstSelected(unsigned int &row, unsigned int &col);
@@ -456,6 +490,11 @@ public:
 
     /** override save so we save in table style.. */
     virtual QDomElement save( QDomElement &parentElem, bool saveFrames = true );
+
+    virtual void saveOasis( KoXmlWriter&, KoSavingContext&, bool saveFrames ) const;
+    void loadOasis( const QDomElement& tag, KoOasisContext& context );
+    virtual bool canBeSavedAsInlineCharacter() const { return false; }
+
     /** load one cell */
     Cell* loadCell( QDomElement &frameElem, bool loadFrames = true, bool useNames = true );
 
@@ -463,7 +502,6 @@ public:
     virtual QDomElement toXML( QDomElement &parentElem, bool saveFrames = true );
     virtual void fromXML( QDomElement &framesetElem, bool loadFrames = true, bool useNames = true );
 
-    virtual void zoom( bool forPrint );
     //virtual void preparePrinting( QPainter *painter, QProgressDialog *progress, int &processedParags );
 
     /** Contribute to the document statistics */
@@ -522,7 +560,12 @@ public:
     */
     void setRightBorder(KoBorder newBorder);
 
-    KCommand *setProtectContent ( bool _protect );
+    KCommand *setProtectContentCommand ( bool _protect );
+
+    // The normal mechanism doesn't apply to tables; cells are protected individually
+    // (in terms of data; the GUI has an item for protecting all cells at once)
+    virtual void setProtectContent ( bool ) {}
+    virtual bool protectContent() const { return false; }
 
     virtual KWTextFrameSet* nextTextObject( KWFrameSet * );
     /**
@@ -530,7 +573,7 @@ public:
      */
     void setZOrder();
 
-    void convertTableToText();
+    QByteArray convertTableToText();
 
 #ifndef NDEBUG
     virtual void printDebug( KWFrame * frame );
@@ -540,14 +583,42 @@ public:
     static const uint m_sDefaultColWidth = 60;
 protected:
     /* Overloaded methods, look for docu in kwframe.h */
+    /// \overload KWFrameSet::deleteAnchors
     virtual void deleteAnchors();
-    virtual void createAnchors( KWTextParag * parag, int index, bool placeHolderExists = false, bool repaint = true );
-    void addCellToArray( Cell* cell );
+    /// \overload KWFrameSet::createAnchors
+    virtual void createAnchors( KoTextParag * parag, int index, bool placeHolderExists = false, bool repaint = true );
 
 private:
-    /** position an individual cell in the grid */
+    void addCellToArray( Cell* cell );
+    void afterLoadingCell( Cell* cell );
+    void parseInsideOfTable( const QDomElement& parent, KoOasisContext& context,
+                             const QMemArray<double> & columnLefts, uint& row, uint& column,
+                             double currentRowHeight );
+    void loadOasisCell( const QDomElement& element, KoOasisContext& context,
+                        const QMemArray<double> & columnLefts, uint row, uint column,
+                        double currentRowHeight );
+
+   /**
+     * @brief position an individual cell in the grid
+     *
+     * Adjusts the size of the cell frames.
+     * It computes the sizes based on:
+     * <ol>
+     * <li>The values in the m_colPositions and m_rowPositions arrays.
+     * <li>The width of the Cell borders.
+     * </ol>
+     */
     void position(Cell *theCell, bool setMinFrameHeight=false);
-    /** returns the absolute top-position of the row in the grid */
+
+    /**
+     * @brief Returns the absolute top-position of the row in the grid
+     *
+     * Returns a double value from m_rowPositions. This is either the bottom
+     * or top position of the row of cells @p row. Note that you cannot index
+     * directly into m_rowPositions from a row value obtained from a cell,
+     * eg cell->firstRow(), because of the extra elements in m_rowPositions when
+     * the table spans multiple pages.
+     */
     double getPositionOfRow(unsigned int row, bool bottom=false);
 
     void insertEmptyColumn(uint index);
@@ -563,6 +634,7 @@ private:
      */
     Row* removeRowVector(uint index);
 
+private:
     unsigned int m_rows, m_cols, m_nr_cells;
     bool m_showHeaderOnAllPages;
     bool m_hasTmpHeaders;
@@ -645,7 +717,7 @@ KWTableFrameSet::TableIterator<VisitStyle>::current() const {
 class RemovedRow {
 
     KWTableFrameSet::Row *m_row;
-    // The row index that this row used to occupy
+    /// The row index that this row used to occupy
     uint m_index;
     double m_rowHeight;
 
@@ -674,7 +746,9 @@ public:
 };
 
 /**
- * The object created to edit this table - in fact at a given moment,
+ * @brief The object created to edit this table
+ *
+ * In fact at a given moment,
  * it edits one cell (frameset) of the table, the one in which the cursor is.
  */
 class KWTableFrameSetEdit : public KWFrameSetEdit
@@ -708,19 +782,20 @@ public:
     virtual void dragMoveEvent( QDragMoveEvent * e, const QPoint &n, const KoPoint &d );
     virtual void dragLeaveEvent( QDragLeaveEvent * e )
     { if ( m_currentCell ) m_currentCell->dragLeaveEvent( e ); }
-    virtual void dropEvent( QDropEvent * e, const QPoint &n, const KoPoint &d )
-    { if ( m_currentCell ) m_currentCell->dropEvent( e, n, d ); } // TODO check current cell
+    virtual void dropEvent( QDropEvent * e, const QPoint &n, const KoPoint &d, KWView* view )
+    { if ( m_currentCell ) m_currentCell->dropEvent( e, n, d, view ); } // TODO check current cell
 
     virtual void focusInEvent() { if ( m_currentCell ) m_currentCell->focusInEvent(); }
     virtual void focusOutEvent() { if ( m_currentCell ) m_currentCell->focusOutEvent(); }
     virtual void copy() { if ( m_currentCell ) m_currentCell->copy(); }
     virtual void cut() { if ( m_currentCell ) m_currentCell->cut(); }
     virtual void paste() { if ( m_currentCell ) m_currentCell->paste(); }
-    // should selectAll select all cells ? etc.
+    /// \note should selectAll select all cells ? etc.
     virtual void selectAll() { if ( m_currentCell ) m_currentCell->selectAll(); }
 
-    // Set the cell which is currently being edited
+    /// Set the cell which is currently being edited
     void setCurrentCell( KWFrameSet * fs, bool eraseSelection=true );
+    /// Set the cell which is currently being edited
     void setCurrentCell( const KoPoint & dPoint );
 
     void showPopup( KWFrame* frame, KWView* view, const QPoint & _point );
