@@ -281,7 +281,7 @@ public:
     /**
      * Stores the given childrens dom in the element.
      */
-    void getChildrenDom(QDomDocument doc, QDomElement elem, uint from, uint to);
+    void getChildrenDom( QDomDocument& doc, QDomElement elem, uint from, uint to);
 
     /**
      * Builds elements from the given node and its siblings and
@@ -298,7 +298,7 @@ public:
 
     virtual QString formulaString();
 
-    virtual void writeMathML( QDomDocument doc, QDomNode parent );
+    virtual void writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat = false );
 
     /**
      * @returns the child at position i.
@@ -434,6 +434,8 @@ private:
     bool textSequence;
 
     static ElementCreationStrategy* creationStrategy;
+    
+    bool singlePipe; //The key '|' produces one '|' not '| |', '||' produces '| |'
 };
 
 
@@ -531,7 +533,7 @@ public:
      */
     static bool isValidSelection( FormulaCursor* cursor );
 
-    virtual void writeMathML( QDomDocument doc, QDomNode parent );
+    virtual void writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat = false );
 
 protected:
 
