@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (c) 2000 Simon Hausmann <hausmann@kde.org>
 
-   $Id: koDocumentInfoDlg.cc,v 1.36 2003/08/29 13:13:33 faure Exp $
+   $Id: koDocumentInfoDlg.cc 421021 2005-06-01 23:33:00Z fedemar $
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -40,6 +40,7 @@
 #include <kabc/stdaddressbook.h>
 #include <kdeversion.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 #include <ktar.h>
 #include <kdebug.h>
 #include <ktempfile.h>
@@ -65,7 +66,8 @@ public:
   QLineEdit *m_leAuthorTitle;
   QLineEdit *m_leCompany;
   QLineEdit *m_leEmail;
-  QLineEdit *m_leTelephone;
+  QLineEdit *m_leTelephoneWork;
+  QLineEdit *m_leTelephoneHome;
   QLineEdit *m_leFax;
   QLineEdit *m_leCountry;
   QLineEdit *m_lePostalCode;
@@ -75,8 +77,10 @@ public:
 
   QLineEdit *m_leDocTitle;
   QMultiLineEdit *m_meAbstract;
+    QLineEdit *m_leDocSubject;
+    QLineEdit *m_leDocKeywords;
+    QLineEdit *m_leAuthorPosition;
 
-  KConfig *m_emailCfg;
 
   bool m_bDeleteDialog;
   KDialogBase *m_dialog;
@@ -88,13 +92,6 @@ KoDocumentInfoDlg::KoDocumentInfoDlg( KoDocumentInfo *docInfo, QWidget *parent,
 {
   d = new KoDocumentInfoDlgPrivate;
   d->m_info = docInfo;
-  d->m_emailCfg = new KConfig( "emaildefaults", true );
-
-  d->m_emailCfg->setGroup( "Defaults" );
-
-  QString group = d->m_emailCfg->readEntry("Profile","Default");
-
-  d->m_emailCfg->setGroup(QString("PROFILE_%1").arg(group));
 
   d->m_dialog = dialog;
   d->m_bDeleteDialog = false;
@@ -123,8 +120,6 @@ KoDocumentInfoDlg::KoDocumentInfoDlg( KoDocumentInfo *docInfo, QWidget *parent,
 
 KoDocumentInfoDlg::~KoDocumentInfoDlg()
 {
-  delete d->m_emailCfg;
-
   if ( d->m_bDeleteDialog )
     delete d->m_dialog;
 
@@ -143,7 +138,6 @@ KDialogBase *KoDocumentInfoDlg::dialog() const
 
 void KoDocumentInfoDlg::loadFromKABC()
 {
-#if KDE_IS_VERSION( 3, 1, 90 )
   KABC::StdAddressBook *ab = static_cast<KABC::StdAddressBook*>
                              ( KABC::StdAddressBook::self() );
 
@@ -152,7 +146,11 @@ void KoDocumentInfoDlg::loadFromKABC()
 
   KABC::Addressee addr = ab->whoAmI();
   if ( addr.isEmpty() )
+  {
+    KMessageBox::sorry( 0L, i18n( "No personal contact data set, please use the option \
+                                  \"Set as Personal Contact Data\" from the \"Edit\" menu in KAddressbook to set one." ) );
     return;
+  }
 
   d->m_leFullName->setText( addr.formattedName() );
   d->m_leInitial->setText( addr.givenName()[ 0 ] + ". " +
@@ -162,7 +160,10 @@ void KoDocumentInfoDlg::loadFromKABC()
   d->m_leEmail->setText( addr.preferredEmail() );
 
   KABC::PhoneNumber phone = addr.phoneNumber( KABC::PhoneNumber::Home );
-  d->m_leTelephone->setText( phone.number() );
+  d->m_leTelephoneHome->setText( phone.number() );
+  phone = addr.phoneNumber( KABC::PhoneNumber::Work );
+  d->m_leTelephoneWork->setText( phone.number() );
+
   phone = addr.phoneNumber( KABC::PhoneNumber::Fax );
   d->m_leFax->setText( phone.number() );
 
@@ -173,7 +174,6 @@ void KoDocumentInfoDlg::loadFromKABC()
   d->m_leStreet->setText( a.street() );
 
   emit changed();
-#endif
 }
 
 void KoDocumentInfoDlg::addAuthorPage( KoDocumentInfoAuthor *authorInfo )
@@ -186,12 +186,6 @@ void KoDocumentInfoDlg::addAuthorPage( KoDocumentInfoAuthor *authorInfo )
   d->m_leFullName = new QLineEdit( authorInfo->fullName(), page );
   layout->addWidget( d->m_leFullName, 0, 1 );
 
-  if ( authorInfo->fullName().isNull() ) // only if null. Empty means the user made it explicitly empty.
-  {
-    QString name = d->m_emailCfg->readEntry( "FullName" );
-    if ( !name.isEmpty() )
-      d->m_leFullName->setText( name );
-  }
 
   layout->addWidget( new QLabel( i18n( "Initials:" ), page ), 1, 0 );
   d->m_leInitial = new QLineEdit( authorInfo->initial(), page );
@@ -201,54 +195,51 @@ void KoDocumentInfoDlg::addAuthorPage( KoDocumentInfoAuthor *authorInfo )
   d->m_leAuthorTitle = new QLineEdit( authorInfo->title(), page );
   layout->addWidget( d->m_leAuthorTitle, 2, 1 );
 
-  layout->addWidget( new QLabel( i18n( "Company:" ), page ), 3, 0 );
+  layout->addWidget( new QLabel( i18n( "Position:" ), page ), 3, 0 );
+  d->m_leAuthorPosition = new QLineEdit( authorInfo->position(), page );
+  layout->addWidget( d->m_leAuthorPosition, 3, 1 );
+
+
+  layout->addWidget( new QLabel( i18n( "Company:" ), page ), 4, 0 );
   d->m_leCompany = new QLineEdit( authorInfo->company(), page );
-  layout->addWidget( d->m_leCompany, 3, 1 );
+  layout->addWidget( d->m_leCompany, 4, 1 );
 
-  if ( authorInfo->company().isNull() )
-  {
-    QString name = d->m_emailCfg->readEntry( "Organization" );
-    if ( !name.isEmpty() )
-      d->m_leCompany->setText( name );
-  }
 
-  layout->addWidget( new QLabel( i18n( "Email:" ), page ), 4, 0 );
+  layout->addWidget( new QLabel( i18n( "Email:" ), page ), 5, 0 );
   d->m_leEmail = new QLineEdit( authorInfo->email(), page );
-  layout->addWidget( d->m_leEmail, 4, 1 );
+  layout->addWidget( d->m_leEmail, 5, 1 );
 
-  if ( authorInfo->email().isNull() )
-  {
-    QString email = d->m_emailCfg->readEntry( "EmailAddress" );
-    if ( !email.isEmpty() )
-      d->m_leEmail->setText( email );
-  }
 
-  layout->addWidget( new QLabel( i18n( "Telephone:" ), page ), 5, 0 );
-  d->m_leTelephone = new QLineEdit( authorInfo->telephone(), page );
-  layout->addWidget( d->m_leTelephone, 5, 1 );
+  layout->addWidget( new QLabel( i18n( "Telephone (Home):" ), page ), 6, 0 );
+  d->m_leTelephoneHome = new QLineEdit( authorInfo->telephoneHome(), page );
+  layout->addWidget( d->m_leTelephoneHome, 6, 1 );
 
-  layout->addWidget( new QLabel( i18n( "Fax:" ), page ), 6, 0 );
+  layout->addWidget( new QLabel( i18n( "Telephone (Work):" ), page ), 7, 0 );
+  d->m_leTelephoneWork = new QLineEdit( authorInfo->telephoneWork(), page );
+  layout->addWidget( d->m_leTelephoneWork, 7, 1 );
+
+  layout->addWidget( new QLabel( i18n( "Fax:" ), page ), 8, 0 );
   d->m_leFax = new QLineEdit( authorInfo->fax(), page );
-  layout->addWidget( d->m_leFax, 6, 1 );
+  layout->addWidget( d->m_leFax, 8, 1 );
 
-  layout->addWidget( new QLabel( i18n( "Street:" ), page ), 7, 0 );
+  layout->addWidget( new QLabel( i18n( "Street:" ), page ), 9, 0 );
   d->m_leStreet = new QLineEdit( authorInfo->street(), page );
-  layout->addWidget( d->m_leStreet, 7, 1 );
+  layout->addWidget( d->m_leStreet, 9, 1 );
 
-  layout->addWidget( new QLabel( i18n( "Postal code:" ), page ), 8, 0 );
+  layout->addWidget( new QLabel( i18n( "Postal code:" ), page ), 10, 0 );
   d->m_lePostalCode = new QLineEdit( authorInfo->postalCode(), page );
-  layout->addWidget( d->m_lePostalCode, 8, 1 );
+  layout->addWidget( d->m_lePostalCode, 10, 1 );
 
-  layout->addWidget( new QLabel( i18n( "City:" ), page ), 9, 0 );
+  layout->addWidget( new QLabel( i18n( "City:" ), page ), 11, 0 );
   d->m_leCity = new QLineEdit( authorInfo->city(), page );
-  layout->addWidget( d->m_leCity, 9, 1 );
+  layout->addWidget( d->m_leCity, 11, 1 );
 
-  layout->addWidget( new QLabel( i18n( "Country:" ), page ), 10, 0 );
+  layout->addWidget( new QLabel( i18n( "Country:" ), page ), 12, 0 );
   d->m_leCountry = new QLineEdit( authorInfo->country(), page );
-  layout->addWidget( d->m_leCountry, 10, 1 );
+  layout->addWidget( d->m_leCountry, 12, 1 );
 
   d->m_pbLoadKABC = new QPushButton( i18n( "Load From Address Book" ), page );
-  layout->addMultiCellWidget( d->m_pbLoadKABC, 11, 11, 0, 1 );
+  layout->addMultiCellWidget( d->m_pbLoadKABC, 13, 13, 0, 1 );
 
   connect( d->m_leFullName, SIGNAL( textChanged( const QString & ) ),
            this, SIGNAL( changed() ) );
@@ -261,7 +252,9 @@ void KoDocumentInfoDlg::addAuthorPage( KoDocumentInfoAuthor *authorInfo )
            this, SIGNAL( changed() ) );
   connect( d->m_leEmail, SIGNAL( textChanged( const QString & ) ),
            this, SIGNAL( changed() ) );
-  connect( d->m_leTelephone, SIGNAL( textChanged( const QString & ) ),
+  connect( d->m_leTelephoneWork, SIGNAL( textChanged( const QString & ) ),
+           this, SIGNAL( changed() ) );
+  connect( d->m_leTelephoneHome, SIGNAL( textChanged( const QString & ) ),
            this, SIGNAL( changed() ) );
   connect( d->m_leFax, SIGNAL( textChanged( const QString & ) ),
            this, SIGNAL( changed() ) );
@@ -273,29 +266,44 @@ void KoDocumentInfoDlg::addAuthorPage( KoDocumentInfoAuthor *authorInfo )
            this, SIGNAL( changed() ) );
   connect( d->m_leStreet, SIGNAL( textChanged( const QString & ) ),
            this, SIGNAL( changed() ) );
+  connect( d->m_leAuthorPosition, SIGNAL( textChanged( const QString & ) ),
+           this, SIGNAL( changed() ) );
   connect( d->m_pbLoadKABC, SIGNAL( clicked() ),
            this, SLOT( loadFromKABC() ) );
 }
 
 void KoDocumentInfoDlg::addAboutPage( KoDocumentInfoAbout *aboutInfo )
 {
-  QFrame *page = d->m_dialog->addPage( i18n("about the document", "About") );
-  QGridLayout *grid = new QGridLayout( page, 3, 2, KDialog::marginHint(), KDialog::spacingHint() );
+  QFrame *page = d->m_dialog->addPage( i18n("about the document", "Document") );
+  QGridLayout *grid = new QGridLayout( page, 6, 2, KDialog::marginHint(), KDialog::spacingHint() );
 
   grid->addWidget( new QLabel( i18n( "Title:" ), page ), 0, 0);
   d->m_leDocTitle = new QLineEdit( aboutInfo->title(), page );
   grid->addWidget(d->m_leDocTitle, 0, 1);
 
-  grid->addWidget(new QLabel( i18n( "Abstract:" ), page ), 1, 0, Qt::AlignTop );
+  grid->addWidget( new QLabel( i18n( "Subject:" ), page ), 1, 0);
+  d->m_leDocSubject = new QLineEdit( aboutInfo->subject(), page );
+  grid->addWidget(d->m_leDocSubject, 1, 1);
+
+  grid->addWidget( new QLabel( i18n( "Keywords:" ), page ), 2, 0);
+  d->m_leDocKeywords = new QLineEdit( aboutInfo->keywords(), page );
+  grid->addWidget(d->m_leDocKeywords, 2, 1);
+
+
+  grid->addWidget(new QLabel( i18n( "Abstract:" ), page ), 3, 0, Qt::AlignTop );
 
   d->m_meAbstract = new QMultiLineEdit( page );
   d->m_meAbstract->setText( aboutInfo->abstract() );
-  grid->addMultiCellWidget(d->m_meAbstract, 1, 2, 1, 1);
+  grid->addMultiCellWidget(d->m_meAbstract, 3, 5, 1, 1);
 
   connect( d->m_leDocTitle, SIGNAL( textChanged( const QString & ) ),
            this, SIGNAL( changed() ) );
   connect( d->m_meAbstract, SIGNAL( textChanged() ),
            this, SIGNAL( changed() ) );
+  connect( d->m_leDocSubject, SIGNAL( textChanged( const QString & ) ),
+           this, SIGNAL( changed() ) );
+  connect( d->m_leDocKeywords, SIGNAL( textChanged( const QString & ) ),
+           this, SIGNAL( changed() ) );
 }
 
 void KoDocumentInfoDlg::save()
@@ -329,16 +337,19 @@ void KoDocumentInfoDlg::save( KoDocumentInfoAuthor *authorInfo )
   authorInfo->setTitle( d->m_leAuthorTitle->text() );
   authorInfo->setCompany( d->m_leCompany->text() );
   authorInfo->setEmail( d->m_leEmail->text() );
-  authorInfo->setTelephone( d->m_leTelephone->text() );
+  authorInfo->setTelephoneWork( d->m_leTelephoneWork->text() );
+  authorInfo->setTelephoneHome( d->m_leTelephoneHome->text() );
   authorInfo->setFax( d->m_leFax->text() );
   authorInfo->setCountry( d->m_leCountry->text() );
   authorInfo->setPostalCode( d->m_lePostalCode->text() );
   authorInfo->setCity( d->m_leCity->text() );
   authorInfo->setStreet( d->m_leStreet->text() );
+  authorInfo->setPosition( d->m_leAuthorPosition->text() );
 
   KConfig* config = KoGlobal::kofficeConfig();
   KConfigGroupSaver cgs( config, "Author" );
-  config->writeEntry("telephone", d->m_leTelephone->text());
+  config->writeEntry("telephone", d->m_leTelephoneHome->text());
+  config->writeEntry("telephone-work", d->m_leTelephoneWork->text());
   config->writeEntry("fax", d->m_leFax->text());
   config->writeEntry("country",d->m_leCountry->text());
   config->writeEntry("postal-code",d->m_lePostalCode->text());
@@ -350,6 +361,8 @@ void KoDocumentInfoDlg::save( KoDocumentInfoAuthor *authorInfo )
 void KoDocumentInfoDlg::save( KoDocumentInfoAbout *aboutInfo )
 {
   aboutInfo->setTitle( d->m_leDocTitle->text() );
+  aboutInfo->setSubject( d->m_leDocSubject->text() );
+  aboutInfo->setKeywords( d->m_leDocKeywords->text() );
   aboutInfo->setAbstract( d->m_meAbstract->text() );
 }
 
@@ -498,7 +511,7 @@ void KoDocumentInfoPropsPage::applyChanges()
   d->m_dst = 0;
 }
 
-void KoDocumentInfoPropsPage::copy( const QString &path, const KTarEntry *entry )
+void KoDocumentInfoPropsPage::copy( const QString &path, const KArchiveEntry *entry )
 {
   kdDebug( 30003 ) << "copy " << entry->name() << endl;
   if ( entry->isFile() )
