@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
                  2000, 2001 Werner Trobin <trobin@kde.org>
+   Copyright (C) 2004 Nicolas Goutte <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -40,6 +41,12 @@
 
 #include <unistd.h>
 
+class KoFilterManager::Private
+{
+public:
+    bool m_batch;
+};
+
 
 KoFilterChooser::KoFilterChooser (QWidget *parent, const QStringList &mimeTypes, const QString &nativeFormat)
     : KDialogBase (parent, "kofilterchooser", true, i18n ("Choose Filter"),
@@ -109,6 +116,8 @@ const int KoFilterManager::s_area = 30500;
 KoFilterManager::KoFilterManager( KoDocument* document ) :
     m_document( document ), m_parentChain( 0 ), m_graph( "" ), d( 0 )
 {
+    d = new KoFilterManager::Private;
+    d -> m_batch = false;
     if ( document )
         QObject::connect( this, SIGNAL( sigProgress( int ) ),
                           document, SIGNAL( sigProgress( int ) ) );
@@ -120,10 +129,13 @@ KoFilterManager::KoFilterManager( const QString& url, const QCString& mimetypeHi
     m_document( 0 ), m_parentChain( parentChain ), m_importUrl( url ), m_importUrlMimetypeHint( mimetypeHint ),
     m_graph( "" ), d( 0 )
 {
+    d = new KoFilterManager::Private;
+    d -> m_batch = false;
 }
 
 KoFilterManager::~KoFilterManager()
 {
+    delete d;
 }
 
 QString KoFilterManager::import( const QString& url, KoFilter::ConversionStatus& status )
@@ -154,7 +166,7 @@ QString KoFilterManager::import( const QString& url, KoFilter::ConversionStatus&
 
             QApplication::setOverrideCursor( arrowCursor );
             KoFilterChooser chooser(0,
-                                    KoFilterManager::mimeFilter (nativeFormat, KoFilterManager::Import),
+                                    KoFilterManager::mimeFilter (nativeFormat, KoFilterManager::Import, m_document->extraNativeMimeTypes()),
                                     nativeFormat);
             if (chooser.exec ())
             {
@@ -301,6 +313,12 @@ namespace  // in order not to mess with the global namespace ;)
     // This method builds up the graph in the passed ascii dict
     void buildGraph( QAsciiDict<Vertex>& vertices, KoFilterManager::Direction direction )
     {
+        QStringList stopList; // Lists of mimetypes that are considered end of chains
+        stopList << "text/plain";
+        stopList << "text/csv";
+        stopList << "text/x-tex";
+        stopList << "text/html";
+
         vertices.setAutoDelete( true );
 
         // partly copied from build graph, but I don't see any other
@@ -321,11 +339,47 @@ namespace  // in order not to mess with the global namespace ;)
         QValueList<KoFilterEntry::Ptr>::ConstIterator end = filters.end();
 
         for ( ; it != end; ++it ) {
+
+            QStringList impList; // Import list
+            QStringList expList; // Export list
+
+            QStringList::Iterator stopEnd = stopList.end();
+            // Now we have to exclude the "stop" mimetypes (in the right direction!)
+            if ( direction == KoFilterManager::Import ) {
+                // Import: "stop" mime type should not appear in export
+                QStringList::ConstIterator testIt = ( *it )->export_.begin();
+                QStringList::ConstIterator testEnd = ( *it )->export_.end();
+                for ( ; testIt != testEnd ; ++testIt ) {
+                    if ( stopList.find( *testIt ) == stopEnd ) {
+                        expList.append( *testIt );
+                    }
+                }
+                impList = ( *it )->import;
+            }
+            else {
+                // Export: "stop" mime type should not appear in import
+                QStringList::ConstIterator testIt = ( *it )->import.begin();
+                QStringList::ConstIterator testEnd = ( *it )->import.end();
+                for ( ; testIt != testEnd ; ++testIt ) {
+                    if ( stopList.find( *testIt ) == stopEnd ) {
+                        impList.append( *testIt );
+                    }
+                }
+                expList = ( *it )->export_;
+            }
+
+            if ( impList.empty() || expList.empty() )
+            {
+                // This filter cannot be used under these conditions
+                kdDebug( 30500 ) << "Filter: " << ( *it )->service()->name() << " ruled out" << endl;
+                continue;
+            }
+
             // First add the "starting points" to the dict
-            QStringList::ConstIterator importIt = ( *it )->import.begin();
-            QStringList::ConstIterator importEnd = ( *it )->import.end();
+            QStringList::ConstIterator importIt = impList.begin();
+            QStringList::ConstIterator importEnd = impList.end();
             for ( ; importIt != importEnd; ++importIt ) {
-                QCString key = ( *importIt ).latin1();  // latin1 is okay here (werner)
+                const QCString key = ( *importIt ).latin1();  // latin1 is okay here (werner)
                 // already there?
                 if ( !vertices[ key ] )
                     vertices.insert( key, new Vertex( key ) );
@@ -333,12 +387,12 @@ namespace  // in order not to mess with the global namespace ;)
 
             // Are we allowed to use this filter at all?
             if ( KoFilterManager::filterAvailable( *it ) ) {
-                QStringList::ConstIterator exportIt = ( *it )->export_.begin();
-                QStringList::ConstIterator exportEnd = ( *it )->export_.end();
+                QStringList::ConstIterator exportIt = expList.begin();
+                QStringList::ConstIterator exportEnd = expList.end();
 
                 for ( ; exportIt != exportEnd; ++exportIt ) {
                     // First make sure the export vertex is in place
-                    QCString key = ( *exportIt ).latin1();  // latin1 is okay here
+                    const QCString key = ( *exportIt ).latin1();  // latin1 is okay here
                     Vertex* exp = vertices[ key ];
                     if ( !exp ) {
                         exp = new Vertex( key );
@@ -348,7 +402,7 @@ namespace  // in order not to mess with the global namespace ;)
                     // direction (import/export)
                     // This is the chunk of code which actually differs from the
                     // graph stuff (apart from the different vertex class)
-                    importIt = ( *it )->import.begin();
+                    importIt = impList.begin(); // ### TODO: why only the first one?
                     if ( direction == KoFilterManager::Import ) {
                         for ( ; importIt != importEnd; ++importIt )
                             exp->addEdge( vertices[ ( *importIt ).latin1() ] );
@@ -359,7 +413,7 @@ namespace  // in order not to mess with the global namespace ;)
                 }
             }
             else
-                kdDebug( 30500 ) << "Filter: " << ( *it )->service()->name() << " doesn't apply." << endl;
+                kdDebug( 30500 ) << "Filter: " << ( *it )->service()->name() << " does not apply." << endl;
         }
     }
 
@@ -399,11 +453,17 @@ namespace  // in order not to mess with the global namespace ;)
 
 // The static method to figure out to which parts of the
 // graph this mimetype has a connection to.
-QStringList KoFilterManager::mimeFilter( const QCString& mimetype, Direction direction )
+QStringList KoFilterManager::mimeFilter( const QCString& mimetype, Direction direction, const QStringList& extraNativeMimeTypes )
 {
     QAsciiDict<Vertex> vertices;
     buildGraph( vertices, direction );
-    return connected( vertices, mimetype );
+    QStringList lst = connected( vertices, mimetype );
+    QStringList::Iterator mimeFilterIt = lst.at( 1 );
+    for( QStringList::ConstIterator extrait = extraNativeMimeTypes.begin(); extrait != extraNativeMimeTypes.end(); ++extrait ) {
+        mimeFilterIt = lst.insert( mimeFilterIt, *extrait );
+        ++mimeFilterIt;
+    }
+    return lst;
 }
 
 QStringList KoFilterManager::mimeFilter()
@@ -491,5 +551,15 @@ void KoFilterManager::importErrorHelper( const QString& mimeType, const bool sup
     if (!suppressDialog) KMessageBox::error( 0L, tmp, i18n("Missing Import Filter") );
 }
 
+void KoFilterManager::setBatchMode( const bool batch )
+{
+    d->m_batch = batch;
+}
+
+bool KoFilterManager::getBatchMode( void ) const
+{
+    return d->m_batch;
+}
+
 #include <koFilterManager.moc>
 #include <koFilterManager_p.moc>
