@@ -35,11 +35,12 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qspinbox.h>
+#include <qtooltip.h>
 #include <kdebug.h>
 #include <knuminput.h>
 #include <kcompletion.h>
 #include <kconfig.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <qcombobox.h>
 #include <qdir.h>
 #include <koSearchDia.h>
@@ -94,6 +95,7 @@ KoAutoFormatExceptionWidget::KoAutoFormatExceptionWidget(QWidget *parent, const
 
     exceptionList=new QListBox(this);
     exceptionList->insertStringList(m_listException);
+    exceptionList->sort();
     grid->addWidget(exceptionList,2,0);
 
     grid->setRowStretch( 2, 1 );
@@ -126,6 +128,7 @@ void KoAutoFormatExceptionWidget::slotAddException()
 
             exceptionList->clear();
             exceptionList->insertStringList(m_listException);
+            exceptionList->sort();
             pbRemoveException->setEnabled( exceptionList->currentItem()!=-1);
             pbAddException->setEnabled(false);
         }
@@ -501,7 +504,9 @@ void KoAutoFormatDia::setupTab3()
 
     QStringList lst;
     lst<<i18n("Default");
+    lst<<i18n("All Languages");
     exceptionLanguageName.insert( i18n("Default"), "");
+    exceptionLanguageName.insert( i18n("All Languages"), "all_languages");
 
     KStandardDirs *standard = new KStandardDirs();
     QStringList tmp = standard->findDirs("data", "koffice/autocorrect/");
@@ -558,6 +563,7 @@ void KoAutoFormatDia::setupTab3()
              SLOT( slotAddEntry()));
 
     pbSpecialChar1 = new QPushButton( "...", tab3 );
+    QToolTip::add( pbSpecialChar1, i18n( "Insert a special character..." ) );
     pbSpecialChar1->setFixedWidth( 40 );
     grid->addWidget( pbSpecialChar1, 3, 2 );
 
@@ -577,6 +583,7 @@ void KoAutoFormatDia::setupTab3()
             SLOT( slotAddEntry()));
 
     pbSpecialChar2 = new QPushButton( "...", tab3 );
+    QToolTip::add( pbSpecialChar2, i18n( "Insert a special character..." ) );
     pbSpecialChar2->setFixedWidth( 40 );
     grid->addWidget( pbSpecialChar2, 3, 5 );
 
@@ -690,7 +697,6 @@ void KoAutoFormatDia::changeAutoformatLanguage(const QString & text)
     {
         m_docAutoFormat->configAutoFormatLanguage( exceptionLanguageName.find(text).data());
     }
-
     if ( !noSignal )
     {
         changeLanguage=true;
@@ -932,8 +938,16 @@ void KoAutoFormatDia::chooseSpecialChar1()
 {
     QString f = font().family();
     QChar c = ' ';
+    bool const focus = m_find->hasFocus();
     if ( KoCharSelectDia::selectChar( f, c, false ) )
-        m_find->setText( c );
+    {
+        int const cursorpos = m_find->cursorPosition();
+        if (focus)
+            m_find->setText( m_find->text().insert( cursorpos, c ) );
+        else
+            m_find->setText( m_find->text().append(c) );
+        m_find->setCursorPosition( cursorpos+1 );
+    }
 }
 
 
@@ -941,8 +955,16 @@ void KoAutoFormatDia::chooseSpecialChar2()
 {
     QString f = font().family();
     QChar c = ' ';
+    bool const focus = m_replace->hasFocus();
     if ( KoCharSelectDia::selectChar( f, c, false ) )
-        m_replace->setText( c );
+    {
+        int const cursorpos = m_replace->cursorPosition();
+        if (focus)
+            m_replace->setText( m_replace->text().insert(m_replace->cursorPosition(),  c ) );
+        else
+        m_replace->setText( m_replace->text().append(c) );
+        m_replace->setCursorPosition( cursorpos+1 );
+    }
 }
 
 
@@ -1152,6 +1174,7 @@ void KoCompletionDia::changeButtonStatus()
 {
     bool state = cbAllowCompletion->isChecked();
     cbAppendSpace->setEnabled( state );
+    cbShowToolTip->setEnabled( state );
     cbAddCompletionWord->setEnabled( state );
     pbRemoveCompletionEntry->setEnabled( state );
     pbSaveCompletionEntry->setEnabled( state );
@@ -1159,7 +1182,8 @@ void KoCompletionDia::changeButtonStatus()
     m_lbListCompletion->setEnabled( state );
     m_minWordLength->setEnabled( state );
     m_maxNbWordCompletion->setEnabled( state );
-
+    m_completionKeyActionLabel->setEnabled( state );
+    m_completionKeyAction->setEnabled( state );
     state = state && (m_lbListCompletion->count()!=0 && !m_lbListCompletion->currentText().isEmpty());
     pbRemoveCompletionEntry->setEnabled( state );
 }
@@ -1171,6 +1195,10 @@ void KoCompletionDia::setup()
     cbAllowCompletion->setText( i18n( "E&nable completion" ) );
     connect(cbAllowCompletion, SIGNAL(toggled ( bool )), this, SLOT( changeButtonStatus()));
     // TODO whatsthis or text, to tell about the key to use for autocompletion....
+
+    cbShowToolTip = new QCheckBox( page );
+    cbShowToolTip->setText( i18n( "&Enable tool tip completion" ) );
+    QWhatsThis::add( cbShowToolTip, i18n("If this option is enabled, a tool tip box will appear when you type the beginning of a word that exists in the completion list. To complete the word, press the TAB or ENTER key." ) );
     cbAddCompletionWord = new QCheckBox( page );
     cbAddCompletionWord->setText( i18n( "&Automatically add new words to completion list" ) );
     QWhatsThis::add( cbAddCompletionWord, i18n("If this option is enabled, any word typed in this document will automatically be added to the list of words used by the completion." ) );
@@ -1200,21 +1228,54 @@ void KoCompletionDia::setup()
     cbAppendSpace = new QCheckBox( page );
     cbAppendSpace->setText( i18n( "A&ppend space" ) );
 
+    m_completionKeyActionLabel = new QLabel(i18n( "Key used for completion:" ),page );
+
+    m_completionKeyAction = new QComboBox( page );
+    QStringList lst;
+    lst << i18n( "Enter" );
+    lst << i18n( "Tab" );
+    lst << i18n( "Space" );
+    lst << i18n( "End" );
+    lst << i18n( "Right" );
+    m_completionKeyAction->insertStringList( lst );
     m_listCompletion = m_docAutoFormat->listCompletion();
 }
 
 void KoCompletionDia::slotResetConf()
 {
-   cbAllowCompletion->setChecked( m_autoFormat.getConfigCompletion());
+    cbAllowCompletion->setChecked( m_autoFormat.getConfigCompletion());
+    cbShowToolTip->setChecked( m_autoFormat.getConfigToolTipCompletion());
     cbAddCompletionWord->setChecked( m_autoFormat.getConfigAddCompletionWord());
     m_lbListCompletion->clear();
     QStringList lst = m_docAutoFormat->listCompletion();
     m_lbListCompletion->insertStringList( lst );
+    m_lbListCompletion->sort();
     if( lst.isEmpty() || m_lbListCompletion->currentText().isEmpty())
         pbRemoveCompletionEntry->setEnabled( false );
     m_minWordLength->setValue ( m_docAutoFormat->getConfigMinWordLength() );
     m_maxNbWordCompletion->setValue ( m_docAutoFormat->getConfigNbMaxCompletionWord() );
     cbAppendSpace->setChecked( m_autoFormat.getConfigAppendSpace() );
+
+    switch( m_docAutoFormat->getConfigKeyAction() )
+    {
+    case KoAutoFormat::Enter:
+        m_completionKeyAction->setCurrentItem( 0 );
+        break;
+    case KoAutoFormat::Tab:
+        m_completionKeyAction->setCurrentItem( 1 );
+        break;
+    case KoAutoFormat::Space:
+        m_completionKeyAction->setCurrentItem( 2 );
+        break;
+    case KoAutoFormat::End:
+        m_completionKeyAction->setCurrentItem( 3 );
+        break;
+    case KoAutoFormat::Right:
+        m_completionKeyAction->setCurrentItem( 4 );
+        break;
+    default:
+        m_completionKeyAction->setCurrentItem( 0 );
+    }
     changeButtonStatus();
 }
 
@@ -1233,7 +1294,7 @@ void KoCompletionDia::slotSaveCompletionEntry()
 void KoCompletionDia::slotAddCompletionEntry()
 {
     bool ok;
-    QString newWord = KLineEditDlg::getText( i18n("Add Completion Entry"),i18n("Enter entry:"),QString::null, &ok, this );
+    QString const newWord = KInputDialog::getText( i18n("Add Completion Entry"), i18n("Enter entry:"), QString::null, &ok, this ).lower();
     if ( ok )
     {
         if ( !m_listCompletion.contains( newWord ))
@@ -1241,6 +1302,7 @@ void KoCompletionDia::slotAddCompletionEntry()
             m_listCompletion.append( newWord );
             m_lbListCompletion->insertItem( newWord );
             pbRemoveCompletionEntry->setEnabled( !m_lbListCompletion->currentText().isEmpty() );
+            m_lbListCompletion->sort();
         }
 
     }
@@ -1256,14 +1318,35 @@ void KoCompletionDia::slotOk()
 
 bool KoCompletionDia::applyConfig()
 {
-
     m_docAutoFormat->configCompletion( cbAllowCompletion->isChecked());
+    m_docAutoFormat->configToolTipCompletion( cbShowToolTip->isChecked());
     m_docAutoFormat->configAppendSpace( cbAppendSpace->isChecked() );
     m_docAutoFormat->configMinWordLength( m_minWordLength->value() );
     m_docAutoFormat->configNbMaxCompletionWord( m_maxNbWordCompletion->value () );
     m_docAutoFormat->configAddCompletionWord( cbAddCompletionWord->isChecked());
 
     m_docAutoFormat->getCompletion()->setItems( m_listCompletion );
+    m_docAutoFormat->updateMaxWords();
+    switch( m_completionKeyAction->currentItem() )
+    {
+    case 0:
+        m_docAutoFormat->configKeyCompletionAction( KoAutoFormat::Enter );
+        break;
+    case 1:
+        m_docAutoFormat->configKeyCompletionAction( KoAutoFormat::Tab );
+        break;
+    case 2:
+        m_docAutoFormat->configKeyCompletionAction( KoAutoFormat::Space );
+        break;
+    case 3:
+        m_docAutoFormat->configKeyCompletionAction( KoAutoFormat::End );
+        break;
+    case 4:
+        m_docAutoFormat->configKeyCompletionAction( KoAutoFormat::Right );
+        break;
+    default:
+        m_docAutoFormat->configKeyCompletionAction( KoAutoFormat::Enter );
+    }
     // Save to config file
     m_docAutoFormat->saveConfig();
     return true;
