@@ -17,19 +17,20 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <qglobal.h>
-#if QT_VERSION >= 0x030200
-#define INDIC
-#endif
-
 #include "kotextformat.h"
-#include "korichtext.h" // for KoTextParag etc.
+#include "kotextparag.h"
 #include "kozoomhandler.h"
+#include "kostyle.h"
+#include "kooasiscontext.h"
+#include <koGenStyles.h>
+#include <koxmlns.h>
+
 #include <kglobal.h>
 #include <kdebug.h>
 #include <klocale.h>
+
+#include <qregexp.h>
 #include <assert.h>
-#include "kostyle.h"
 
 void KoTextFormat::KoTextFormatPrivate::clearCache()
 {
@@ -43,6 +44,13 @@ void KoTextFormat::KoTextFormatPrivate::clearCache()
     memset( m_screenWidths, 0, 256 * sizeof( ushort ) );
 }
 
+void KoTextFormat::zoomChanged()
+{
+    delete d->m_screenFontMetrics; d->m_screenFontMetrics = 0;
+    delete d->m_screenFont; d->m_screenFont = 0;
+    memset( d->m_screenWidths, 0, 256 * sizeof( ushort ) );
+}
+
 KoTextFormat::KoTextFormat()
 {
     //linkColor = TRUE;
@@ -73,7 +81,7 @@ KoTextFormat::KoTextFormat()
 //#endif
 }
 
-KoTextFormat::KoTextFormat( const QFont &f, const QColor &c, const QString &_language, bool hyphenation, double ulw, KoTextFormatCollection *parent )
+KoTextFormat::KoTextFormat( const QFont &f, const QColor &c, const QString &_language, bool hyphenation, KoTextFormatCollection *parent )
     : fn( f ), col( c ) /*fm( QFontMetrics( f ) ),*/ //linkColor( TRUE )
 {
 #ifdef DEBUG_COLLECTION
@@ -81,7 +89,7 @@ KoTextFormat::KoTextFormat( const QFont &f, const QColor &c, const QString &_lan
 #endif
     int pointSize;
     if ( f.pointSize() == -1 ) // font was set with a pixelsize, we need a pointsize!
-        pointSize = (int)( ( (double)fn.pixelSize() * 72.0 ) / (double)QPaintDevice::x11AppDpiY() );
+        pointSize = (int)( ( (double)fn.pixelSize() * 72.0 ) / (double)KoGlobal::dpiY() );
     else
         pointSize = f.pointSize();
     fn.setPointSize( pointSize );
@@ -111,7 +119,7 @@ KoTextFormat::KoTextFormat( const QFont &f, const QColor &c, const QString &_lan
     d->m_bWordByWord = false;
     d->m_charStyle = 0L;
     d->m_bHyphenation = hyphenation;
-    d->m_underLineWidth = ulw;
+    d->m_underLineWidth = 1.0;
     m_attributeFont = ATT_NONE;
     ////
     generateKey();
@@ -140,6 +148,7 @@ KoTextFormat::KoTextFormat( const QFont &_font,
     ref = 0;
     collection = 0;
     fn = _font;
+    fn.setStyleStrategy( QFont::ForceOutline );
     col = _color;
     missp = false;
     va = _valign;
@@ -203,7 +212,7 @@ KoTextFormat& KoTextFormat::operator=( const KoTextFormat &f )
     //dsc = f.dsc;
     missp = f.missp;
     va = f.va;
-    k = f.k;
+    m_key = f.m_key;
     //linkColor = f.linkColor;
     //// kotext addition
     delete d;
@@ -230,22 +239,372 @@ KoTextFormat& KoTextFormat::operator=( const KoTextFormat &f )
     return *this;
 }
 
+// Helper for load
+static void importTextPosition( const QString& text_position, double fontSize, KoTextFormat::VerticalAlignment& value, double& relativetextsize, int& offset )
+{
+    //OO: <vertical position (% or sub or super)> [<size as %>]
+    //Examples: "super" or "super 58%" or "82% 58%" (where 82% is the vertical position)
+    QStringList lst = QStringList::split( ' ', text_position );
+    if ( !lst.isEmpty() )
+    {
+        QString textPos = lst.front().stripWhiteSpace();
+        QString textSize;
+        lst.pop_front();
+        if ( !lst.isEmpty() )
+            textSize = lst.front().stripWhiteSpace();
+        Q_ASSERT( lst.count() == 1 );
+        if ( textPos.endsWith("%") )
+        {
+            textPos.truncate( textPos.length() - 1 );
+            double val = textPos.toDouble();
+            offset = qRound( fontSize * val / 100.0 );
+        }
+        if ( textPos == "super" )
+            value = KoTextFormat::AlignSuperScript;
+        else if ( textPos == "sub" )
+            value = KoTextFormat::AlignSubScript;
+        else
+            value = KoTextFormat::AlignNormal;
+        if ( !textSize.isEmpty() && textSize.endsWith("%") )
+        {
+            textSize.truncate( textSize.length() - 1 );
+            relativetextsize = textSize.toDouble() / 100; // e.g. 0.58
+        }
+    }
+    else
+        value = KoTextFormat::AlignNormal;
+}
+
+// OASIS 14.2.29
+static void importOasisUnderline( const QString& type, const QString& style,
+                                  KoTextFormat::UnderlineType& underline,
+                                  KoTextFormat::UnderlineStyle& styleline )
+{
+  if ( type == "single" )
+      underline = KoTextFormat::U_SIMPLE;
+  else if ( type == "double" )
+      underline = KoTextFormat::U_DOUBLE;
+  else if ( type == "none" )
+      underline = KoTextFormat::U_NONE;
+  else if ( style.isEmpty() || style == "none" )
+      underline = KoTextFormat::U_NONE;
+  else
+      underline = KoTextFormat::U_SIMPLE; // OO exports empty type, and style=solid, for normal underline
+
+  styleline = KoTextFormat::U_SOLID; // assume "solid" if unknown
+  if ( style == "dotted" )
+      styleline = KoTextFormat::U_DOT;
+  else if ( style == "dash"
+            || style == "long-dash" ) // not in kotext
+      styleline = KoTextFormat::U_DASH;
+  else if ( style == "dot-dash" )
+      styleline = KoTextFormat::U_DASH_DOT;
+  else if ( style == "dot-dot-dash" )
+      styleline = KoTextFormat::U_DASH_DOT_DOT;
+  else if ( style == "wave" )
+      underline = KoTextFormat::U_WAVE;
+
+  // TODO bold. But this is another attribute in OASIS (text-underline-width), which makes sense.
+  // We should separate them in kotext...
+}
+
+QString exportOasisUnderline( KoTextFormat::UnderlineStyle styleline )
+{
+    switch( styleline ) {
+    case KoTextFormat::U_DOT:
+        return "dotted";
+    case KoTextFormat::U_DASH:
+        return "dash";
+    case KoTextFormat::U_DASH_DOT:
+        return "dot-dash";
+    case KoTextFormat::U_DASH_DOT_DOT:
+        return "dot-dot-dash";
+    default:
+        return "solid";
+    }
+}
+
+// Helper for load. Legacy OO format.
+static void importUnderline( const QString& in,
+                             KoTextFormat::UnderlineType& underline,
+                             KoTextFormat::UnderlineStyle& styleline )
+{
+    underline = KoTextFormat::U_SIMPLE;
+    styleline = KoTextFormat::U_SOLID;
+    if ( in == "none" )
+        underline = KoTextFormat::U_NONE;
+    else if ( in == "single" )
+        styleline = KoTextFormat::U_SOLID;
+    else if ( in == "double" ) {
+        underline = KoTextFormat::U_DOUBLE;
+    }
+    else if ( in == "dotted" || in == "bold-dotted" ) // bold-dotted not in libkotext
+        styleline = KoTextFormat::U_DOT;
+    else if ( in == "dash"
+              // those are not in libkotext:
+              || in == "long-dash"
+              || in == "bold-dash"
+              || in == "bold-long-dash" )
+        styleline = KoTextFormat::U_DASH;
+    else if ( in == "dot-dash"
+              || in == "bold-dot-dash") // not in libkotext
+        styleline = KoTextFormat::U_DASH_DOT; // tricky ;)
+    else if ( in == "dot-dot-dash"
+              || in == "bold-dot-dot-dash") // not in libkotext
+        styleline = KoTextFormat::U_DASH_DOT_DOT; // this is getting fun...
+    else if ( in == "wave"
+              || in == "bold-wave" // not in libkotext
+              || in == "double-wave" // not in libkotext
+              || in == "small-wave" ) { // not in libkotext
+        underline = KoTextFormat::U_WAVE;
+    } else if( in == "bold" ) {
+        underline = KoTextFormat::U_SIMPLE_BOLD;
+    } else
+        kdWarning() << k_funcinfo << " unsupported text-underline value: " << in << endl;
+}
+
+void KoTextFormat::load( KoOasisContext& context )
+{
+    KoStyleStack& styleStack = context.styleStack();
+    styleStack.setTypeProperties( "text" ); // load all style attributes from "style:text-properties"
+
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "color" ) ) { // 3.10.3
+        col.setNamedColor( styleStack.attributeNS( KoXmlNS::fo, "color" ) ); // #rrggbb format
+    }
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "font-family" )  // 3.10.9
+         || styleStack.hasAttributeNS( KoXmlNS::style, "font-name") ) { // 3.10.8
+        // Hmm, the remove "'" could break it's in the middle of the fontname...
+        QString fontName = styleStack.attributeNS( KoXmlNS::fo, "font-family" ).remove( "'" );
+        if (fontName.isEmpty()) {
+            // ##### TODO. This is wrong. style:font-name refers to a font-decl entry.
+            // We have to look it up there, and retrieve _all_ font attributes from it, not just the name.
+            fontName = styleStack.attributeNS( KoXmlNS::style, "font-name" ).remove( "'" );
+        }
+        // 'Thorndale' is not known outside OpenOffice so we substitute it
+        // with 'Times New Roman' that looks nearly the same.
+        if ( fontName == "Thorndale" )
+            fontName = "Times New Roman";
+
+        fontName.remove(QRegExp("\\sCE$")); // Arial CE -> Arial
+        fn.setFamily( fontName );
+    }
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "font-size" ) ) { // 3.10.14
+        double pointSize = styleStack.fontSize();
+        fn.setPointSizeFloat( pointSize );
+    }
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "font-weight" ) ) { // 3.10.24
+        QString fontWeight = styleStack.attributeNS( KoXmlNS::fo, "font-weight" );
+        int boldness;
+        if ( fontWeight == "normal" )
+            boldness = 50;
+        else if ( fontWeight == "bold" )
+            boldness = 75;
+        else
+            // XSL/CSS has 100,200,300...900. Not the same scale as Qt!
+            // See http://www.w3.org/TR/2001/REC-xsl-20011015/slice7.html#font-weight
+            boldness = fontWeight.toInt() / 10;
+        fn.setWeight( boldness );
+    }
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "font-style" ) ) // 3.10.19
+        if ( styleStack.attributeNS( KoXmlNS::fo, "font-style" ) == "italic" ||
+             styleStack.attributeNS( KoXmlNS::fo, "font-style" ) == "oblique" ) { // no difference in kotext
+            fn.setItalic( true );
+        }
+
+    d->m_bWordByWord = styleStack.attributeNS( KoXmlNS::style, "text-underline-mode" ) == "skip-white-space";
+    // TODO style:text-line-through-mode
+
+#if 0 // OO compat code, to move to OO import filter
+    d->m_bWordByWord = (styleStack.hasAttributeNS( KoXmlNS::fo, "score-spaces")) // 3.10.25
+                      && (styleStack.attributeNS( KoXmlNS::fo, "score-spaces") == "false");
+    if( styleStack.hasAttributeNS( KoXmlNS::style, "text-crossing-out" )) { // 3.10.6
+        QString strikeOutType = styleStack.attributeNS( KoXmlNS::style, "text-crossing-out" );
+        if( strikeOutType =="double-line")
+            m_strikeOutType = S_DOUBLE;
+        else if( strikeOutType =="single-line")
+            m_strikeOutType = S_SIMPLE;
+        else if( strikeOutType =="thick-line")
+            m_strikeOutType = S_SIMPLE_BOLD;
+        // not supported by KWord: "slash" and "X"
+        // not supported by OO: stylelines (solid, dash, dot, dashdot, dashdotdot)
+    }
+#endif
+    if ( styleStack.hasAttributeNS( KoXmlNS::style, "text-underline-type" )
+        || styleStack.hasAttributeNS( KoXmlNS::style, "text-underline-style" ) ) { // OASIS 14.4.28
+        importOasisUnderline( styleStack.attributeNS( KoXmlNS::style, "text-underline-type" ),
+                              styleStack.attributeNS( KoXmlNS::style, "text-underline-style" ),
+                              m_underlineType, m_underlineStyle );
+    }
+    else if ( styleStack.hasAttributeNS( KoXmlNS::style, "text-underline" ) ) { // OO compat (3.10.22), to be moved out
+        importUnderline( styleStack.attributeNS( KoXmlNS::style, "text-underline" ),
+                         m_underlineType, m_underlineStyle );
+    }
+    QString underLineColor = styleStack.attributeNS( KoXmlNS::style, "text-underline-color" ); // OO 3.10.23, OASIS 14.4.31
+    if ( !underLineColor.isEmpty() && underLineColor != "font-color" )
+        m_textUnderlineColor.setNamedColor( underLineColor );
+
+    if ( styleStack.hasAttributeNS( KoXmlNS::style, "text-line-through-type" ) ) { // OASIS 14.4.7
+        // Reuse code for loading underlines, and convert to strikeout enum (if not wave)
+        UnderlineType uType; UnderlineStyle uStyle;
+        importOasisUnderline( styleStack.attributeNS( KoXmlNS::style, "text-line-through-type" ),
+                              styleStack.attributeNS( KoXmlNS::style, "text-line-through-style" ),
+                              uType, uStyle );
+        m_strikeOutType = S_NONE;
+        if ( uType != U_WAVE )
+            m_strikeOutType = (StrikeOutType)uType;
+        m_strikeOutStyle = (StrikeOutStyle)uStyle;
+    }
+
+    // Text position
+    va = AlignNormal;
+    d->m_relativeTextSize = 0.58;
+    d->m_offsetFromBaseLine = 0;
+    if( styleStack.hasAttributeNS( KoXmlNS::style, "text-position")) { // OO 3.10.7
+        importTextPosition( styleStack.attributeNS( KoXmlNS::style, "text-position"), fn.pointSizeFloat(),
+                            va, d->m_relativeTextSize, d->m_offsetFromBaseLine );
+    }
+    // Small caps, lowercase, uppercase
+    m_attributeFont = ATT_NONE;
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "font-variant" ) // 3.10.1
+         || styleStack.hasAttributeNS( KoXmlNS::fo, "text-transform" ) ) { // 3.10.2
+        bool smallCaps = styleStack.attributeNS( KoXmlNS::fo, "font-variant" ) == "small-caps";
+        if ( smallCaps ) {
+            m_attributeFont = ATT_SMALL_CAPS;
+        } else {
+            QString textTransform = styleStack.attributeNS( KoXmlNS::fo, "text-transform" );
+            if ( textTransform == "uppercase" )
+                m_attributeFont = ATT_UPPER;
+            else if ( textTransform == "lowercase" )
+                m_attributeFont = ATT_LOWER;
+            // TODO in KWord: "capitalize".
+        }
+    }
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "language") ) { // 3.10.17
+        m_language = styleStack.attributeNS( KoXmlNS::fo, "language");
+        const QString country = styleStack.attributeNS( KoXmlNS::fo, "country" );
+        if ( !country.isEmpty() ) {
+            m_language += '_';
+            m_language += country;
+        }
+    }
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "background-color") ) {
+        QString tmp = styleStack.attributeNS( KoXmlNS::fo, "background-color");
+        if (tmp != "transparent")
+            m_textBackColor.setNamedColor( tmp );
+    }
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "text-shadow") ) { // 3.10.21
+        parseShadowFromCss( styleStack.attributeNS( KoXmlNS::fo, "text-shadow") );
+    }
+
+    d->m_bHyphenation = true;
+    if ( styleStack.hasAttributeNS( KoXmlNS::fo, "hyphenate" ) ) // it's a character property in OASIS (but not in OO-1.1)
+        d->m_bHyphenation = styleStack.attributeNS( KoXmlNS::fo, "hyphenate" ) == "true";
+
+    /*
+      Missing properties:
+      style:use-window-font-color, 3.10.4 - this is what KWord uses by default (fg color from the color style)
+         OO also switches to another color when necessary to avoid dark-on-dark and light-on-light cases.
+         (that is TODO in KWord)
+      style:text-outline, 3.10.5 - not implemented in kotext
+      style:font-family-generic, 3.10.10 - roman, swiss, modern -> map to a font?
+      style:font-style-name, 3.10.11 - can be ignored, says DV, the other ways to specify a font are more precise
+      style:font-pitch, 3.10.12 - fixed or variable -> map to a font?
+      style:font-charset, 3.10.14 - not necessary with Qt
+      style:font-size-rel, 3.10.15 - TODO in StyleStack::fontSize()
+      fo:letter-spacing, 3.10.16 - not implemented in kotext
+      style:text-relief, 3.10.20 - not implemented in kotext
+      style:letter-kerning, 3.10.20 - not implemented in kotext
+      style:text-blinking, 3.10.27 - not implemented in kotext IIRC
+      style:text-combine, 3.10.29/30 - not implemented, see http://www.w3.org/TR/WD-i18n-format/
+      style:text-emphasis, 3.10.31 - not implemented in kotext
+      style:text-scale, 3.10.33 - not implemented in kotext
+      style:text-rotation-angle, 3.10.34 - not implemented in kotext (kpr rotates whole objects)
+      style:text-rotation-scale, 3.10.35 - not implemented in kotext (kpr rotates whole objects)
+      style:punctuation-wrap, 3.10.36 - not implemented in kotext
+    */
+
+    d->m_underLineWidth = 1.0;
+
+    generateKey();
+    addRef();
+}
+
+void KoTextFormat::save( KoGenStyle& gs, KoSavingContext& context ) const
+{
+    KoGenStyle::PropertyType tt = KoGenStyle::TextType;
+    gs.addProperty( "fo:color", col.isValid() ? col.name() : "#000000", tt );
+    gs.addProperty( "style:font-name", fn.family(), tt );
+    context.addFontFace( fn.family() );
+    gs.addPropertyPt( "fo:font-size", fn.pointSize(), tt );
+    int w = fn.weight();
+    gs.addProperty( "fo:font-weight", w == 50 ? "normal" : w == 75 ? "bold" : QString::number( qRound( w / 10 ) * 100 ), tt );
+    gs.addProperty( "fo:font-style", fn.italic() ? "italic" : "normal", tt );
+    gs.addProperty( "style:text-underline-mode", d->m_bWordByWord ? "skip-white-space" : "continuous", tt );
+    gs.addProperty( "style:text-underline-type", m_underlineType == U_NONE ? "none" :
+                    m_underlineType == U_DOUBLE ? "double" : "single", tt );
+    QString styleline;
+    if ( m_underlineType == U_WAVE )
+        styleline = "wave";
+    else
+        styleline = exportOasisUnderline( m_underlineStyle );
+    gs.addProperty( "style:text-underline-style", m_underlineType == U_NONE ? "none" : styleline, tt );
+    gs.addProperty( "style:text-underline-color", m_textUnderlineColor.isValid() ? m_textUnderlineColor.name() : "font-color", tt );
+
+    if ( m_strikeOutType != S_NONE )
+    {
+        // TODO U_SIMPLE_BOLD
+        // TODO style:text-line-through-mode
+        gs.addProperty( "style:text-line-through-type", m_strikeOutType == S_DOUBLE ? "double" : "single", tt );
+        styleline = exportOasisUnderline( (UnderlineStyle) m_strikeOutStyle );
+        gs.addProperty( "style:text-line-through-style", styleline, tt );
+        //gs.addProperty( "style:text-line-through-color", ...) TODO in kotext
+    }
+    else
+    {
+        gs.addProperty( "style:text-line-through-type", "none" , tt );
+        gs.addProperty( "style:text-line-through-style", "none", tt );
+    }
+
+    QString textPos;
+    if ( d->m_offsetFromBaseLine != 0 )
+        textPos = QString::number( 100 * d->m_offsetFromBaseLine / fn.pointSizeFloat() ) + '%';
+    else if ( va == AlignSuperScript ) textPos = "super";
+    else if ( va == AlignSubScript ) textPos = "sub";
+    else textPos = "0%";
+    textPos += ' ';
+    textPos += QString::number( d->m_relativeTextSize * 100 );
+    textPos += '%';
+    gs.addProperty( "style:text-position", textPos, tt );
+
+    if ( m_attributeFont == ATT_SMALL_CAPS )
+        gs.addProperty( "fo:font-variant", "small-caps", tt );
+    else if ( m_attributeFont == ATT_UPPER )
+        gs.addProperty( "fo:text-transform", "uppercase", tt );
+    else if ( m_attributeFont == ATT_LOWER )
+        gs.addProperty( "fo:text-transform", "lowercase", tt );
+
+    QString lang = m_language;
+    QString country;
+    const int pos = lang.find( '_' );
+    if ( pos != -1 ) {
+        country = lang.mid( pos + 1 );
+        lang = lang.left( pos );
+    }
+
+    gs.addProperty( "fo:language", lang, tt );
+    gs.addProperty( "fo:country", country, tt );
+    gs.addProperty( "fo:background-color",
+                    m_textBackColor.isValid() ? m_textBackColor.name() : "transparent", tt );
+    gs.addProperty( "fo:text-shadow", shadowAsCss(), tt );
+    gs.addProperty( "fo:hyphenate", d->m_bHyphenation, tt );
+}
+
 void KoTextFormat::update()
 {
     //kdDebug(32500) << this << " KoTextFormat::update " << fn.family() << " " << pointSize() << endl;
-    fn.setStyleStrategy( QFont::ForceOutline );
-    //fm = QFontMetrics( fn );
-    //leftBearing = fm.minLeftBearing();
-    //rightBearing = fm.minRightBearing();
-    //hei = fm.height();
-    //asc = fm.ascent();
-    //dsc = fm.descent();
-    generateKey();
-    //updateStyleFlags();
-    //// kotext
+    m_key = QString::null; // invalidate key, recalc at the next key() call
     assert( d );
     d->clearCache(); // i.e. recalc at the next screenFont[Metrics]() call
-    ////
 }
 
 void KoTextFormat::copyFormat( const KoTextFormat & nf, int flags )
@@ -361,9 +720,10 @@ void KoTextFormat::setPointSize( int s )
 
 void KoTextFormat::setFont( const QFont &f )
 {
-    if ( f == fn && !k.isEmpty() )
+    if ( f == fn )
 	return;
     fn = f;
+    fn.setStyleStrategy( QFont::ForceOutline );
     update();
 }
 
@@ -397,7 +757,7 @@ int KoTextFormat::minRightBearing() const
 // ## readable form when !NDEBUG, like QFont does?
 void KoTextFormat::generateKey()
 {
-    k = fn.key();
+    QString k = fn.key();
     k += '/';
     if ( col.isValid() ) // just to shorten the key in the common case
         k += QString::number( (uint)col.rgb() );
@@ -439,6 +799,7 @@ void KoTextFormat::generateKey()
     k += QString::number( (double)d->m_underLineWidth);
     ////
     // Keep in sync with method below
+    m_key = k;
 }
 
 // This is used to create "simple formats", with font and color etc., but without
@@ -481,6 +842,14 @@ QString KoTextFormat::getKey( const QFont &fn, const QColor &col, bool misspelle
     return k;
 }
 
+
+QString KoTextFormat::key() const
+{
+    if ( m_key.isEmpty() )
+        const_cast<KoTextFormat*>( this )->generateKey();
+    return m_key;
+}
+
 void KoTextFormat::addRef()
 {
     ref++;
@@ -738,30 +1107,21 @@ int KoTextFormat::charWidth( const KoZoomHandler* zh, bool applyZoom, const KoTe
                              const KoTextParag* parag, int i ) const
 {
     ushort unicode = c->c.unicode();
-#ifndef INDIC
-    if ( unicode == 0xad ) // soft hyphen
-	return 0;
-#else
     if ( !c->charStop || unicode == 0xad || unicode == 0x2028 )
 	 return 0;
-#endif
     Q_ASSERT( !c->isCustom() ); // actually it's a bit stupid to call this for custom items
     if( c->isCustom() ) {
 	 if( c->customItem()->placement() == KoTextCustomItem::PlaceInline ) {
              // customitem width is in LU pixels. Convert to 100%-zoom-pixels (pt2pt==pix2pix)
-             int w = qRound( KoTextZoomHandler::layoutUnitPtToPt( c->customItem()->width ) );
-             return applyZoom ? ( w * zh->zoom() / 100 ) : w;
+             double w = KoTextZoomHandler::layoutUnitPtToPt( c->customItem()->width );
+             return qRound( applyZoom ? ( w * zh->zoomFactorX() ) : w );
          }
          else
              return 0;
     }
     int pixelww;
     int r = c->c.row();
-#ifndef INDIC
-    if( r < 0x06 || r > 0x1f )
-#else
     if( /*r < 0x06 || r > 0x1f*/ r < 0x06 || (r > 0x1f && !(r > 0xd7 && r < 0xe0)) )
-#endif
     {
         // Small caps -> we can't use the cached font metrics from KoTextFormat
         if ( attributeFont() == KoTextFormat::ATT_SMALL_CAPS && c->c.upper() != c->c )
@@ -796,19 +1156,10 @@ int KoTextFormat::charWidth( const KoZoomHandler* zh, bool applyZoom, const KoTe
         const QFontMetrics& fontMetrics = smallCaps ? smallCapsFont( zh, applyZoom ) : applyZoom ? screenFontMetrics( zh ) : refFontMetrics();
         QString str;
         int pos = 0;
-#ifndef INDIC
-        if( i > 4 )
-            pos = i - 4;
-#else
         if( i > 8 )
             pos = i - 8;
-#endif
         int off = i - pos;
-#ifndef INDIC
-        int end = QMIN( parag->length(), i + 4 );
-#else
         int end = QMIN( parag->length(), i + 8 );
-#endif
         while ( pos < end ) {
             str += displayedChar( parag->at(pos)->c );
             pos++;
@@ -816,21 +1167,6 @@ int KoTextFormat::charWidth( const KoZoomHandler* zh, bool applyZoom, const KoTe
         pixelww = fontMetrics.charWidth( str, off );
     }
 
-#if 0
-    // Add room for the shadow - hmm, this is wrong. A word with a shadow
-    // doesn't need to space its chars so that the shadow never runs into
-    // the next char. The usual effect is that it DOES run into other chars.
-    if ( d->m_shadowDistanceX != 0 )
-    {
-        // pt to pixel conversion
-        int shadowpix = (int)(POINT_TO_INCH( static_cast<double>( QPaintDevice::x11AppDpiX() ) ) * QABS( d->m_shadowDistanceX ) );
-        //kdDebug(32500) << "d->m_shadowDistanceX=" << d->m_shadowDistanceX << " -> shadowpix=" << shadowpix
-        //      << ( applyZoom ? " and applying zoom " : " (100% zoom) " )
-        //      << " -> adding " << ( applyZoom ? (  shadowpix * zh->zoom() / 100 ) : shadowpix ) << endl;
-        pixelww += applyZoom ? ( shadowpix * zh->zoom() / 100 ) : shadowpix;
-    }
-#endif
-
 #if 0
         kdDebug(32500) << "KoTextFormat::charWidth: char=" << QString(c->c) << " format=" << key()
                        << ", applyZoom=" << applyZoom << " pixel-width=" << pixelww << endl;
@@ -852,7 +1188,7 @@ int KoTextFormat::height() const
         // Add room for the shadow
         if ( d->m_shadowDistanceY != 0 ) {
             // pt -> pixel (at 100% zoom)
-            h += (int)(POINT_TO_INCH( static_cast<double>( QPaintDevice::x11AppDpiY() ) ) * QABS( d->m_shadowDistanceY ) );
+            h += (int)(POINT_TO_INCH( static_cast<double>( KoGlobal::dpiY() ) ) * QABS( d->m_shadowDistanceY ) );
         }
 
         //kdDebug(32500) << "KoTextFormat::height 100%-zoom font says h=" << h << " in LU:" << KoTextZoomHandler::ptToLayoutUnitPt(h) << endl;
@@ -872,7 +1208,7 @@ int KoTextFormat::offsetX() const // in LU pixels
     if ( d->m_shadowDistanceX < 0 )
     {
         double lupt = KoTextZoomHandler::ptToLayoutUnitPt( QABS( d->m_shadowDistanceX ) );
-        off += (int)(POINT_TO_INCH( static_cast<double>( QPaintDevice::x11AppDpiX() ) ) * lupt );
+        off += (int)(POINT_TO_INCH( static_cast<double>( KoGlobal::dpiX() ) ) * lupt );
     }
 #endif
     return off;
@@ -886,7 +1222,7 @@ int KoTextFormat::offsetY() const // in LU pixels
     if ( d->m_shadowDistanceY < 0 )
     {
         double lupt = KoTextZoomHandler::ptToLayoutUnitPt( QABS( d->m_shadowDistanceY ) );
-        off += (int)(POINT_TO_INCH( static_cast<double>( QPaintDevice::x11AppDpiY() ) ) * lupt );
+        off += (int)(POINT_TO_INCH( static_cast<double>( KoGlobal::dpiY() ) ) * lupt );
     }
 #endif
     return off;
@@ -1016,7 +1352,7 @@ void KoTextFormat::parseShadowFromCss( const QString& _css )
             kdWarning(32500) << "Parse error in text-shadow: " << css << endl;
             return;
         }
-        // Check which token looks like a colour
+        // Check which token looks like a color
         QColor col( tokens.first() );
         if ( col.isValid() )
             tokens.pop_front();
@@ -1038,6 +1374,7 @@ void KoTextFormat::parseShadowFromCss( const QString& _css )
             tokens.pop_front();
         }
         // We ignore whatever else is in the string (e.g. blur radius, other shadows)
+
     }
     update();
 }
@@ -1199,7 +1536,7 @@ void KoTextFormat::setLanguage( const QString & _lang)
 QStringList KoTextFormat::underlineTypeList()
 {
     QStringList lst;
-    lst <<i18n("Without");
+    lst <<i18n("Underline Style", "None");
     lst <<i18n("Single");
     lst <<i18n("Simple Bold");
     lst <<i18n("Double");
@@ -1210,7 +1547,7 @@ QStringList KoTextFormat::underlineTypeList()
 QStringList KoTextFormat::strikeOutTypeList()
 {
     QStringList lst;
-    lst <<i18n("Without");
+    lst <<i18n("Strikeout Style", "None");
     lst <<i18n("Single");
     lst <<i18n("Simple Bold");
     lst <<i18n("Double");
@@ -1230,26 +1567,25 @@ QStringList KoTextFormat::fontAttributeList()
 QStringList KoTextFormat::underlineStyleList()
 {
     QStringList lst;
-    lst <<i18n("Solid Line");
-    lst <<i18n("Dash Line");
-    lst <<i18n("Dot Line");
-    lst <<i18n("Dash Dot Line");
-    lst <<i18n("Dash Dot Dot Line");
+    lst <<"_________";   // SOLID
+    lst <<"___ ___ __";  // DASH
+    lst <<"_ _ _ _ _ _"; // DOT
+    lst <<"___ _ ___ _"; // DASH_DOT
+    lst <<"___ _ _ ___"; // DASH_DOT_DOT
     return lst;
 }
 
 QStringList KoTextFormat::strikeOutStyleList()
 {
     QStringList lst;
-    lst <<i18n("Solid Line");
-    lst <<i18n("Dash Line");
-    lst <<i18n("Dot Line");
-    lst <<i18n("Dash Dot Line");
-    lst <<i18n("Dash Dot Dot Line");
+    lst <<"_________";   // SOLID
+    lst <<"___ ___ __";  // DASH
+    lst <<"_ _ _ _ _ _"; // DOT
+    lst <<"___ _ ___ _"; // DASH_DOT
+    lst <<"___ _ _ ___"; // DASH_DOT_DOT
     return lst;
 }
 
-
 #ifndef NDEBUG
 void KoTextFormat::printDebug()
 {
@@ -1269,20 +1605,20 @@ KoTextFormatCollection::KoTextFormatCollection()
 #ifdef DEBUG_COLLECTION
     kdDebug(32500) << "KoTextFormatCollection::KoTextFormatCollection " << this << endl;
 #endif
-    defFormat = new KoTextFormat( QApplication::font(), QColor(), KGlobal::locale()->language(), false, 1.0 ); //// kotext: need to use default QColor here
+    defFormat = new KoTextFormat( QApplication::font(), QColor(), KGlobal::locale()->language(), false );
     lastFormat = cres = 0;
     cflags = -1;
     cKey.setAutoDelete( TRUE );
     cachedFormat = 0;
 }
 
-KoTextFormatCollection::KoTextFormatCollection( const QFont& defaultFont, const QColor& defaultColor, const QString & defaultLanguage, bool hyphen, double ulw )
-    : cKey( 307 )//, sheet( 0 )
+KoTextFormatCollection::KoTextFormatCollection( const QFont& defaultFont, const QColor& defaultColor, const QString & defaultLanguage, bool defaultHyphenation )
+    : cKey( 307 )
 {
 #ifdef DEBUG_COLLECTION
     kdDebug(32500) << "KoTextFormatCollection::KoTextFormatCollection " << this << endl;
 #endif
-    defFormat = new KoTextFormat( defaultFont, defaultColor, defaultLanguage, hyphen, ulw );
+    defFormat = new KoTextFormat( defaultFont, defaultColor, defaultLanguage, defaultHyphenation );
     lastFormat = cres = 0;
     cflags = -1;
     cKey.setAutoDelete( TRUE );
@@ -1393,7 +1729,8 @@ KoTextFormat *KoTextFormatCollection::format( const KoTextFormat *of, const KoTe
     return cres;
 }
 
-KoTextFormat *KoTextFormatCollection::format( const QFont &f, const QColor &c, const QString & language, bool hyphen, double ulw )
+#if 0
+KoTextFormat *KoTextFormatCollection::format( const QFont &f, const QColor &c, const QString & language, bool hyphen )
 {
     if ( cachedFormat && cfont == f && ccol == c ) {
 #ifdef DEBUG_COLLECTION
@@ -1419,7 +1756,7 @@ KoTextFormat *KoTextFormatCollection::format( const QFont &f, const QColor &c, c
     if ( key == defFormat->key() )
 	return defFormat;
 
-    cachedFormat = createFormat( f, c,language, hyphen, ulw );
+    cachedFormat = createFormat( f, c, language, hyphen );
     cachedFormat->collection = this;
     cKey.insert( cachedFormat->key(), cachedFormat );
     if ( cachedFormat->key() != key )
@@ -1429,6 +1766,7 @@ KoTextFormat *KoTextFormatCollection::format( const QFont &f, const QColor &c, c
 #endif
     return cachedFormat;
 }
+#endif
 
 void KoTextFormatCollection::remove( KoTextFormat *f )
 {
@@ -1441,6 +1779,14 @@ void KoTextFormatCollection::remove( KoTextFormat *f )
     cKey.remove( f->key() );
 }
 
+void KoTextFormatCollection::zoomChanged()
+{
+    QDictIterator<KoTextFormat> it( cKey );
+    for ( ; it.current(); ++it ) {
+        it.current()->zoomChanged();
+    }
+}
+
 #if 0
 void KoTextFormatCollection::setPainter( QPainter *p )
 {
@@ -1467,5 +1813,4 @@ void KoTextFormatCollection::debug()
     }
     kdDebug(32500) << "------------ KoTextFormatCollection: debug --------------- END" << endl;
 }
-
 #endif
